(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    366058,       6730]
NotebookOptionsPosition[    360959,       6652]
NotebookOutlinePosition[    361534,       6673]
CellTagsIndexPosition[    361491,       6670]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 20 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}, {
   3.890973965108789*^9, 3.8909739653874283`*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0521a82d-3ac4-4af3-ac0c-3ecb329ec3ba"],

Cell["Chapter 9, Section 9.9, Figures 9.33\[Dash]34", "Section",ExpressionUUID->"6e8e70b0-1575-4ccc-baaf-e425552046ca"],

Cell["\<\
Calculate the Julian date corresponding to 1st September 1989 when Pluto was \
at perihelion.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3c7aeaef-b3f9-4c07-be4d-8f4bc4dbd77f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"date", " ", "=", " ", 
  RowBox[{"JulianDate", "[", 
   RowBox[{"{", 
    RowBox[{"1989", ",", " ", "9", ",", " ", "1", ",", " ", "0."}], "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.888915746690968*^9, 3.8889157466936607`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"d4a525c2-5c7e-4c5f-99a4-e11877c21736"],

Cell[BoxData["2.4477704583333335`*^6"], "Output",
 CellChangeTimes->{3.888915799186715*^9, 3.889269598557332*^9, 
  3.889338214152874*^9, 3.8894198118377132`*^9, 3.889427729014464*^9, 
  3.891017626527133*^9},
 CellLabel->"Out[1]=",ExpressionUUID->"193a76b0-a57d-460c-82d4-bca8163b54d2"]
}, Open  ]],

Cell[TextData[{
 "Next we define a function ",
 StyleBox["PrintPlanetXYZ", "Input"],
 " that will use the data in Tables A.2 and A.3 to derive and print out \
details of the calculation of the coordinates and orbital elements of planet \
number ",
 StyleBox["id", "Input"],
 " at Julian Date ",
 StyleBox["jd", "Input"],
 ".  Note that ",
 StyleBox["id", "Input"],
 "=1,2,...,9 corresponds to Mercury, Venus, ..., Pluto."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1e6ea287-f3f6-406f-a963-81a6d3dcd9d1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"PrintPlanetXYZ", "[", 
     RowBox[{"id_", ",", "jd_"}], "]"}], " ", ":=", "\n", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{"a", " ", "=", " ", 
         RowBox[{"{", "    ", 
          RowBox[{
          "0.38709893", ",", "     ", "0.72333199", ",", "     ", 
           "1.00000011", ",", " ", "\n", "                  ", "1.52366231", 
           ",", "     ", "5.20336301", ",", "     ", "9.53707032", ",", "\n", 
           "                 ", "19.19126393", ",", "    ", "30.06896348", 
           ",", "    ", "39.48168677"}], "}"}]}], ",", "\n", "        ", 
        RowBox[{"\[Delta]a", " ", "=", " ", 
         RowBox[{"{", "    ", 
          RowBox[{"0.00000066", ",", "     ", "0.00000092", ",", "    ", 
           RowBox[{"-", "0.00000005"}], ",", "\n", "                 ", 
           RowBox[{"-", "0.00007221"}], ",", "     ", "0.00060737", ",", 
           "    ", 
           RowBox[{"-", "0.00301530"}], ",", "\n", "                  ", 
           "0.00152025", ",", "    ", 
           RowBox[{"-", "0.00125196"}], ",", "    ", 
           RowBox[{"-", "0.00076912"}]}], "}"}]}], ",", "\n", "         ", 
        RowBox[{"e", " ", "=", " ", 
         RowBox[{"{", "    ", 
          RowBox[{
          "0.20563069", ",", "     ", "0.00677323", ",", "     ", 
           "0.01671022", ",", "\n", "                  ", "0.09341233", ",", 
           "     ", "0.04839266", ",", "     ", "0.05415060", ",", "\n", 
           "                  ", "0.04716771", ",", "     ", "0.00858587", 
           ",", "     ", "0.24880766"}], "}"}]}], ",", "\n", "        ", 
        RowBox[{"\[Delta]e", " ", "=", " ", 
         RowBox[{"{", "    ", 
          RowBox[{"0.00002527", ",", "    ", 
           RowBox[{"-", "0.00004938"}], ",", "    ", 
           RowBox[{"-", "0.00003804"}], ",", "\n", "                  ", 
           "0.00011902", ",", "    ", 
           RowBox[{"-", "0.00012880"}], ",", "    ", 
           RowBox[{"-", "0.00036762"}], ",", "\n", "                 ", 
           RowBox[{"-", "0.00019150"}], ",", "     ", "0.00002514", ",", 
           "     ", "0.00006465"}], "}"}]}], ",", "\n", "         ", 
        RowBox[{"i", " ", "=", " ", 
         RowBox[{"{", "    ", 
          RowBox[{
          "7.00487", ",", "        ", "3.39471", ",", "        ", "0.00005", 
           ",", "\n", "                  ", "1.85061", ",", "        ", 
           "1.30530", ",", "        ", "2.48446", ",", "\n", 
           "                  ", "0.76986", ",", "        ", "1.76917", ",", 
           "       ", "17.14175"}], "   ", "}"}]}], ",", "\n", "        ", 
        RowBox[{"\[Delta]i", " ", "=", " ", 
         RowBox[{"{", "  ", 
          RowBox[{
           RowBox[{"-", "23.51"}], ",", "          ", 
           RowBox[{"-", "2.86"}], ",", "         ", 
           RowBox[{"-", "46.94"}], ",", "\n", "                ", 
           RowBox[{"-", "25.47"}], ",", "          ", 
           RowBox[{"-", "4.15"}], ",", "           ", "6.11", ",", "\n", 
           "                 ", 
           RowBox[{"-", "2.09"}], ",", "          ", 
           RowBox[{"-", "3.64"}], ",", "          ", "11.07"}], "      ", 
          "}"}]}], ",", "\n", "         ", 
        RowBox[{"\[CapitalOmega]", " ", "=", " ", 
         RowBox[{"{", "   ", 
          RowBox[{"48.33167", ",", "       ", "76.68069", ",", "      ", 
           RowBox[{"-", "11.26064"}], ",", "\n", "                 ", 
           "49.57854", ",", "      ", "100.55615", ",", "      ", "113.71504",
            ",", "\n", "                 ", "74.22988", ",", "      ", 
           "131.72169", ",", "      ", "110.30347"}], "   ", "}"}]}], ",", 
        "\n", "        ", 
        RowBox[{"\[Delta]\[CapitalOmega]", " ", "=", " ", 
         RowBox[{"{", " ", 
          RowBox[{
           RowBox[{"-", "446.30"}], ",", "        ", 
           RowBox[{"-", "996.89"}], ",", "      ", 
           RowBox[{"-", "18228.25"}], ",", "\n", "              ", 
           RowBox[{"-", "1020.19"}], ",", "        ", "1217.17", ",", 
           "       ", 
           RowBox[{"-", "1591.05"}], ",", "\n", "               ", "1681.40", 
           ",", "        ", 
           RowBox[{"-", "151.25"}], ",", "         ", 
           RowBox[{"-", "37.33"}]}], "      ", "}"}]}], ",", "\n", 
        "         ", 
        RowBox[{"\[CurlyPi]", " ", "=", " ", 
         RowBox[{"{", "   ", 
          RowBox[{
          "77.45645", ",", "      ", "131.53298", ",", "      ", "102.94719", 
           ",", "\n", "                ", "336.04084", ",", "       ", 
           "14.75385", ",", "       ", "92.43194", ",", "\n", 
           "                ", "170.96424", ",", "       ", "44.97135", ",", 
           "      ", "224.06676"}], "   ", "}"}]}], ",", "\n", "        ", 
        RowBox[{"\[Delta]\[CurlyPi]", " ", "=", " ", 
         RowBox[{"{", "  ", 
          RowBox[{"573.57", ",", "        ", 
           RowBox[{"-", "108.80"}], ",", "        ", "1198.28", ",", "\n", 
           "               ", "1560.78", ",", "         ", "839.93", ",", 
           "       ", 
           RowBox[{"-", "1948.89"}], ",", "\n", "               ", "1312.56", 
           ",", "        ", 
           RowBox[{"-", "844.43"}], ",", "        ", 
           RowBox[{"-", "132.25"}]}], "      ", "}"}]}], ",", "\n", 
        "         ", 
        RowBox[{"\[Lambda]", " ", "=", " ", 
         RowBox[{"{", "  ", 
          RowBox[{
          "252.25084", ",", "      ", "181.97973", ",", "      ", "100.46435",
            ",", "\n", "                ", "355.45332", ",", "       ", 
           "34.40438", ",", "       ", "49.94432", ",", "\n", 
           "                ", "313.23218", ",", "      ", "304.88003", ",", 
           "      ", "238.92881"}], "   ", "}"}]}], ",", "\n", "        ", 
        RowBox[{"\[Delta]\[Lambda]", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{
          "261628.29", ",", "      ", "712136.06", ",", "     ", "1293740.63",
            ",", "\n", "              ", "217103.78", ",", "      ", 
           "557078.35", ",", "      ", "513052.95", ",", "\n", 
           "              ", "246547.79", ",", "      ", "786449.21", ",", 
           "      ", "522747.90"}], "     ", "}"}]}], ",", "\n", "       ", 
        RowBox[{"rev", " ", "=", " ", 
         RowBox[{"{", "  ", 
          RowBox[{
          "415", ",", "            ", "162", ",", "             ", "99", ",", 
           "\n", "                 ", "53", ",", "              ", "8", ",", 
           "              ", "3", ",", "\n", "                  ", "1", ",", 
           "              ", "0", ",", "              ", "0"}], "         ", 
          "}"}]}], ",", "\n", "       ", 
        RowBox[{"j2000", " ", "=", " ", "2451545.0"}], ",", " ", "t", ",", 
        " ", "aa", ",", " ", "ee", ",", " ", "ii", ",", " ", "nnode", ",", 
        " ", "llp", ",", " ", "\[Omega]", ",", "om", ",", " ", "llam", ",", 
        "\n", "       ", "ma", ",", " ", "rma", ",", "x", ",", " ", "y", ",", 
        " ", "ea", ",", " ", "eca", ",", " ", "deca", ",", " ", "p1", ",", 
        " ", "p2", ",", " ", "p3", ",", " ", "p", ",", " ", "r"}], "}"}], ",",
       "\n", 
      RowBox[{
       RowBox[{"t", "     ", "=", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"jd", " ", "-", " ", "j2000"}], ")"}], "/", "36525"}]}], 
       ";", "\n", 
       RowBox[{"aa", "    ", "=", " ", 
        RowBox[{
         RowBox[{"a", "[", 
          RowBox[{"[", "id", "]"}], "]"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"\[Delta]a", "[", 
           RowBox[{"[", "id", "]"}], "]"}], "*", "t"}]}]}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Semimajor axis (AU) : \>\"", ",", "aa"}], "]"}], ";", 
       "\n", 
       RowBox[{"ee", "    ", "=", " ", 
        RowBox[{
         RowBox[{"e", "[", 
          RowBox[{"[", "id", "]"}], "]"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"\[Delta]e", "[", 
           RowBox[{"[", "id", "]"}], "]"}], "*", "t"}]}]}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Eccentricity        : \>\"", ",", "ee"}], "]"}], ";", 
       "\n", 
       RowBox[{"ii", "    ", "=", " ", 
        RowBox[{"Mod", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"i", "[", 
            RowBox[{"[", "id", "]"}], "]"}], "    ", "+", " ", 
           RowBox[{
            RowBox[{"\[Delta]i", "[", 
             RowBox[{"[", "id", "]"}], "]"}], "*", 
            RowBox[{"t", "/", "3600"}]}]}], ",", " ", "360"}], "]"}]}], ";", 
       "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Inclination         : \>\"", ",", "ii"}], "]"}], ";", 
       "\n", 
       RowBox[{"nnode", " ", "=", " ", 
        RowBox[{"Mod", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"\[CapitalOmega]", "[", 
            RowBox[{"[", "id", "]"}], "]"}], " ", "+", " ", 
           RowBox[{
            RowBox[{"\[Delta]\[CapitalOmega]", "[", 
             RowBox[{"[", "id", "]"}], "]"}], "*", 
            RowBox[{"t", "/", "3600"}]}]}], ",", " ", "360"}], "]"}]}], ";", 
       "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"nnode", " ", "<", " ", "0"}], ",", " ", 
         RowBox[{"nnode", " ", "=", " ", 
          RowBox[{"nnode", " ", "+", " ", "360"}]}]}], "]"}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Long. of Asc. Node  : \>\"", ",", "nnode"}], "]"}], ";", 
       "\n", 
       RowBox[{"llp", "   ", "=", " ", 
        RowBox[{"Mod", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"\[CurlyPi]", "[", 
            RowBox[{"[", "id", "]"}], "]"}], "   ", "+", " ", 
           RowBox[{
            RowBox[{"\[Delta]\[CurlyPi]", "[", 
             RowBox[{"[", "id", "]"}], "]"}], "*", 
            RowBox[{"t", "/", "3600"}]}]}], ",", " ", "360"}], "]"}]}], ";", 
       "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"llp", " ", "<", " ", "0"}], ",", " ", 
         RowBox[{"llp", " ", "=", " ", 
          RowBox[{"llp", " ", "+", " ", "360"}]}]}], "]"}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Long. of Perihelion : \>\"", ",", "llp"}], "]"}], ";", 
       "\n", 
       RowBox[{"\[Omega]", " ", "=", " ", 
        RowBox[{"llp", " ", "-", " ", "nnode"}]}], ";", "\n", 
       RowBox[{"llam", "  ", "=", " ", 
        RowBox[{"Mod", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Lambda]", "[", 
            RowBox[{"[", "id", "]"}], "]"}], "  ", "+", " ", "\n", 
           "            ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"\[Delta]\[Lambda]", "[", 
                RowBox[{"[", "id", "]"}], "]"}], "/", "3600"}], " ", "+", " ", 
              RowBox[{
               RowBox[{"rev", "[", 
                RowBox[{"[", "id", "]"}], "]"}], "*", "360"}]}], ")"}], "*", 
            "t"}]}], ",", " ", "360"}], "]"}]}], ";", "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"llam", " ", "<", " ", "0"}], ",", " ", 
         RowBox[{"llam", " ", "=", " ", 
          RowBox[{"llam", " ", "+", " ", "360"}]}]}], "]"}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Mean Longitude      : \>\"", ",", "llam"}], "]"}], ";", 
       "\n", 
       RowBox[{"ma", " ", "=", " ", 
        RowBox[{"Mod", "[", 
         RowBox[{
          RowBox[{"llam", " ", "-", " ", "llp"}], ",", " ", "360"}], "]"}]}], 
       ";", "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"ma", " ", "<", " ", "0"}], ",", " ", 
         RowBox[{"ma", " ", "=", " ", 
          RowBox[{"ma", " ", "+", " ", "360"}]}]}], "]"}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Mean Anomaly        : \>\"", ",", "ma"}], "]"}], ";", 
       "\n", 
       RowBox[{"rma", " ", "=", " ", 
        RowBox[{"N", "[", 
         RowBox[{"ma", " ", "\[Degree]"}], "]"}]}], ";", "\n", 
       RowBox[{"eca", " ", "=", " ", 
        RowBox[{"ea", " ", "/.", " ", 
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"ea", " ", "-", " ", 
             RowBox[{"ee", " ", 
              RowBox[{"Sin", "[", "ea", "]"}]}]}], " ", "==", " ", "rma"}], 
           ",", " ", 
           RowBox[{"{", 
            RowBox[{"ea", ",", "rma"}], "}"}]}], "]"}]}]}], ";", "\n", 
       RowBox[{"deca", " ", "=", " ", 
        RowBox[{"N", "[", 
         RowBox[{"eca", "/", "\[Degree]"}], "]"}]}], ";", "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"deca", " ", "<", " ", "0"}], ",", " ", 
         RowBox[{"deca", " ", "=", " ", 
          RowBox[{"deca", " ", "+", " ", "360"}]}]}], "]"}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Eccentric Anomaly   : \>\"", ",", "deca"}], "]"}], ";", 
       "\n", 
       RowBox[{"x", " ", "=", " ", 
        RowBox[{"aa", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", "eca", "]"}], " ", "-", " ", "ee"}], ")"}]}]}],
        ";", " ", "\n", 
       RowBox[{"y", " ", "=", " ", 
        RowBox[{"aa", "*", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"1", "-", 
           RowBox[{"ee", "^", "2"}]}], "]"}], "*", 
         RowBox[{"Sin", "[", "eca", "]"}]}]}], ";", "\n", 
       RowBox[{"r", " ", "=", " ", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"x", "^", "2"}], " ", "+", " ", 
          RowBox[{"y", "^", "2"}]}], "]"}]}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Radius (AU)         : \>\"", ",", "r"}], "]"}], ";", 
       "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<{x, y} coordinates  : \>\"", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y"}], "}"}]}], "]"}], ";", "\n", 
       RowBox[{"p1", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"\[Omega]", " ", "\[Degree]"}], "]"}], ",", "    ", 
            RowBox[{"-", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Omega]", " ", "\[Degree]"}], "]"}]}], ",", "     ", 
            "0"}], "             ", "}"}], ",", "\n", "      ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{"\[Omega]", " ", "\[Degree]"}], "]"}], ",", "     ", 
            RowBox[{"Cos", "[", 
             RowBox[{"\[Omega]", " ", "\[Degree]"}], "]"}], ",", "     ", 
            "0"}], "             ", "}"}], ",", "\n", "      ", 
          RowBox[{"{", 
           RowBox[{
           "0", ",", "                  ", "0", ",", "                  ", 
            "1"}], "             ", "}"}]}], "}"}]}], ";", "\n", 
       RowBox[{"p2", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1", ",", "                  ", "0", ",", "                  ", 
            "0"}], "             ", "}"}], ",", "\n", "      ", 
          RowBox[{"{", 
           RowBox[{"0", ",", "                  ", 
            RowBox[{"Cos", "[", 
             RowBox[{"ii", " ", "\[Degree]"}], "]"}], ",", "    ", 
            RowBox[{"-", 
             RowBox[{"Sin", "[", 
              RowBox[{"ii", " ", "\[Degree]"}], "]"}]}]}], "}"}], ",", "\n", 
          "      ", 
          RowBox[{"{", 
           RowBox[{"0", ",", "                  ", 
            RowBox[{"Sin", "[", 
             RowBox[{"ii", " ", "\[Degree]"}], "]"}], ",", "     ", 
            RowBox[{"Cos", "[", 
             RowBox[{"ii", " ", "\[Degree]"}], "]"}]}], "}"}]}], "}"}]}], ";",
        "\n", 
       RowBox[{"p3", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"nnode", " ", "\[Degree]"}], "]"}], ",", " ", 
            RowBox[{"-", 
             RowBox[{"Sin", "[", 
              RowBox[{"nnode", " ", "\[Degree]"}], "]"}]}], ",", "  ", "0"}], 
           "             ", "}"}], ",", "\n", "      ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{"nnode", " ", "\[Degree]"}], "]"}], ",", "  ", 
            RowBox[{"Cos", "[", 
             RowBox[{"nnode", " ", "\[Degree]"}], "]"}], ",", "  ", "0"}], 
           "             ", "}"}], ",", "\n", "      ", 
          RowBox[{"{", 
           RowBox[{
           "0", ",", "                  ", "0", ",", "                  ", 
            "1"}], "             ", "}"}]}], "}"}]}], ";", "\n", 
       RowBox[{"p", " ", "=", " ", 
        RowBox[{"N", "[", 
         RowBox[{"p3", ".", "p2", ".", "p1"}], "]"}]}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Rotation Matrix P1  : \>\"", ",", 
         RowBox[{"MatrixForm", "[", 
          RowBox[{"N", "[", "p1", "]"}], "]"}]}], "]"}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Rotation Matrix P2  : \>\"", ",", 
         RowBox[{"MatrixForm", "[", 
          RowBox[{"N", "[", "p2", "]"}], "]"}]}], "]"}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Rotation Matrix P3  : \>\"", ",", 
         RowBox[{"MatrixForm", "[", 
          RowBox[{"N", "[", "p3", "]"}], "]"}]}], "]"}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Rotation Matrix P   : \>\"", ",", 
         RowBox[{"MatrixForm", "[", "p", "]"}]}], "]"}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<{X, Y, Z} coords.   : \>\"", ",", 
         RowBox[{"p", ".", 
          RowBox[{"{", 
           RowBox[{"x", ",", " ", "y", ",", " ", "0"}], "}"}]}]}], "]"}]}]}], 
     "\n", "]"}]}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.88891577812367*^9, 3.888915778126639*^9}, {
  3.8892648371691713`*^9, 3.889264844441382*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"e986d2c8-6682-408d-b946-ac05cf7e7474"],

Cell[TextData[{
 "Here we define a function ",
 StyleBox["PlanetXYZ", "Input"],
 " that is identical to ",
 StyleBox["PrintPlanetXYZ", "Input"],
 " except that it does not print out any of the results.  Again it uses the \
data in Tables A.2 and A.3 to derive the ",
 StyleBox["(X,Y,Z)", "Input"],
 " coordinates of planet number ",
 StyleBox["id", "Input"],
 " at Julian Date ",
 StyleBox["jd", "Input"],
 ".  Note that ",
 StyleBox["id", "Input"],
 "=1,2,...,9 corresponds to Mercury, Venus, ..., Pluto."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"06eee10d-3ff4-41e5-a807-c90227427eee"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"PlanetXYZ", "[", 
     RowBox[{"id_", ",", " ", "jd_"}], "]"}], " ", ":=", "\n", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{"a", " ", "=", " ", 
         RowBox[{"{", "    ", 
          RowBox[{
          "0.38709893", ",", "     ", "0.72333199", ",", "     ", 
           "1.00000011", ",", " ", "\n", "                  ", "1.52366231", 
           ",", "     ", "5.20336301", ",", "     ", "9.53707032", ",", "\n", 
           "                 ", "19.19126393", ",", "    ", "30.06896348", 
           ",", "    ", "39.48168677"}], "}"}]}], ",", "\n", "        ", 
        RowBox[{"\[Delta]a", " ", "=", " ", 
         RowBox[{"{", "    ", 
          RowBox[{"0.00000066", ",", "     ", "0.00000092", ",", "    ", 
           RowBox[{"-", "0.00000005"}], ",", "\n", "                 ", 
           RowBox[{"-", "0.00007221"}], ",", "     ", "0.00060737", ",", 
           "    ", 
           RowBox[{"-", "0.00301530"}], ",", "\n", "                  ", 
           "0.00152025", ",", "    ", 
           RowBox[{"-", "0.00125196"}], ",", "    ", 
           RowBox[{"-", "0.00076912"}]}], "}"}]}], ",", "\n", "         ", 
        RowBox[{"e", " ", "=", " ", 
         RowBox[{"{", "    ", 
          RowBox[{
          "0.20563069", ",", "     ", "0.00677323", ",", "     ", 
           "0.01671022", ",", "\n", "                  ", "0.09341233", ",", 
           "     ", "0.04839266", ",", "     ", "0.05415060", ",", "\n", 
           "                  ", "0.04716771", ",", "     ", "0.00858587", 
           ",", "     ", "0.24880766"}], "}"}]}], ",", "\n", "        ", 
        RowBox[{"\[Delta]e", " ", "=", " ", 
         RowBox[{"{", "    ", 
          RowBox[{"0.00002527", ",", "    ", 
           RowBox[{"-", "0.00004938"}], ",", "    ", 
           RowBox[{"-", "0.00003804"}], ",", "\n", "                  ", 
           "0.00011902", ",", "    ", 
           RowBox[{"-", "0.00012880"}], ",", "    ", 
           RowBox[{"-", "0.00036762"}], ",", "\n", "                 ", 
           RowBox[{"-", "0.00019150"}], ",", "     ", "0.00002514", ",", 
           "     ", "0.00006465"}], "}"}]}], ",", "\n", "         ", 
        RowBox[{"i", " ", "=", " ", 
         RowBox[{"{", "    ", 
          RowBox[{
          "7.00487", ",", "        ", "3.39471", ",", "        ", "0.00005", 
           ",", "\n", "                  ", "1.85061", ",", "        ", 
           "1.30530", ",", "        ", "2.48446", ",", "\n", 
           "                  ", "0.76986", ",", "        ", "1.76917", ",", 
           "       ", "17.14175"}], "   ", "}"}]}], ",", "\n", "        ", 
        RowBox[{"\[Delta]i", " ", "=", " ", 
         RowBox[{"{", "  ", 
          RowBox[{
           RowBox[{"-", "23.51"}], ",", "          ", 
           RowBox[{"-", "2.86"}], ",", "         ", 
           RowBox[{"-", "46.94"}], ",", "\n", "                ", 
           RowBox[{"-", "25.47"}], ",", "          ", 
           RowBox[{"-", "4.15"}], ",", "           ", "6.11", ",", "\n", 
           "                 ", 
           RowBox[{"-", "2.09"}], ",", "          ", 
           RowBox[{"-", "3.64"}], ",", "          ", "11.07"}], "      ", 
          "}"}]}], ",", "\n", "         ", 
        RowBox[{"\[CapitalOmega]", " ", "=", " ", 
         RowBox[{"{", "   ", 
          RowBox[{"48.33167", ",", "       ", "76.68069", ",", "      ", 
           RowBox[{"-", "11.26064"}], ",", "\n", "                 ", 
           "49.57854", ",", "      ", "100.55615", ",", "      ", "113.71504",
            ",", "\n", "                 ", "74.22988", ",", "      ", 
           "131.72169", ",", "      ", "110.30347"}], "   ", "}"}]}], ",", 
        "\n", "        ", 
        RowBox[{"\[Delta]\[CapitalOmega]", " ", "=", " ", 
         RowBox[{"{", " ", 
          RowBox[{
           RowBox[{"-", "446.30"}], ",", "        ", 
           RowBox[{"-", "996.89"}], ",", "      ", 
           RowBox[{"-", "18228.25"}], ",", "\n", "              ", 
           RowBox[{"-", "1020.19"}], ",", "        ", "1217.17", ",", 
           "       ", 
           RowBox[{"-", "1591.05"}], ",", "\n", "               ", "1681.40", 
           ",", "        ", 
           RowBox[{"-", "151.25"}], ",", "         ", 
           RowBox[{"-", "37.33"}]}], "      ", "}"}]}], ",", "\n", 
        "         ", 
        RowBox[{"\[CurlyPi]", " ", "=", " ", 
         RowBox[{"{", "   ", 
          RowBox[{
          "77.45645", ",", "      ", "131.53298", ",", "      ", "102.94719", 
           ",", "\n", "                ", "336.04084", ",", "       ", 
           "14.75385", ",", "       ", "92.43194", ",", "\n", 
           "                ", "170.96424", ",", "       ", "44.97135", ",", 
           "      ", "224.06676"}], "   ", "}"}]}], ",", "\n", "        ", 
        RowBox[{"\[Delta]\[CurlyPi]", " ", "=", " ", 
         RowBox[{"{", "  ", 
          RowBox[{"573.57", ",", "        ", 
           RowBox[{"-", "108.80"}], ",", "        ", "1198.28", ",", "\n", 
           "               ", "1560.78", ",", "         ", "839.93", ",", 
           "       ", 
           RowBox[{"-", "1948.89"}], ",", "\n", "               ", "1312.56", 
           ",", "        ", 
           RowBox[{"-", "844.43"}], ",", "        ", 
           RowBox[{"-", "132.25"}]}], "      ", "}"}]}], ",", "\n", 
        "         ", 
        RowBox[{"\[Lambda]", " ", "=", " ", 
         RowBox[{"{", "  ", 
          RowBox[{
          "252.25084", ",", "      ", "181.97973", ",", "      ", "100.46435",
            ",", "\n", "                ", "355.45332", ",", "       ", 
           "34.40438", ",", "       ", "49.94432", ",", "\n", 
           "                ", "313.23218", ",", "      ", "304.88003", ",", 
           "      ", "238.92881"}], "   ", "}"}]}], ",", "\n", "        ", 
        RowBox[{"\[Delta]\[Lambda]", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{
          "261628.29", ",", "      ", "712136.06", ",", "     ", "1293740.63",
            ",", "\n", "              ", "217103.78", ",", "      ", 
           "557078.35", ",", "      ", "513052.95", ",", "\n", 
           "              ", "246547.79", ",", "      ", "786449.21", ",", 
           "      ", "522747.90"}], "     ", "}"}]}], ",", "\n", "       ", 
        RowBox[{"rev", " ", "=", " ", 
         RowBox[{"{", "  ", 
          RowBox[{
          "415", ",", "            ", "162", ",", "             ", "99", ",", 
           "\n", "                 ", "53", ",", "              ", "8", ",", 
           "              ", "3", ",", "\n", "                  ", "1", ",", 
           "              ", "0", ",", "              ", "0"}], "         ", 
          "}"}]}], ",", "\n", "       ", 
        RowBox[{"j2000", " ", "=", " ", "2451545.0"}], ",", " ", "t", ",", 
        " ", "aa", ",", " ", "ee", ",", " ", "ii", ",", " ", "nnode", ",", 
        " ", "llp", ",", " ", "om", ",", " ", "llam", ",", "\n", "       ", 
        "ma", ",", " ", "x", ",", " ", "y", ",", " ", "ea", ",", " ", "eca", 
        ",", " ", "p1", ",", " ", "p2", ",", " ", "p3", ",", " ", "p", ",", 
        " ", "xx", ",", " ", "yy", ",", " ", "zz"}], "}"}], ",", "\n", 
      RowBox[{
       RowBox[{"t", "     ", "=", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"jd", " ", "-", " ", "j2000"}], ")"}], "/", "36525"}]}], 
       ";", "\n", 
       RowBox[{"aa", "    ", "=", " ", 
        RowBox[{
         RowBox[{"a", "[", 
          RowBox[{"[", "id", "]"}], "]"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"\[Delta]a", "[", 
           RowBox[{"[", "id", "]"}], "]"}], "*", "t"}]}]}], ";", "\n", 
       RowBox[{"ee", "    ", "=", " ", 
        RowBox[{
         RowBox[{"e", "[", 
          RowBox[{"[", "id", "]"}], "]"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"\[Delta]e", "[", 
           RowBox[{"[", "id", "]"}], "]"}], "*", "t"}]}]}], ";", "\n", 
       RowBox[{"ii", "    ", "=", " ", 
        RowBox[{"Mod", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"i", "[", 
            RowBox[{"[", "id", "]"}], "]"}], "    ", "+", " ", 
           RowBox[{
            RowBox[{"\[Delta]i", "[", 
             RowBox[{"[", "id", "]"}], "]"}], "*", 
            RowBox[{"t", "/", "3600"}]}]}], ",", " ", "360"}], "]"}]}], ";", 
       "\n", 
       RowBox[{"nnode", " ", "=", " ", 
        RowBox[{"Mod", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"\[CapitalOmega]", "[", 
            RowBox[{"[", "id", "]"}], "]"}], " ", "+", " ", 
           RowBox[{
            RowBox[{"\[Delta]\[CapitalOmega]", "[", 
             RowBox[{"[", "id", "]"}], "]"}], "*", 
            RowBox[{"t", "/", "3600"}]}]}], ",", " ", "360"}], "]"}]}], ";", 
       "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"nnode", " ", "<", " ", "0"}], ",", " ", 
         RowBox[{"nnode", " ", "=", " ", 
          RowBox[{"nnode", " ", "+", " ", "360"}]}]}], "]"}], ";", "\n", 
       RowBox[{"llp", "   ", "=", " ", 
        RowBox[{"Mod", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"\[CurlyPi]", "[", 
            RowBox[{"[", "id", "]"}], "]"}], "   ", "+", " ", 
           RowBox[{
            RowBox[{"\[Delta]\[CurlyPi]", "[", 
             RowBox[{"[", "id", "]"}], "]"}], "*", 
            RowBox[{"t", "/", "3600"}]}]}], ",", " ", "360"}], "]"}]}], ";", 
       "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"llp", " ", "<", " ", "0"}], ",", " ", 
         RowBox[{"llp", " ", "=", " ", 
          RowBox[{"llp", " ", "+", " ", "360"}]}]}], "]"}], ";", "\n", 
       RowBox[{"\[Omega]", " ", "=", " ", 
        RowBox[{"llp", " ", "-", " ", "nnode"}]}], ";", "\n", 
       RowBox[{"llam", "  ", "=", " ", 
        RowBox[{"Mod", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Lambda]", "[", 
            RowBox[{"[", "id", "]"}], "]"}], "  ", "+", " ", "\n", 
           "            ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"\[Delta]\[Lambda]", "[", 
                RowBox[{"[", "id", "]"}], "]"}], "/", "3600"}], " ", "+", " ", 
              RowBox[{
               RowBox[{"rev", "[", 
                RowBox[{"[", "id", "]"}], "]"}], "*", "360"}]}], ")"}], "*", 
            "t"}]}], ",", " ", "360"}], "]"}]}], ";", "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"llam", " ", "<", " ", "0"}], ",", " ", 
         RowBox[{"llam", " ", "=", " ", 
          RowBox[{"llam", " ", "+", " ", "360"}]}]}], "]"}], ";", "\n", 
       RowBox[{"ma", " ", "=", " ", 
        RowBox[{"Mod", "[", 
         RowBox[{
          RowBox[{"llam", " ", "-", " ", "llp"}], ",", " ", "360"}], "]"}]}], 
       ";", "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"ma", " ", "<", " ", "0"}], ",", " ", 
         RowBox[{"ma", " ", "=", " ", 
          RowBox[{"ma", " ", "+", " ", "360"}]}]}], "]"}], ";", "\n", 
       RowBox[{"rma", " ", "=", " ", 
        RowBox[{"N", "[", 
         RowBox[{"ma", " ", "\[Degree]"}], "]"}]}], ";", "\n", 
       RowBox[{"eca", " ", "=", " ", 
        RowBox[{"ea", " ", "/.", " ", 
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"ea", " ", "-", " ", 
             RowBox[{"ee", " ", 
              RowBox[{"Sin", "[", "ea", "]"}]}]}], " ", "==", " ", "rma"}], 
           ",", " ", 
           RowBox[{"{", 
            RowBox[{"ea", ",", "rma"}], "}"}]}], "]"}]}]}], ";", "\n", 
       RowBox[{"x", "=", 
        RowBox[{"aa", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", "eca", "]"}], " ", "-", " ", "ee"}], ")"}]}]}],
        ";", " ", "\n", 
       RowBox[{"y", "=", 
        RowBox[{"aa", "*", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"1", "-", 
           RowBox[{"ee", "^", "2"}]}], "]"}], "*", 
         RowBox[{"Sin", "[", "eca", "]"}]}]}], ";", "\n", 
       RowBox[{"p1", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"\[Omega]", " ", "\[Degree]"}], "]"}], ",", "    ", 
            RowBox[{"-", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Omega]", " ", "\[Degree]"}], "]"}]}], ",", "     ", 
            "0"}], "             ", "}"}], ",", "\n", "      ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{"\[Omega]", " ", "\[Degree]"}], "]"}], ",", "     ", 
            RowBox[{"Cos", "[", 
             RowBox[{"\[Omega]", " ", "\[Degree]"}], "]"}], ",", "     ", 
            "0"}], "             ", "}"}], ",", "\n", "      ", 
          RowBox[{"{", 
           RowBox[{
           "0", ",", "                  ", "0", ",", "                  ", 
            "1"}], "             ", "}"}]}], "}"}]}], ";", "\n", 
       RowBox[{"p2", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1", ",", "                  ", "0", ",", "                  ", 
            "0"}], "             ", "}"}], ",", "\n", "      ", 
          RowBox[{"{", 
           RowBox[{"0", ",", "                  ", 
            RowBox[{"Cos", "[", 
             RowBox[{"ii", " ", "\[Degree]"}], "]"}], ",", "    ", 
            RowBox[{"-", 
             RowBox[{"Sin", "[", 
              RowBox[{"ii", " ", "\[Degree]"}], "]"}]}]}], "}"}], ",", "\n", 
          "      ", 
          RowBox[{"{", 
           RowBox[{"0", ",", "                  ", 
            RowBox[{"Sin", "[", 
             RowBox[{"ii", " ", "\[Degree]"}], "]"}], ",", "     ", 
            RowBox[{"Cos", "[", 
             RowBox[{"ii", " ", "\[Degree]"}], "]"}]}], "}"}]}], "}"}]}], ";",
        "\n", 
       RowBox[{"p3", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"nnode", " ", "\[Degree]"}], "]"}], ",", " ", 
            RowBox[{"-", 
             RowBox[{"Sin", "[", 
              RowBox[{"nnode", " ", "\[Degree]"}], "]"}]}], ",", "  ", "0"}], 
           "             ", "}"}], ",", "\n", "      ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{"nnode", " ", "\[Degree]"}], "]"}], ",", "  ", 
            RowBox[{"Cos", "[", 
             RowBox[{"nnode", " ", "\[Degree]"}], "]"}], ",", "  ", "0"}], 
           "             ", "}"}], ",", "\n", "      ", 
          RowBox[{"{", 
           RowBox[{
           "0", ",", "                  ", "0", ",", "                  ", 
            "1"}], "             ", "}"}]}], "}"}]}], ";", "\n", 
       RowBox[{"p", " ", "=", " ", 
        RowBox[{"N", "[", 
         RowBox[{"p3", ".", "p2", ".", "p1"}], "]"}]}], ";", "\n", 
       RowBox[{"p", ".", 
        RowBox[{"{", 
         RowBox[{"x", ",", " ", "y", ",", " ", "0"}], "}"}]}]}]}], "\n", 
     "]"}]}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.8889158269047527`*^9, 3.888915826907824*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"388b24a0-4c3d-4561-9097-3da0221cc470"],

Cell[TextData[{
 "Now define a function ",
 StyleBox["PlanetElements", "Input"],
 " that uses the data in Tables A.2 and A.3 to return the semi-major axis, \
eccentricity, inclination, argument of perihelion and longitude of ascending \
node for planet number ",
 StyleBox["id", "Input"],
 " at Julian date ",
 StyleBox["jd", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"08e74ed8-0797-4847-9022-fce34af1facb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlanetElements", "[", 
   RowBox[{"id_", ",", " ", "jd_"}], "]"}], " ", ":=", "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"a", " ", "=", " ", 
       RowBox[{"{", "    ", 
        RowBox[{
        "0.38709893", ",", "     ", "0.72333199", ",", "     ", "1.00000011", 
         ",", " ", "\n", "                  ", "1.52366231", ",", "     ", 
         "5.20336301", ",", "     ", "9.53707032", ",", "\n", 
         "                 ", "19.19126393", ",", "    ", "30.06896348", ",", 
         "    ", "39.48168677"}], "}"}]}], ",", "\n", "        ", 
      RowBox[{"\[Delta]a", " ", "=", " ", 
       RowBox[{"{", "    ", 
        RowBox[{"0.00000066", ",", "     ", "0.00000092", ",", "    ", 
         RowBox[{"-", "0.00000005"}], ",", "\n", "                 ", 
         RowBox[{"-", "0.00007221"}], ",", "     ", "0.00060737", ",", "    ", 
         RowBox[{"-", "0.00301530"}], ",", "\n", "                  ", 
         "0.00152025", ",", "    ", 
         RowBox[{"-", "0.00125196"}], ",", "    ", 
         RowBox[{"-", "0.00076912"}]}], "}"}]}], ",", "\n", "         ", 
      RowBox[{"e", " ", "=", " ", 
       RowBox[{"{", "    ", 
        RowBox[{
        "0.20563069", ",", "     ", "0.00677323", ",", "     ", "0.01671022", 
         ",", "\n", "                  ", "0.09341233", ",", "     ", 
         "0.04839266", ",", "     ", "0.05415060", ",", "\n", 
         "                  ", "0.04716771", ",", "     ", "0.00858587", ",", 
         "     ", "0.24880766"}], "}"}]}], ",", "\n", "        ", 
      RowBox[{"\[Delta]e", " ", "=", " ", 
       RowBox[{"{", "    ", 
        RowBox[{"0.00002527", ",", "    ", 
         RowBox[{"-", "0.00004938"}], ",", "    ", 
         RowBox[{"-", "0.00003804"}], ",", "\n", "                  ", 
         "0.00011902", ",", "    ", 
         RowBox[{"-", "0.00012880"}], ",", "    ", 
         RowBox[{"-", "0.00036762"}], ",", "\n", "                 ", 
         RowBox[{"-", "0.00019150"}], ",", "     ", "0.00002514", ",", 
         "     ", "0.00006465"}], "}"}]}], ",", "\n", "         ", 
      RowBox[{"i", " ", "=", " ", 
       RowBox[{"{", "    ", 
        RowBox[{
        "7.00487", ",", "        ", "3.39471", ",", "        ", "0.00005", 
         ",", "\n", "                  ", "1.85061", ",", "        ", 
         "1.30530", ",", "        ", "2.48446", ",", "\n", 
         "                  ", "0.76986", ",", "        ", "1.76917", ",", 
         "       ", "17.14175"}], "   ", "}"}]}], ",", "\n", "        ", 
      RowBox[{"\[Delta]i", " ", "=", " ", 
       RowBox[{"{", "  ", 
        RowBox[{
         RowBox[{"-", "23.51"}], ",", "          ", 
         RowBox[{"-", "2.86"}], ",", "         ", 
         RowBox[{"-", "46.94"}], ",", "\n", "                ", 
         RowBox[{"-", "25.47"}], ",", "          ", 
         RowBox[{"-", "4.15"}], ",", "           ", "6.11", ",", "\n", 
         "                 ", 
         RowBox[{"-", "2.09"}], ",", "          ", 
         RowBox[{"-", "3.64"}], ",", "          ", "11.07"}], "      ", 
        "}"}]}], ",", "\n", "         ", 
      RowBox[{"\[CapitalOmega]", " ", "=", " ", 
       RowBox[{"{", "   ", 
        RowBox[{"48.33167", ",", "       ", "76.68069", ",", "      ", 
         RowBox[{"-", "11.26064"}], ",", "\n", "                 ", 
         "49.57854", ",", "      ", "100.55615", ",", "      ", "113.71504", 
         ",", "\n", "                 ", "74.22988", ",", "      ", 
         "131.72169", ",", "      ", "110.30347"}], "   ", "}"}]}], ",", "\n",
       "        ", 
      RowBox[{"\[Delta]\[CapitalOmega]", " ", "=", " ", 
       RowBox[{"{", " ", 
        RowBox[{
         RowBox[{"-", "446.30"}], ",", "        ", 
         RowBox[{"-", "996.89"}], ",", "      ", 
         RowBox[{"-", "18228.25"}], ",", "\n", "              ", 
         RowBox[{"-", "1020.19"}], ",", "        ", "1217.17", ",", "       ", 
         RowBox[{"-", "1591.05"}], ",", "\n", "               ", "1681.40", 
         ",", "        ", 
         RowBox[{"-", "151.25"}], ",", "         ", 
         RowBox[{"-", "37.33"}]}], "      ", "}"}]}], ",", "\n", "         ", 
      
      RowBox[{"\[CurlyPi]", " ", "=", " ", 
       RowBox[{"{", "   ", 
        RowBox[{
        "77.45645", ",", "      ", "131.53298", ",", "      ", "102.94719", 
         ",", "\n", "                ", "336.04084", ",", "       ", 
         "14.75385", ",", "       ", "92.43194", ",", "\n", 
         "                ", "170.96424", ",", "       ", "44.97135", ",", 
         "      ", "224.06676"}], "   ", "}"}]}], ",", "\n", "        ", 
      RowBox[{"\[Delta]\[CurlyPi]", " ", "=", " ", 
       RowBox[{"{", "  ", 
        RowBox[{"573.57", ",", "        ", 
         RowBox[{"-", "108.80"}], ",", "        ", "1198.28", ",", "\n", 
         "               ", "1560.78", ",", "         ", "839.93", ",", 
         "       ", 
         RowBox[{"-", "1948.89"}], ",", "\n", "               ", "1312.56", 
         ",", "        ", 
         RowBox[{"-", "844.43"}], ",", "        ", 
         RowBox[{"-", "132.25"}]}], "      ", "}"}]}], ",", "\n", "         ", 
      RowBox[{"\[Lambda]", " ", "=", " ", 
       RowBox[{"{", "  ", 
        RowBox[{
        "252.25084", ",", "      ", "181.97973", ",", "      ", "100.46435", 
         ",", "\n", "                ", "355.45332", ",", "       ", 
         "34.40438", ",", "       ", "49.94432", ",", "\n", 
         "                ", "313.23218", ",", "      ", "304.88003", ",", 
         "      ", "238.92881"}], "   ", "}"}]}], ",", "\n", "        ", 
      RowBox[{"\[Delta]\[Lambda]", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
        "261628.29", ",", "      ", "712136.06", ",", "     ", "1293740.63", 
         ",", "\n", "              ", "217103.78", ",", "      ", "557078.35",
          ",", "      ", "513052.95", ",", "\n", "              ", 
         "246547.79", ",", "      ", "786449.21", ",", "      ", 
         "522747.90"}], "     ", "}"}]}], ",", "\n", "       ", 
      RowBox[{"rev", " ", "=", " ", 
       RowBox[{"{", "  ", 
        RowBox[{
        "415", ",", "            ", "162", ",", "             ", "99", ",", 
         "\n", "                 ", "53", ",", "              ", "8", ",", 
         "              ", "3", ",", "\n", "                  ", "1", ",", 
         "              ", "0", ",", "              ", "0"}], "         ", 
        "}"}]}], ",", "\n", "       ", 
      RowBox[{"j2000", " ", "=", " ", "2451545.0"}], ",", " ", "t", ",", " ", 
      "aa", ",", " ", "ee", ",", " ", "ii", ",", " ", "nnode", ",", " ", 
      "llp", ",", " ", "\[Omega]", ",", "om", ",", " ", "llam", ",", "\n", 
      "       ", "ma", ",", "rma", ",", " ", "x", ",", " ", "y", ",", " ", 
      "ea", ",", " ", "eca", ",", " ", "p1", ",", " ", "p2", ",", " ", "p3", 
      ",", " ", "p", ",", " ", "xx", ",", " ", "yy", ",", " ", "zz"}], "}"}], 
    ",", "\n", 
    RowBox[{
     RowBox[{"t", "     ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"jd", " ", "-", " ", "j2000"}], ")"}], "/", "36525"}]}], ";", 
     "\n", 
     RowBox[{"aa", "    ", "=", " ", 
      RowBox[{
       RowBox[{"a", "[", 
        RowBox[{"[", "id", "]"}], "]"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"\[Delta]a", "[", 
         RowBox[{"[", "id", "]"}], "]"}], "*", "t"}]}]}], ";", "\n", 
     RowBox[{"ee", "    ", "=", " ", 
      RowBox[{
       RowBox[{"e", "[", 
        RowBox[{"[", "id", "]"}], "]"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"\[Delta]e", "[", 
         RowBox[{"[", "id", "]"}], "]"}], "*", "t"}]}]}], ";", "\n", 
     RowBox[{"ii", "    ", "=", " ", 
      RowBox[{"Mod", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"i", "[", 
          RowBox[{"[", "id", "]"}], "]"}], "    ", "+", " ", 
         RowBox[{
          RowBox[{"\[Delta]i", "[", 
           RowBox[{"[", "id", "]"}], "]"}], "*", 
          RowBox[{"t", "/", "3600"}]}]}], ",", " ", "360"}], "]"}]}], ";", 
     "\n", 
     RowBox[{"nnode", " ", "=", " ", 
      RowBox[{"Mod", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"\[CapitalOmega]", "[", 
          RowBox[{"[", "id", "]"}], "]"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"\[Delta]\[CapitalOmega]", "[", 
           RowBox[{"[", "id", "]"}], "]"}], "*", 
          RowBox[{"t", "/", "3600"}]}]}], ",", " ", "360"}], "]"}]}], ";", 
     "\n", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"nnode", " ", "<", " ", "0"}], ",", " ", 
       RowBox[{"nnode", " ", "=", " ", 
        RowBox[{"nnode", " ", "+", " ", "360"}]}]}], "]"}], ";", "\n", 
     RowBox[{"llp", "   ", "=", " ", 
      RowBox[{"Mod", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"\[CurlyPi]", "[", 
          RowBox[{"[", "id", "]"}], "]"}], "   ", "+", " ", 
         RowBox[{
          RowBox[{"\[Delta]\[CurlyPi]", "[", 
           RowBox[{"[", "id", "]"}], "]"}], "*", 
          RowBox[{"t", "/", "3600"}]}]}], ",", " ", "360"}], "]"}]}], ";", 
     "\n", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"llp", " ", "<", " ", "0"}], ",", " ", 
       RowBox[{"llp", " ", "=", " ", 
        RowBox[{"llp", " ", "+", " ", "360"}]}]}], "]"}], ";", "\n", 
     RowBox[{"\[Omega]", " ", "=", " ", 
      RowBox[{"llp", " ", "-", " ", "nnode"}]}], ";", "\n", 
     RowBox[{"{", 
      RowBox[{"aa", ",", "ee", ",", "ii", ",", "\[Omega]", ",", "nnode"}], 
      "}"}]}]}], "\n", "]"}]}]], "Input",
 CellChangeTimes->{{3.888915851335369*^9, 3.888915851338623*^9}, {
  3.889264860221694*^9, 3.8892648668060293`*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"f68ca662-ed8b-4978-bff1-602abda50129"],

Cell[TextData[{
 "Now define a function ",
 StyleBox["OrbitXYZ", "Input"],
 " that returns a list of ",
 StyleBox["npts", "Input"],
 " values of ",
 StyleBox["(X,Y,Z)", "Input"],
 " around the orbit of planet ",
 StyleBox["id", "Input"],
 " at Julian date ",
 StyleBox["jd", "Input"],
 ".  Note that this function makes use of ",
 StyleBox["PlanetElements", "Input"],
 " to return the orbital elements at ",
 StyleBox["jd", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d05c996d-7459-4ae3-8619-4ae813fccd6d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OrbitXYZ", "[", 
   RowBox[{"id_", ",", " ", "jd_", ",", " ", "npts_"}], "]"}], " ", ":=", 
  "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "elem", ",", " ", "a", ",", " ", "e", ",", " ", "ii", ",", " ", 
      "\[Omega]", ",", " ", "\[CapitalOmega]", ",", " ", "p1", ",", " ", "p2",
       ",", " ", "p3", ",", " ", "p", ",", " ", "x", ",", " ", "y", ",", " ", 
      "z", ",", "\n", "        ", "f", ",", " ", "r", ",", " ", "cf", ",", 
      " ", "sf", ",", "ae"}], "}"}], ",", "\n", 
    RowBox[{
     RowBox[{"elem", " ", "=", " ", 
      RowBox[{"PlanetElements", "[", 
       RowBox[{"id", ",", " ", "jd"}], "]"}]}], ";", "\n", 
     RowBox[{"a", "   ", "=", " ", 
      RowBox[{"elem", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", 
     RowBox[{"e", "   ", "=", " ", 
      RowBox[{"elem", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", "\n", 
     RowBox[{"ii", "  ", "=", " ", 
      RowBox[{"elem", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], ";", "\n", 
     RowBox[{"\[Omega]", "   ", "=", " ", 
      RowBox[{"elem", "[", 
       RowBox[{"[", "4", "]"}], "]"}]}], ";", "\n", 
     RowBox[{"\[CapitalOmega]", "   ", "=", " ", 
      RowBox[{"elem", "[", 
       RowBox[{"[", "5", "]"}], "]"}]}], ";", "\n", 
     RowBox[{"p1", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"\[Omega]", " ", "\[Degree]"}], "]"}], ",", "    ", 
          RowBox[{"-", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Omega]", " ", "\[Degree]"}], "]"}]}], ",", "     ", 
          "0"}], "             ", "}"}], ",", "\n", "      ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"\[Omega]", " ", "\[Degree]"}], "]"}], ",", "     ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Omega]", " ", "\[Degree]"}], "]"}], ",", "     ", "0"}],
          "             ", "}"}], ",", "\n", "      ", 
        RowBox[{"{", 
         RowBox[{"0", ",", "            ", "0", ",", "            ", "1"}], 
         "             ", "}"}]}], "}"}]}], ";", "\n", 
     RowBox[{"p2", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "            ", "0", ",", "            ", "0"}], 
         "             ", "}"}], ",", "\n", "      ", 
        RowBox[{"{", 
         RowBox[{"0", ",", "            ", 
          RowBox[{"Cos", "[", 
           RowBox[{"ii", " ", "\[Degree]"}], "]"}], ",", "    ", 
          RowBox[{"-", 
           RowBox[{"Sin", "[", 
            RowBox[{"ii", " ", "\[Degree]"}], "]"}]}]}], "}"}], ",", "\n", 
        "      ", 
        RowBox[{"{", 
         RowBox[{"0", ",", "            ", 
          RowBox[{"Sin", "[", 
           RowBox[{"ii", " ", "\[Degree]"}], "]"}], ",", "     ", 
          RowBox[{"Cos", "[", 
           RowBox[{"ii", " ", "\[Degree]"}], "]"}]}], "}"}]}], "}"}]}], ";", 
     "\n", 
     RowBox[{"p3", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"\[CapitalOmega]", " ", "\[Degree]"}], "]"}], ",", "   ", 
          RowBox[{"-", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[CapitalOmega]", " ", "\[Degree]"}], "]"}]}], ",", 
          "    ", "0"}], "             ", "}"}], ",", "\n", "      ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"\[CapitalOmega]", " ", "\[Degree]"}], "]"}], ",", "    ", 
          
          RowBox[{"Cos", "[", 
           RowBox[{"\[CapitalOmega]", " ", "\[Degree]"}], "]"}], ",", "    ", 
          "0"}], "             ", "}"}], ",", "\n", "      ", 
        RowBox[{"{", 
         RowBox[{"0", ",", "           ", "0", ",", "           ", "1"}], 
         "             ", "}"}]}], "}"}]}], ";", "\n", 
     RowBox[{"p", " ", "=", " ", 
      RowBox[{"N", "[", 
       RowBox[{"p3", ".", "p2", ".", "p1"}], "]"}]}], ";", "\n", 
     RowBox[{"f", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"N", "[", "t", "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", 
          RowBox[{"2", "Pi"}], ",", 
          RowBox[{"2", 
           RowBox[{"Pi", "/", "npts"}]}]}], "}"}]}], "]"}]}], ";", "\n", 
     RowBox[{"cf", " ", "=", " ", 
      RowBox[{"Cos", "[", "f", "]"}]}], ";", "\n", 
     RowBox[{"sf", " ", "=", " ", 
      RowBox[{"Sin", "[", "f", "]"}]}], ";", "\n", 
     RowBox[{"ae", " ", "=", " ", 
      RowBox[{"a", "*", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"e", "*", "e"}]}], ")"}]}]}], ";", "\n", 
     RowBox[{"r", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"ae", "/", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"e", "*", 
             RowBox[{"Cos", "[", "#", "]"}]}]}], ")"}]}], "&"}], ",", " ", 
        "f"}], "]"}]}], ";", "\n", 
     RowBox[{"x", " ", "=", " ", 
      RowBox[{"r", "*", "cf"}]}], ";", "\n", 
     RowBox[{"y", " ", "=", " ", 
      RowBox[{"r", "*", "sf"}]}], ";", "\n", 
     RowBox[{"z", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"npts", "+", "1"}], "}"}]}], "]"}]}], ";", "\n", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"p", ".", "#"}], ")"}], "&"}], ",", " ", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}]}], "]"}]}]}], "\n", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8889158722410593`*^9, 3.8889158722441196`*^9}, {
  3.889264892049144*^9, 3.889264896594206*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"6d21460d-0123-4e60-9f21-ccbdaf51f309"],

Cell[TextData[{
 "In order to make drawings of the planetary orbits we need to be able to \
take the ",
 StyleBox["(X,Y)", "Input"],
 " coordinates from the list obtained from ",
 StyleBox["OrbitXYZ", "Input"],
 " and make them into a ",
 StyleBox["Line", "Input"],
 " of joined up points.  Hence we define a function ",
 StyleBox["OrbitXY", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"a5208f34-cbff-4da1-9fbb-0f6646570de2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"OrbitXY", "[", 
    RowBox[{"id_", ",", " ", "jd_", ",", " ", "npts_"}], "]"}], " ", ":=", 
   "\n", "  ", 
   RowBox[{"Line", "[", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"OrbitXYZ", "[", 
         RowBox[{"id", ",", " ", "jd", ",", " ", "npts"}], "]"}], "]"}], ",", 
       "2"}], "]"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.888915895743964*^9, 3.888915895747732*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"bd5b1bdd-47d3-4af7-8945-57037a25b020"],

Cell["Set the colours to be used for the two orbits.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878562591887006*^9, 3.878562613471806*^9}, {
  3.878645977794298*^9, 3.878646003488901*^9}, {3.878646081324325*^9, 
  3.878646113633102*^9}, {3.884607227808136*^9, 3.884607228482621*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2a95b0b2-a352-4075-97a7-5f59ef5ebfb5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"color1", "=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"color2", "=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.884607205132513*^9, 3.884607206710265*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"ace28e4d-4334-4e26-a75d-00e9831428cf"],

Cell[TextData[{
 "Now we can define a function ",
 StyleBox["PlotPlanets", "Input"],
 " that will draw the selected planetary orbits at the given Julian date ",
 StyleBox["jd", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"35ce9c0f-2e58-40f7-9127-35236564ad5e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlotPlanets", "[", 
   RowBox[{"idl_List", ",", " ", "jd_", ",", " ", "npts_"}], "]"}], " ", ":=",
   "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "  ", 
    RowBox[{
     RowBox[{"sun", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{"Yellow", ",", 
        RowBox[{"Sphere", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "3.0"}], "]"}]}], 
       "}"}]}], ";", "\n", "  ", 
     RowBox[{"orbits", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Line", "[", "#", "]"}], "&"}], ",", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"OrbitXYZ", "[", 
            RowBox[{"#", ",", " ", "jd", ",", " ", "npts"}], "]"}], "&"}], 
          ",", " ", "idl"}], "]"}]}], "]"}]}], ";", "\n", "  ", 
     RowBox[{"positions", " ", "=", " ", "\n", "   ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Blue", ",", 
           RowBox[{"Sphere", "[", 
            RowBox[{
             RowBox[{"PlanetXYZ", "[", 
              RowBox[{"#", ",", " ", "jd"}], "]"}], ",", "1.5"}], "]"}]}], 
          "}"}], "&"}], ",", " ", "idl"}], "]"}]}], ";", "\n", "  ", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"Graphics3D", "[", 
        RowBox[{"{", 
         RowBox[{"sun", ",", " ", "orbits", ",", " ", "positions"}], "}"}], 
        "]"}], ",", "\n", "      ", 
       RowBox[{"PlotRange", "->", "All"}], ",", 
       RowBox[{"Boxed", "->", "False"}], ",", 
       RowBox[{"ViewPoint", "->", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "20"}], "}"}]}]}], "]"}]}]}], "\n", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8889159122916727`*^9, 3.888915912294436*^9}, {
   3.88926744660424*^9, 3.889267480744162*^9}, {3.88926754905436*^9, 
   3.889267642023563*^9}, {3.889269452079822*^9, 3.889269477684841*^9}, 
   3.889338545129134*^9, {3.889338593067822*^9, 3.889338595924658*^9}, {
   3.889338677566058*^9, 3.889338755788546*^9}, 3.889338787831283*^9, {
   3.889338830297921*^9, 3.889338836968288*^9}, {3.8893390184324627`*^9, 
   3.889339020008218*^9}, {3.889339058449168*^9, 3.889339063150528*^9}, {
   3.889339093672854*^9, 3.8893391042242317`*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"21cf9018-4114-4d65-ba12-700a036b685f"],

Cell["Show Neptune and Pluto at the given Julian date.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.889424921580764*^9, 3.889424945295196*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"bd6027c6-f73a-4709-9302-8e8f95a59d2e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotPlanets", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"8", ",", "9"}], "}"}], ",", "date", ",", "200"}], "]"}]], "Input",\

 CellChangeTimes->{{3.8893383009255533`*^9, 3.889338336980695*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"504edf43-0e45-4157-943a-a52a33af7412"],

Cell[BoxData[
 Graphics3DBox[{
   {RGBColor[1, 1, 0], SphereBox[{0, 0, 0}, 3.]}, {Line3DBox[CompressedData["
1:eJxdmGk41d3Xx1WmZCaVxEnmYzjnOBycYe8oQ1JIKo23qUQ3FaVJQiqVFE2I
ihAqSUjYu0IZMhWZ5/EMKCmZ+v+u635ePS/223Xttdf3u9b67LXu/s5ei4WE
hCqJs4Q4D0rEA+XlTeAISWX4spwJNPIT8cs7KECbemM4P7zo8HFiiYRvoQnk
iO9PCXcVoBySiPnrPGN4R8RWonOXKcz89uTfP2wB+r6p6U/kAg0uWXNvZcGU
Kax/sL9itaoANXlP2cRZ0aBITWdp41UG3Ng45vnjFx/JXamUXRZBhRWNfoMS
KmZQ+Ot4WeQnPro1/nWvMqbAjAe2Hcw0M8hewlIbuMVHMxd2xw2MG8HXAz4e
VnrmUKzn1qEVrnxU/OTI+KUdhvBnQXGuUIY5fOIwusVIno/uvVkvHl6gD0/e
b7rgomYBE1fvN2V95KEDYj6zTFkyLLfaI7M2xgLqT7eZOAbx0Mfdn18ou+vC
v4V6OptmLODC980K51V4iGt4FF1+pg0xXc3w9V4mfJB7F3QVc5Hzpqr9339o
QvF7yap2RUwYkURqjHDlIjzzxu4dTQNuHqi5NybDgvGSYhFXR0fRqEDzkfcR
dbhup1f/jX0sOFS9OEvyxChy/E7vcEwhQdXSbT9WprHgYTrXWGNuBBUWebn0
Pl0DaWe5vieHWJAh1pM4fmYEpapx8vxFlGHMxKdn8WpsaOujO359ahhFDDVc
oLkpwZJ0n4bjTmz43SG7UM1nGDnvLObIPZWHpb925EydYcMfz5VEPjYPoeko
MzXuoBR0iVg2opjMhpmzz13TOUNoZC5e6uZRUXht86HOj0VsCOi1SYMPB1HL
uWNFnYJ5sD+rF4nWseE0Tdg0Y34AYSXe3cBuAfg+x7lW3c6GXa+GvihtH0BC
wXr1X28eR7OeQjLyvWyoX3Q10i29H2H38ZkEyhgacHYf+tbFhg5Lcp4++NmH
dnLb5bHyAsrfsxCu0kTEt43qXMbuQxts9+TduSqK3eXEDXs/sGGs1ub5htBe
JJy5oUEgLI2P+2gI6Wax4fgVp+WquAfFmBzwKnsrj80j23jTUWy4b9ffl5xf
3WgmpF2iIkAJ3wpOLNzhwYb5255SJD27ULbe/YZokjJ+/sV7yRY6cf88p8Ni
VR3o1yHwlFa1Bp/rmGIPzRN1DLam3NZpR+XT3Ts98kmYRr/xTB+zoN+Fsk0q
oa1o/XHbopxwdRzK2+djdIYFL0/m/SPS8A15KP6Mvr5ZAyvOe+9cMGTB1MDW
gaLVzeiX46+2SFktrAqFjLLaCf3kHJ7MOPAVle0Yydar08bHfvN87S4wIblE
34r9sBGVrfe0EL+si6sZUy5jakz4r+m86HBbPVo4fXDuhQUZa55YO5lTYAEt
tpQ+NVCvRS3Bt6tfDenj5xn+0pm2FlCYLL/iXGQVis3YNpd21RBfD9HU/dlo
DjfHTf77uL8C1WfvZt9QpGCDrZmns1zN4fdt1PGLFh9QEknt+M5uCrY+Pz4q
+GIGuX/jL65biZCz+BPX2SdUrGjuLda+yQy67VoR65FbgI4UkRU3HqLh+aAw
0bi3DEiVOlKStjEHDe4ObFuiZYzvnK7OZ2ox4Mu7j8/GpT9CztLSI6Ldxthp
6emzv6JMYfBQ0tcmbhBKmD12TzWWjnXyU225oyYwXCJlNWv/PbDLeDJAxdIE
F/NmYjhWJpD8Q6Xn5uos8N7Kx+ALzwSL75axUblLh89v2L3Zu+g1qPLPq1GK
McUfC2h1zwaNYbZYZ0xmQDHYsvdnYrEhA8fUdv9SNTKG0zyPU0P8d+C0XJhN
wkcG1jco4iYep8EF62W3jj4oB8Iyjzui3Mxw/HuSvusrKlRO8dohalcJRH14
XZ7DZvjZUtfI02MUqBe5xv/1WA3gJ+3fIvyvOW48D5YwNSkwInd8yyfresBd
ZfRq45g5Zrw8i2JfGMJ1loNh2+UbwRY9LR2xQxZ4wxqbv3mSBpDFCsy91voF
tPqWeuq0W+AzG8LfW7qT4djVGt0/CU1gW3h9RZQNE7+VZq/NyNGFYdoB67V3
fQM/6H275Z4x8feRGLrztDbUObX+XKpsK0jol+Q+XMbC57kPZ1+Ya8G2TP+s
v+/aQEhC8LSaBwsXZbQDWpAGjFrOWFLp1wHMew5+O/GKhd/DhGD7LHV4ZtLX
6pZsFzgWXZ9+Y46FXULWPffvIMEMt/L6sexukMMMcXflsLFhrWShjrwq5JmM
j7552ANeJxZ1FQazsUqC4MkBD2VIqjxK7vDuBYbxwS1pWWxc/20t/eQzJXi3
PuBlpk4faOpamJL7xsbipZbJ+77LQxd7V+nJwT5QWCv9WTDDxmafazSVDkhD
4f6nE+FJ/SD4b8Sw0QoODl1V2DjwVRTa35ekGjgPgDfHAz7WkTmY8tQv0yhy
AST+nOhGQoOAKp7ErTDj4J6Y8m2huWOAkSixTTpzEATk3P4sy+FgIb9ov80B
4SBjTwCN7zAEApzFxjKZHEyyWvRTSnkMiSb6XjTkD4F4qyc1cVQOLuxw+HmN
s4C+uEyUZkUMg4zkw2N1ahwcsLEuuT9PFO95X1jJXDECrEbtO/eLcvAIWdvA
e6M0zv77V6EwZQREP3DU2TTIxo7qLspHhuUxY7I5flZ3FOglK3rcKWbj0uiU
W2npSjhvQXqq7+kouHU/R2PLNTaOqO3SPeiujBcvzd+7eR0XrCkWFz3nwsYs
au+7AiVVfCFBrXTFHS6YPnwhmbKcjVtugD0NvSR8c+JEgdZiHugqWxUZXMvC
MToDy5Xz1PHAn6asPQd5gL+Gb+MdysKgZ0615IIGfn6jsyKpnAdcGxQPSZFZ
uKAmPNtykxZO0a4W+arCBwYyQm7htUxsm/bFjC6lgz88FgeDfnxw7Lra2e7D
TOyyuDdVpUoXx03SdEte80GazVJ5phATnx1YvetyKBlfi437x/Y3H9CLhDgv
oy2wWrfAS4RigC2nZI8FUQWgYxP/zz4lC6yhUJmyrsUQd7uFNNM9BeBzfaGM
x11zfAns87FgUXBbru+iUzcE4M1RA7kuOXMsu+rdHmtxKn7g5njA9JUAMO1o
W39cNMN6CguPhOqp+P3Auv0edQIgefNa/YdJBr7jFuVoEkvDyuv3+E73C8As
W8E2eDcDc3mzL146GePSQcdf4xMCsHjDfglGiSk2cnSw3rCMjgvbFp20/kXE
GZ9ZrLvKFPs5fRgsRnQc/nm978ykAJCnFZ4G+5vgD+n+Rfx/TfB4nOVOSS4R
h5E36YTpuKbSfkfaSlOs/SW8KqRFAFgiFx36iLhGpsPvS4pNcUX6uu2uSEDo
ZO3lnc7GOP5targ4cS/9pzdj7icJQNXEXO0Ace9TQWFZe4k8Kh+mrnQ6IQAD
8d33C4k8LQ4e6r9N5F1epRB1yVoA5msWJ4supWKz5j9BV4l3Ij9wOW8nIwBn
yZ/LFrMp2LJocJcy8a7W+7quPanng6ErR7TKWg1xeXMuk0TUYZliEys7ig/c
vubavaYaYO9NwpfOEnUbuLtGIoDNB5rJXkY2YWTs+HCbvyxRZ3pbh5vIKA9c
nGHOjlbr4q7sNdOlhC68kj1Ph13nAcldCvdlZHRwHzo/50foKI4dc+uvHg8o
xvQlkjdr4bFflqaLCN21qcSl3nnHBUrPWOqvwjXwYPG2DZ6ETl9OWV7wcOKC
E44BWSr56nhxeUpOKKHrrr/VOLxtFBRv2yrU00/CLopBU5aED66cmnqjtHcU
aJG3r+Irq+JsgWTYfcI3zqRvwezWEaCfuPrcS29lXFX4uTSQ8NlT75WvlbeO
gJj06E8i2Ur4ACiQ/Uj4sn9P/sfG0mFQ6HNDsYcnj8s6N3dEED52Cdj+8KrO
MAheEudxdIs0bo7svZRK+P7dpnVFfteGgBnd9JNcqSheeGt3TpXEwbvXO8gm
cwcBxfbFST2nBdTXNqknIPrK4kEZeQerQfCwoLXjHRhDkv8cFJZicbCEp+ed
x3cGgFDG8roldcdBlrB+2Fmib2VEOdbVDPQDKBSV+vvqGLhcsmoty5yIb9PF
mjHoB47C906XHFsALYoK/2zR52CbFyjZ7VgfKPviYbeiWhQ22JM/FBB99HtM
Kk81txf4xSdkmrpKw2CSxceQWTYOeWVtfkrQA5rLEvQO8uVhhUH3SBbRp48I
qIWJGj2AliC3+VSGEuxZ8TvBLpuNP0bHwzMvukD0kSs39u5ThrShCFvPU2yc
Vu1irS7dCfTYF9+slVKFX1XkrSUAG5O+w6J4r3ZQ427XxW0lwTzny8328yxs
2OV/zTm/FXSWd82WZ6jDJv1LJGYeC0fsa9n4RqgFXOhfeJN9TAPG1Zrr8ok5
liJ5cxRsbAYHCu1kyQxizk0+/xwoycLCEtVNOyO+guwS1Uu1U9qQJFXwlk/M
yRutd1NPljYCrZ9JLlrPdaF+k/3hI7ZMrBcTISn3sx5Er5A+9WE/GXpNRcjJ
d1hgvx6dMBP7WnBa4VqbmYQBnDi05vFvYm5HfrBLU0qvAkFU0oHVzwyhtPf1
Yta4OdbRuKKeN1cBQvhioos0KPB0VnH6In9zrJIvXT+/+QNQjy6RsBIQ+8Fa
J5tDI2bY9PKFpZVUBOKaE0PX5lKha90DubjdZrgx1zDj1fsCYJz4Z4/vMRoc
p5qKZH5i4IVK+DB5Sw7gWBZ8mTAwhkLSekn1Rgzs17KK3P/8EZi7csU9fMAY
LnQKqoxumuL6D96CvokgEJBX0z51mw51hH/2TPBNcOOzz/fuu99DO//br2DJ
f/sVVv5vv0I92y8V14yYwEU2iu0b4ui44uyJlJMLeWjoKqruvGIK1e74LKb2
GGNN862JjYeKUbtoqraOJgMOkN6HUrWNca/fE72QwXfIOKus82IRA166XPsn
yIeGXR1Wyly/WY6oASGXG+3M4GMZjqFROhWPe7vYZjIqUWZgnSuv0Qx2PH80
Ft1DwYoWRYv4zTVotdkbhRfbzWHHorXSn5ZT8K0f8xwTRj3Kv04xWGgwh22r
JDJVog1xpFyo9sOFBvRbOKGoyMYCdiaYD+mP6uPtXF/rje++oJC01rBP+Raw
dmahn8wm46Y3nRfzQprQhGjvIilizw5MP7AlMkoXn6SE2543/YZojV1H/EOZ
MEV/6+bMBm3cujE23GykBb2TFbxtaWPC9cwrnmIKWtimlNkSGNuGVCK3pRoT
e7/J4M5/pLdqYCdyaHYVowPNpexI8zvNgrdVqHRqpDouDYy0avzaicrSE5Yd
Qyyo7U5r7SskYR9zhybNw92IFyPFMyY4ZLrSIsiwbg3usR9ozDnTgxpfe5NT
jdkw0iVQJ1JTGScsfyklz+lFrEbWxXx3NuxxCHxWEKSE1Z74cUXnetHNkCcR
BwguUlRgKL3A8ljYC3YfeN2HTOWORN3PZMNgua0tudLSmN3vG/vDpx8ZzvXW
uBHcFTipMmZ7WxTr3GSP3lg1gKI+mexM/sqGGS+TZGcMFtDBr/li0mUDqKor
UNqT4Dq8kuP70nUMHQ5q87DyGUTFO5TS03vYUAhaza6nhyOFm6mVYkuH0BUV
zeeHCW50XEErMCsSgEjbLE96yhBqfrIk/EUtG346zTU61z4PjEMPfkphDKOi
3GrX0wSXahS0VFw4JAolFTSnqRXDaMjVXq8hiQ0pa5crL3RIQdfv9/8t3jKC
WsofVr8luLfMSXTmWao8FOSt01RvGEEuG098sSI4mRLNVujfrgS3b8iKt3IY
RSmvux8FElwdFiZuZLJIGTYbGLYt/jCKGkntbrsJDo+PulBR/GQNfH5UEGpF
4yLVsqA+UYLbxV6pLd/0iAT3nV9fxo3nImvxuy2XCM53IbHbfX3V4VMThZPd
c1yU0HksbkKGBcOWblryhaIBW9EfaYmdPMSfSFXbXsSE/bELCrLfNaEFfT7D
JZuH9hv8olTvZcKeQdOhvCxtWNQzL5X1h4csFj5rHZ6xgLspBSUuB3RhmTnO
nwF85PjecZF9jAW0T4r9J0KaDJO8H9TRzvORSY/+nstqFjBqyoze9lof2vm1
MDcU8FHhyIpDnAxzmPJJ3n5suyFUn797b+0IH8XS5vuj9MzhIb2ai25jRtDv
dwRAcgL0bUf38utpZnDXZKzzXkSB6x9J2SnQBUhk9sgHLxUzeCMjn+IaToW1
uQ7Ry7cKkDXDSY9xjQEPehrjYUsaLLJMyETuAmS7Rn9a45cpbLl2cqpvngaN
MgvnJP0FKCFhh6WLmymsPCnSuyrPGPadzEqfOS5AKyk7zvEKTeDjqvI3+73o
MCbKLPbSUQFK+r//q+H/93/1P77bSiI=
     "]], Line3DBox[CompressedData["
1:eJxdeGk0FYz39TVHyDzTveYpwzVcrjscw1WZMpVKT4VCRUqZooyZSjyG6DFU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     "]]}, {
    {RGBColor[0, 0, 1], 
     SphereBox[{6.018673911707433, -29.6007081488021, 0.46980980066264977`}, 
      1.5]}, 
    {RGBColor[0, 0, 1], 
     SphereBox[{-20.267394500921334`, -20.11523901824606, 8.015589193357108}, 
      1.5]}}},
  Boxed->False,
  PlotRange->All,
  ViewPoint->{0, 0, 20}]], "Output",
 CellChangeTimes->{
  3.889338338144761*^9, 3.889338549703702*^9, 3.889338599196747*^9, {
   3.889338697579227*^9, 3.889338759124151*^9}, {3.889338815443733*^9, 
   3.889338840265098*^9}, 3.8893390231173487`*^9, 3.889339067097302*^9, 
   3.889339107491561*^9, 3.889419812096203*^9, 3.889427729202016*^9, 
   3.891017628086576*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"b725b66b-7703-47f3-9f4c-ebac15da4972"]
}, Open  ]],

Cell[TextData[{
 "Finally we define a function ",
 StyleBox["PlotNeptunePluto", "Input"],
 " that uses the previous functions to plot the orbits of Neptune and Pluto \
at the specified date."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0591ee4e-3327-4b75-bf04-035f1a306d57"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlotNeptunePluto", "[", 
   RowBox[{"jd_", ",", " ", "npts_"}], "]"}], " ", ":=", "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"outer", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{"8", ",", "9"}], "}"}]}], "}"}], ",", "\n", "  ", 
    RowBox[{
     RowBox[{"sun", " ", "=", 
      RowBox[{"{", 
       RowBox[{"Yellow", ",", 
        RowBox[{"Sphere", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "3.0"}], "]"}]}], 
       "}"}]}], ";", "\n", "    ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"nepdata", ",", "pludata"}], "}"}], " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"OrbitXYZ", "[", 
          RowBox[{"#", ",", " ", "jd", ",", " ", "npts"}], "]"}], "&"}], ",", 
        " ", "outer"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"pludata1", "=", 
      RowBox[{"Select", "[", 
       RowBox[{"pludata", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "<", "0"}], ")"}], "&"}]}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"pludata2", "=", 
      RowBox[{"Select", "[", 
       RowBox[{"pludata", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "3", "]"}], "]"}], ">=", "0"}], ")"}], "&"}]}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"temp", "=", 
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"Partition", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Transpose", "[", "pludata2", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", "2", ",", "1"}], "]"}], ",", 
         
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Abs", "[", 
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}], ">", "10"}], "&&", 
            RowBox[{
             RowBox[{"Sign", "[", 
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "*", 
               RowBox[{"#", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "==", 
             RowBox[{"-", "1"}]}]}], ")"}], "&"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"postemp", "=", 
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Transpose", "[", "pludata2", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", "temp"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"pludata2a", "=", 
      RowBox[{"Take", "[", 
       RowBox[{"pludata2", ",", "postemp"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"pludata2b", "=", 
      RowBox[{"Take", "[", 
       RowBox[{"pludata2", ",", 
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Length", "[", "pludata2", "]"}], "-", "postemp"}], 
          ")"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"pludata2new", "=", 
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{"Join", "[", 
          RowBox[{"{", 
           RowBox[{"pludata2b", ",", "pludata2a"}], "}"}], "]"}], "]"}], ",", 
        "3"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"pluorbit1", "=", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", "color2", ",", 
        RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
        RowBox[{"Line", "[", "pludata1", "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"pluorbit2", "=", 
      RowBox[{"{", 
       RowBox[{"color2", ",", 
        RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
        RowBox[{"Line", "[", "pludata2new", "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"plunode", "=", 
      RowBox[{"{", 
       RowBox[{"color2", ",", 
        RowBox[{"Thickness", "[", "0.002", "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"First", "[", "pludata1", "]"}], ",", 
           RowBox[{"Last", "[", "pludata1", "]"}]}], "}"}], "]"}]}], "}"}]}], 
     ";", 
     RowBox[{"nepdata1", "=", 
      RowBox[{"Select", "[", 
       RowBox[{"nepdata", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "<", "0"}], ")"}], "&"}]}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"nepdata2", "=", 
      RowBox[{"Select", "[", 
       RowBox[{"nepdata", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "3", "]"}], "]"}], ">=", "0"}], ")"}], "&"}]}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"temp", "=", 
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"Partition", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Transpose", "[", "nepdata1", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", "2", ",", "1"}], "]"}], ",", 
         
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Abs", "[", 
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}], ">", "10"}], "&&", 
            RowBox[{
             RowBox[{"Sign", "[", 
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "*", 
               RowBox[{"#", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "==", 
             RowBox[{"-", "1"}]}]}], ")"}], "&"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"postemp", "=", 
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Transpose", "[", "nepdata1", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", "temp"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"nepdata1a", "=", 
      RowBox[{"Take", "[", 
       RowBox[{"nepdata1", ",", "postemp"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"nepdata1b", "=", 
      RowBox[{"Take", "[", 
       RowBox[{"nepdata1", ",", 
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Length", "[", "nepdata1", "]"}], "-", "postemp"}], 
          ")"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"nepdata1new", "=", 
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{"Join", "[", 
          RowBox[{"{", 
           RowBox[{"nepdata1b", ",", "nepdata1a"}], "}"}], "]"}], "]"}], ",", 
        "3"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"neporbit1", "=", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", "color1", ",", 
        RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
        RowBox[{"Line", "[", "nepdata1new", "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"neporbit2", "=", 
      RowBox[{"{", 
       RowBox[{"color1", ",", 
        RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
        RowBox[{"Line", "[", "nepdata2", "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"nepnode", "=", 
      RowBox[{"{", 
       RowBox[{"color1", ",", 
        RowBox[{"Thickness", "[", "0.002", "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"First", "[", "nepdata2", "]"}], ",", 
           RowBox[{"Last", "[", "nepdata2", "]"}]}], "}"}], "]"}]}], "}"}]}], 
     ";", 
     RowBox[{"neppos", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Sphere", "[", 
         RowBox[{
          RowBox[{"PlanetXYZ", "[", 
           RowBox[{"8", ",", " ", "jd"}], "]"}], ",", "1.0"}], "]"}]}], 
       "}"}]}], ";", 
     RowBox[{"plupos", "=", 
      RowBox[{"{", 
       RowBox[{"White", ",", 
        RowBox[{"Sphere", "[", 
         RowBox[{
          RowBox[{"PlanetXYZ", "[", 
           RowBox[{"9", ",", " ", "jd"}], "]"}], ",", "0.7"}], "]"}]}], 
       "}"}]}], ";", "\n", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"Graphics3D", "[", 
        RowBox[{"{", 
         RowBox[{
         "sun", ",", "neppos", ",", "plupos", ",", "neporbit1", ",", 
          "neporbit2", ",", "plunode", ",", "nepnode", ",", "pluorbit1", ",", 
          "pluorbit2"}], "}"}], "]"}], ",", 
       RowBox[{"SphericalRegion", "->", "True"}], ",", 
       RowBox[{"PlotRange", "->", "All"}], ",", 
       RowBox[{"Boxed", "->", "False"}]}], "]"}]}]}], "\n", "]"}]}]], "Input",\

 CellChangeTimes->{{3.888915927049152*^9, 3.88891592705191*^9}, {
   3.8892695025662603`*^9, 3.889269514083967*^9}, {3.889269553758781*^9, 
   3.889269563048379*^9}, {3.889269657100327*^9, 3.889269658298606*^9}, {
   3.8893393747098703`*^9, 3.889339464767872*^9}, {3.8893396954511843`*^9, 
   3.889339833118832*^9}, {3.889339873050252*^9, 3.88933998388767*^9}, {
   3.8893409404718323`*^9, 3.889341005767799*^9}, {3.889341662940419*^9, 
   3.8893418367200413`*^9}, {3.889341985897085*^9, 3.889341991419407*^9}, {
   3.8893433017383738`*^9, 3.8893433852425537`*^9}, {3.889343498216282*^9, 
   3.889343551676321*^9}, {3.889343588893499*^9, 3.889343687735443*^9}, {
   3.889343735088416*^9, 3.889343753942429*^9}, {3.889343808191983*^9, 
   3.889343858895844*^9}, {3.8893440148223343`*^9, 3.889344021543985*^9}, 
   3.889344174177243*^9, {3.88934422360082*^9, 3.889344266813236*^9}, {
   3.8893447728414173`*^9, 3.8893447856761017`*^9}, {3.889344822428817*^9, 
   3.889344830659754*^9}, 3.889346926290668*^9, {3.88934696847751*^9, 
   3.8893470282114887`*^9}, {3.88934706096029*^9, 3.889347079197987*^9}, {
   3.889347137665887*^9, 3.889347141512774*^9}, {3.8893476965028048`*^9, 
   3.889347713149704*^9}, {3.889347859335318*^9, 3.889347859927601*^9}, {
   3.889347932255546*^9, 3.889347935954279*^9}, {3.889347990293874*^9, 
   3.889347999403528*^9}, {3.88934845797578*^9, 3.889348473206077*^9}, {
   3.8893488600041313`*^9, 3.8893488670774593`*^9}, {3.889349219608797*^9, 
   3.88934922234067*^9}, {3.889349272627071*^9, 3.889349296845769*^9}, {
   3.889349349868326*^9, 3.889349357842453*^9}, {3.8894224766446*^9, 
   3.889422503978978*^9}, {3.889422618244766*^9, 3.8894226368744173`*^9}, 
   3.8894226720951443`*^9, {3.889423429364764*^9, 3.889423433378778*^9}, {
   3.889423486136492*^9, 3.889423498839417*^9}, {3.88942353578885*^9, 
   3.8894235404358683`*^9}, {3.8894236108604717`*^9, 3.889423618043991*^9}, {
   3.889423677819064*^9, 3.889423702704358*^9}, {3.889423783419477*^9, 
   3.889423911203642*^9}, {3.889424088808834*^9, 3.8894242967592983`*^9}, {
   3.889424334531138*^9, 3.889424352823928*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"440a53e5-37e5-4aad-8b4e-46218272edb6"],

Cell["Now produce the basic plot using 1000 points per orbit.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.889424961584906*^9, 3.889424998514917*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"883787f3-cdd6-4b46-824f-abc770631d33"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nepplu", "=", " ", 
  RowBox[{"PlotNeptunePluto", "[", 
   RowBox[{"date", ",", " ", "1000"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.889422567828044*^9, 3.88942258419308*^9}, {
  3.88942413977179*^9, 3.889424144316111*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"471265d3-11b5-43b3-bb0f-394197914ce0"],

Cell[BoxData[
 Graphics3DBox[{
   {RGBColor[1, 1, 0], SphereBox[{0, 0, 0}, 3.]}, 
   {RGBColor[0, 0, 1], 
    SphereBox[{6.018673911707433, -29.6007081488021, 0.46980980066264977`}, 
     1.]}, 
   {GrayLevel[1], 
    SphereBox[{-20.267394500921334`, -20.11523901824606, 8.015589193357108}, 
     0.7]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005], 
    Dashing[{Small, Small}], Line3DBox[CompressedData["
1:eJxdeXk01d/3vilUkrmSzPN4XfN1LzuphJKiASGZh6gU70gikibNCMkcKiRT
cg5JQoXIPM/XvaRQmfq+Pmv9/vr9Za29Xms7Z59nP8O6Ui7+h9zYWFhYFlhZ
WNiJv7cGz/P7cGvD8GYtsfoAXcwyZWqb4G6M6i7lTO5Q1Yb10XlUhYO6uP57
qhF3338IOL/femKlDSE/DCP3a+hiGyOPhyeGYlBDkmn2yFltGLS23WvIq4vL
an0kWrzuoYDipp6Fh9qgyDE/+IOhg5tffI5PcIlHpwa7WlvKiD6VKTmnG3Ww
RS9n7R+7FPRfmo92UI82vL3l9rv4uQ5efnwg3l8pDQXriTwfW9UGefqgfO01
HTx+2KJMXC4TrXNh7xaT1IHKdNLdJDcdvPfOQZ4IyRx0TOtXgJiJDrybXooz
2qWDRX+KDd7dnofCWqlbR0/pwNhBnyu5kjo4PIcevkfkJYrf+fXiuSgdaKzU
rBpc1ca3bleLW8YUIBMpsmlDlg5QA66kD3Vr47M2Sq+N1xUh17PRkpMfdcB2
bfPtF6Xa2Ee8Sn7pyms0aHutsmlSB1j3CvWYPtDGdaEX0oPWihFqiP0QtF4X
eAJ2T2YHaOO0IT2b4osliOIdMTWppAs5fV2CHZbaOOzkoGv+YinaKb3yXcJc
F9KVoitbFYk+Zw6yOZwtR51MaZqYty4sbgvd+YRDG9cnB9ohZgUav4Ea+67r
gsQjLzbNQS0sZ2CV1OpZiTZrG2i5PteFr0+CnB681cI8G9j+3B15hx7veyT7
ql4XEsn7yj880sJKzI6UvycQKuW5ZF01oQtpjksBH85o4UlK9hCbL0Yf92n7
3uXUg0wBicn7llpYueaOZZdiNerhzFBQlNODUcmacE0FLTzkm6kcNlaN9DWO
6EXs0oNwFdfkFFYtnN28+fHssxpkQguyenpSDzLuL6X29JDxzeW0FyqO75Hu
8HfZy5f1wNRzZmbyDRnrk0djSaK16GT+pK9Ush68Orx9uu4OGYfl81qutNci
rbzavqgKPbgW8+XveS8yPrJ/6+Zbdz+gm/yK6vkdesD58sPlRRMyPn205Oeg
ZR2y/X5e+MG8Hqg3qg2biZGxm4SLyCLXRzRxqNSCxq8PyZpp0X4Lmrih7ERi
Q81H9HMg6Xq2mj7QPFS+uX7RxCeelT11uFSPNAPCYlr36UPaZiN1jWxNPOtu
Y5ar9wlFKzmwVbnpg3Fb+VrTZU3sajFVUjj3Cf1d7i/0uqIPDpaTeUbHNDGM
bNh8Jq8B8egdP9SepA8/RkKSr5I0sVaR6vlx10YksuPjU5YyfdhWc9vwKbcm
rqrJ4uUTb0K5gV+PTLfqQ+/LZzO3B0lYiFLByvjehOy21mo/ZOoD559ECZsy
Ej4w9fB88J3PyPRq2u9VLgP4bPtBb/YOCf/ptLv3eu8XpOgi5CgnbQAnv3xJ
dfYg4apWyStP/n1ByoIBChupBnAg4WNtjhEJS40t+aiXfkVi+uWCr2wNoJdV
irdemITv/Vw10tFrRnF6z0b4/A0g/N6xr5e6NPCW88lzWfeakV3NtWOkGANI
3qz13/ZrGvjriI/rNLOZ2IsQ7U3PDEBAjPnDS1sDm+PLL1n3taCmSgNKdrkB
XL1uz+s9pI4zHIInJtNbUMktktpaiwF0b9uQK3ZbHUfzhyukrrWghexLLfx0
A5ikGSRHUNSx8tkD1+SPt6L0l7PTQ6wUiGntqU4aV8NVYcqSIa9b0YMrnCan
t1EguO/BT597arj9G2Nj8qZvKKf4V0IJiQIuZm82zNHU8ItOVrcbHt/Qb44n
FRV7KdD/xGBcdUoV29B99uyu/oY8mu75XHSkQGLZx5OSD1RxctSHxk+ibUjw
nOz5hUAKRMbl2zUZqeIxv138WwPbkNiAZarKDQqQ+rteak6p4KzWEi2Nz23I
fbiyROwZBUR6R6jW91XwjrN3DvLKt6OwrK6I+hIKfFlaG1GhqeD28r6o4rB2
hETefVVvooDgo9XImnFl7D9m81Oyox15mOl6WQ0R3z/fvyocp4zdRPe/OaTx
Hf0b/LRdeZECp6MWSQoGytgh4sOM2bXvqOBiUXHVBkMIvvyI5feQEj7q4o7Y
Br6jH5xDrJskDCEw2/lAdKwSDiJFml3W7UACGqstQlqGIBAsutpOVsIPssTy
393qQDtfu8237zGEoWvbfox3K2Kbb8M870Y7kPNHksFBO0NoN9i5sSJCER9R
1LsdatiJtp5WPRPpZwhGfixaB5UVMX+0us3y3U5Ebu338w83hAxVK8vcFgXc
uft+pP5kJ+pPjmYVum8I/Q751E/BCrgMJnZqGXUh44Pb/wVkGkKu93b6CwkF
jNvc3tDvd6H1d/dToksN4fsfKcPjdfKYc2LdOsepLuQace3a4U+GkH/zg0iT
rzx2Gg05dtOoG1XzMd92dhvCTsPrrlyC8nhvlWFn4P1utAIOL4QZhrDR1oeH
p1wOF45ffCEy2Y1SQv3IG1YNYZvAyGK3oxx2MCOznaH2IL3ec9Ilm6gwRu3n
Oc8hh8NpkqyRcT1o3P+S7TZxKnzqq9LreS6LaZEN7RajPUgs+nCGljoVdMaO
neS1ksXWKuH5DXq9yPPHxUkOIypwf589t3leBqNY+6K12F4UuEd75eZ+KuT5
a9sNxMtgHnlT4Ym+XmSqEFrR6EAFh6Mm/8JoMtjlyQ/2SFIfCgve+A/7UGGx
OvnA7JA0vnB98kVLRB9aSz+a5XuRCg/FNLU1o6VxVWD0rta2PuT07d6tLzFU
mHljnrRbWRpLPv+7ECnfj9iU8++NP6JClHviObUvUlhe1Oz3WFA/mlmxelCc
QYWnBhrZU2ekcKTxwYu/6/vRtvWTZ/SLqKApfF42RFgKb/rRUFS6bQDVZj/Z
eBZRQcGF3DVcJom9DPa3y3kPIA7WgyYnm6hQVBz1WspBEtN0zLfsrBhAcdSc
3+u6qBAzUbfrzJoEljgde5Rj3SBKKVjH6zxGhTY2BXlrUwlMp/+Yeqc6iMQ3
x3j6z1FBu/YEY/S6OGZNH+23tBlEjLhN01qrxBw+Uc6rf92BhyxGWwtCBlGI
hNbFF9w0ID2ST9UQ2oG/SQ+7TKUNotOhNss9gjQ4MLBjP/2YGL7w1VR18dMg
euJx0waJ06C4P9/BOXk7PrZ7sun7j0Ek877Y96gSDQpS6a/uD4lilgzxkdgt
Q6j1jbtKhhYNom0CFaPlRPET4cJNAkZDKL1xKTiTRoPUJ545Bl7bcFT+4LSP
6xC6I3TdyH4vDXy7XQQK8rdisrHHjvjYIfRg55Tbh4M0aLp2Yd/07BYssivY
5FHBEOpFRV0jx2mQE6asySRvwe8zq5fdvg8hais1qsSFBoP7A1+UnhfBEpm+
dM6VITSSk2JD86FBaOzrNMsyYdyZKV4QLDWMjIJeaQefo4G35IuFF0tC+DP3
0kzFnmEkE8Mp6BFCg5TM6Bt9VCFct5ay77PPMNI7uNy3PpIGSXnV+/rCBLGK
veqpV3HD6G5Y5lXnWBoICeqJvMICmMMNBpzfDKOkjX2L3ndpUO8k0GHDJoCr
sv6eHOoaRiZ7KHJK8TRY2vj5bPMufpxS+fsOaW0YmQ0Isz5JoYFov1KzTBQf
firlwHtAegSx/IoJxRnEfS865z+7uRmTlhsiDPaMIF1+v9iEXBoE81t1FvHy
YtqIz/2fXiPIYZeDuHwBDZy7ZX+FxfFgxUL6ePCtEcTOX6jq/oYGPKE2TesF
NmK2ncGyTQUjKCkiOvd4BQ0goVjr6P31uNCg8df0txEUJl12iwXRQPHqhb/e
Qtz4covkasfiCFJfGWqye0+DwF9iM2YPObHiXdrUnW2jaC3B2cnzIw16S84O
zwuvw93Cp08KUkcRncWaptRIgx8BV7LPPmLHh1uubXZxHEWtuXFOyV9o4GoV
w1snwoY5Pk0lh4SPIkbYO1TbQoPa+p+TPx+x4DOHL5U6pY2i2HqdY0/biDkU
pvAtqa0hj7YSLt7aUWSqulVWrYMG3FE3Q5vVllFM0CNK9NgoOvBkl8TpLhoc
TJMsD1D7gzKnclY+co6h3buP7nHpocFWwx6vYdUFdJePe7lVYQwpxBQ9Wt9H
nDNPn6ym+hMdqbYfyTIbQw39gbyu/TTAW418Co/MIO/z3ad2eY2hkM+X8s8M
0CDg4WP1LptJNLu6TyXn+hgS/ewbQB4kvo+NmB88NIzYdFmm2p6PoTPaz+yy
iLrzhxaOgmedSPb1iOWnT2NoRoLi+/l/389+O6dr+AmlBPpyRU2NocqjItnZ
RJ0Fdi3v1I5EgnczPnGtH0fy2m2bdIh6+K8PEwZtdcYTw4q7rRXHkUt4S/p5
4jypAmoHIv06jPlfK6me3DuOKuxV/LyI86e27TI2KBsyPuPio6nnPo44tlWd
5iPuG+5XyO5ePmE8yL+X+9vVcRQjJvfSm5gPaQu5VL+CaRxllueqnT6OTMoq
NIOJedZ3qGy27psz5kgQW7arHkehnPEsBsT8j1U2Xt7XN288Y1oSvmdgHLXW
PJB+QbwXN7mUf633t/Fqv3Le4so4ypLam9pGvG/wMxNlj94l46TpWpKP6AT6
nske+YrAQ/1FusalnlVjrXCP+nS9CbQ239tGI/Aj9Iy8W8yPBb4N3lZKtZlA
bLnpqZcJvNU32LWYMVjBV8yax/nMBNoqPz4XSOCzdkvKGfBhh5JsR6WRWxNI
zflH2w4Cz2Izo/b/pjjAaZGNopQ7gSqKGo9cJPAvW9pZd8WTE3gE5f5o1k2g
P9lGUbHEviS1Mqbej3PBbR0z8dWhCZRU23T6ALFfV697rFa7roe/R296xK5O
oKmDJdJ1xD4W//WmBA9vAPqnl3e6tk4ibck/BXPE/vayrHUPO/FAcs2Gw3St
STR+xEK5hdh3RSlh0bXeTWA7l3C68sAk6lWXS3Ul+OGYyxOtuuObwYFn4amV
1yQ6WFEim0/wiWI8rWi7Dx+kONpkpkdOIvlMRkM2wT/RCYcX5JX4If5wHK0s
eRJlzZ/OOkrwVdq9u2zsE/ywgU1a8VbpJOr8kNr4luA3bM259CJDAJjFMnLS
LZOIb0OqVRvBh66r1ityLoKgfM564QJ9Epma7DZ7RvBnQFCuspeEEKRErbe7
wT6FbuvLNEmfogEbHsg63ysE7cuWwk5iU8i3LPrnMTti/jbO9/clCIOcBp6a
055CNrsvfNtlTeDqNk1wxFYEbE3zEnftn0K1XwuvjRD8772sYQ4CW6A5b2n6
sNsUWvMsUtQ3okFcxRMHpy9b4ESqcZr0pSnEuvC8eac2DVa+PvA3it0KezMK
Il49mELUnohEFmUa1Pw3ktOzexsIryodXsqbQulvBp4FStAgIoJbQ4dVFL6r
qXezvZ9Cdmui7ClCNPh5Z6fSvkpRqPIf76/vmkLdb/f0hK6nwUzALSQctB1u
KckoWf6YQikqqmb8a1QgeRSIJmiKgZybw5WbnHTk4mPhaf+TqAfou7ZMi8Hv
XUUF18XoqFWyx85+nAqJsVfqKjN3wMszzPBdZDoalKg35u+mwoa/5b7HncTh
3MPLleV76ejx5jd6lz5TISxyPCJzqwR0VEeqMxzoKHjT0qmnmAqBxeM6T1sk
YH64Kq37DB25WmWMB72mQnps5XHp3ZLgqpI6djWajsRrzw9zZlGB67WEsPkz
SXC8vLOWnkhHx4pGL1rGU+GM99Do7lVJeNvvwcPzio4OHdneZhZLBaWt1CGh
41Ig+Tny5mQNHXGE/RZYCaHCbZ5h6ZJiKRgpKxQM/05HozIbTrj7UWH58b8a
RT5psHeuONM6RUd7uB93XnOkgo0krcfHRxqe6wgGDazQkcm+B/nOVlQo0amO
CquTBtnq/vmszdMI/j5nmTOmwrpMcp+TlAyIsjErFaWnEV+x5qo+iQqt1ytW
eENlQO/L22eu2tOohKzbqC9JBVlHTpYb32XAViPogt2eaZTYd/bBj81UCF9v
zv6NJAud6C/vhmPTKO3E4Ujnf4R/Zu6UGY+VhavrPhuf85om3vFXTcyMIXz6
pX3p/agsjDUo9T+8OI3CxXdc9uozhEcPFtW9jeRALOgPOnNjGpH+mI+yNRmC
9sjkka7HckBzbXnLmTSNmD8yJGwrDGH4/pog35wcULRXc2zyp5HrTlYn5xxD
aGR9F7XJXB5UZc872VdOoyN5I82yjwyhRcuoqTlNHiwcR0pFm6bRetZLGWmR
hN8eIHMfXya+N0+/ca9nGu3Iy13fHWAIzZ6jdpmHFaC+p7q4hj6NnNUWSY0n
DGFgTHe8OE8BKgZXN+X9nUaM5w8sLpgbguW2vKZodkXQsaw/a8HNQOan3G/0
6BoCPcBZU9ReERyvmKJ0EQaapi5KL0sbQivLFv3TRYpATjJrfi3LQPco/+1u
5zWEt6Ga6yLWK8Fw2YnIEDIDUdY+y3svUcCeVPrOxlkJag1wyZIxA9WZhi6X
j1EAL9heGytRgsKNzvs09zOQy8niP7XNFOBWdo3R2qQMw5ODohJ2DBRcesDm
xlsKsDwbnqCdUgavxMSNte4MFK7VaLopiwLuj8I+s5crA5d+worEOQY6WHOQ
1SKOAhYp909e5VWBFPfkr+TLDOT2Mb/a9CLR/77a56pTKiD4UMxjJZaBHt49
VLV0igK+ERsoRWUq0KC3Myv0EQOVfLEj+e2nwKH4pNYTm1TBn2064PUzBmpf
jbBO0qWAAzdPDT6pCtclX+Wl5jOQzqCqQ4wEBa4v6Gt3v1GFfb6dhqalDCQ6
deKGJjcF2I+9s32+Xg24Mjy4UqoZSDq/SjT+hwF8HZo5rHZCDTRSBBdeNDLQ
TfPEPZWdBjA/OOjgVqAG+SH7GOfaGUhwoM8iBRtAnaT704Ps6jDaqdo+289A
ZZNbPI1yDCC9XsBixlYdpFcfx0tNMhBncVBX0h0DKDMwiqPlqMNtbjHJ9XMM
dPZ9U3/5BQMwoXOk0pbUIUuS9UjWXwbaoRtd+vCEATQYm+czLTRA7ckeub+s
TPRUrSidZGoAQh4VE5bJGvBCIf0/1g1MdJ+8OhKrbACeyk1RdjMa4Pv7qjHi
Z6Ksx4XlGXwGIH/qZF+sBAkYI/yu5G1M9L2nxD1sUR+4+jv6qvaSYOy+Qrud
JBPxbLyrtrVXH4KtKQP1/iRoSLG/oq/ARP07nK3PVutDWMhwaM5jEtS+XD7a
qMZEHUcHhG9l6cPxX/cPnUAk2Pls0z5BbSZ6neGKPG8Q/TdfWhkfJ8F4ptVu
PgoTHZgfuLcuQB8s6vW27ObVBA0HfaMaYyaKeNjdfspGn9CJBuMgHU1wn12U
U9rNRNl3LnyJ1NcHzsjngpccNIGqeW7W1JyJ1i37vXcT04e4nBLSkUhN+FK0
/7awFRNJHRNYWc+iD18u7NJhy9UEw96BxcTDTJQ2ZoEDRvTA8SQ/Dm/WhAo2
qnj7USZyXog/llinBy/qDwW0LGqC4iW1pff2TMQw3sR77bkeOHfmjf0SI4NC
qf4VDycm2qNnrax3Uw88XLXwhAkZKkye5CIXJhI79ux37mk9CP5wLjXfkwxO
kxanm9yYSObiZzx8UA8Min0UTG6ToejNUu0tTybik9Bv6SfrQa3MncXs12S4
t4E/h92HiRJxe+BTIT1YEa1/1ddJhk8ZhfzqfkxktkP1j+yiLnTeDFoYXiWD
Rm7ZCo8/E3Fctc7x79CFdaQL3qXSWuBe+NY1NYCJ3okzWi+X6YKorXCR3V4t
WKxfv2fyDBPlG2rW2SbogmGlRECTjxaIXMpLHj3LRNUPR5vn/tMFO69uM544
LejocfF6eI6Jnjw5amJjpwufgtYNbSvWguGgvOwlot7wxtP7EkUXYhm9ffMd
WlDlVXFUKJCJwm9EJPiJ6kLjtW1jSctaEGoV9t8w8f2dPU8k5ZZ0wOLhXBK/
hDZIWDzd5EbURb5rWWd06UDi2235h0y0wfRfmHAScZ6tpKOXpst0IK3hQ7mT
mzbExerfv0acf/O9hN9Lj3WgOua5n36MNrhcSb2uQNz3AN4i+O2CDphd/uvf
m6sN+8ZNV0JOM9EF0wsygbY6EPbBx8viszbUSvrNXvUl5pw7GNqvpQMbG/XZ
o2a14fXPbZ4m3kyU8o47UEBAByYkxSZi+HVAw3edb7EHEyX/v/rk/1dXq5Fz
5PuhDWk7bdERot9yXxprjysTzRT8iusk/p/ZsRzdGRsd8G4QJ5WcZKIA/yIX
nzxtOMvp9OcAcd6WNsd/ux2ZSJ5bTvkTcR9ppX0FwcT9wl+xBsfaMZH5UJzR
T+L+aUnvNvgQ8zDidkqPPMJEhT8rf48T8zL8l1gsR8yPeu7aDc1DxL4s/XiR
Tcx3/qyZfc5fHSi0MTV8sJ+Jkgrny7VXtGCHY0n+z2260FC/pSrPjIkWV3jP
3+7Ugn5lp6McxHsejKVKBu9iogLJdQZviPd+tM5sQ99xXcjtyDz9l0a8y49t
zs8JfFATWc+HEni5fuRfiYY+sUerPLt9fLXgWnPO3uF4XZhfyOfaTmYim/pt
u5YJ/G2/NkHmJfD470uD/1sVYj7Ti2+Oy2hB2P6FiX/fdWGSXe0fnxwTzZm3
/41eIwP7jvitpQu60JzsVLddnMCPoZNPZBcZ7vDJBWkR+7HgmfW9R4SJ5gtL
PayKyWCw/UpJILFPjl9XdlpvJvp4/Wc5Texb+zup2IvE/pGKhLeHcjEJn1YS
dNSLDLZvN2WZEvvqt9P+vMM/QkfcF/Y+2EWGdU19Va039GB364zrz0UGkjur
LZa2gwz5Vu+uyxJ8MPU6Z402w0B68aOHr/zWhKtr3pUGBH/8ZNt6zHiMgbLr
6QfILZrAlmCwSYDgG+2QiGuLPQz05mmK3xuCj8If8Wm9+KcHGmaj6adaGYj/
+ie+jVc1oa7Vd2wDwWccbbO10fUMlDWUmaB1QhNsKCd7lQn+G3iwid25ioH+
29rvpaGrCffOP27mIfiSvcs+aPY1oftfboysEXzadO9gSIG/PpjefWmo85yB
fizoeqVNkGDjK7dHwgQfS4je8dZMIb6fbTshikmQk2zWa0jwN42dKjF6j4Fi
cz7KesSToOk2B7cMwffJ7Tnn919jIOWSXqnrASQoLDZqb+jRB+3OS7F+IQyk
f8ayPNyM6DOhy6JF6AnPty0hpv4MZMJXbnVAkgTs++p32xP6w9Vyza3VhYGW
rtg/GJ3VgDejXqd2EXrFNXjPc8sRBoq6YijWnaIBddYaW6Z3GcD7r4XpgvsY
iDpZxxa2XwMSrD9JHCL0cG2GT++jIQPNL4UJtSyrw4BfNDWY0E+Pj3d2kdUZ
qDrzlXjbc3UIekjIOKG3jA5Mt5FkoMpMv9lrR9VhvrSyiIXQ58z9Uwc0BBjE
nj6wZXIQdSfmLRdCz0lvWe5XszNQdNIHyXVFarDTsjA8gtD/yi8F3RsXptG+
K65SzY5qkMF1fr8z4Rd8OG3NecenkVH/I0WrjWpw9/Ke0mUuCgSeWuL89H0a
xZfv5I4sVYWghPYrNoQfSdrupEv9OI2WENd931OqMFEXeMab8C9O+36ueZRO
o9GTe5N4NquCe/w2CxrhdyISv12zzJ5Gl2e3/jlVoQL8Vifamgh/dGC19c/U
o2mUU2QZcs5NBYZ9L33bSvgpA8uAixBN+Ewur2VDPhX4sMthsxThv1T/dOsc
PD+NfM/mHKiqUAbHyCtWY5kU2Fs4Z7PNdRo5lfy2WHZVhogPog5uhL/T4TVh
Szo0jVgmfjX84lWGwG0rq6mEHxQkc3t1wjRavDiZnlOmBPW3UtceE/7xU4D6
my/q0+ij/edXoi5K8K9MWdGc8Jtrc5aCl8Wmkfe8ab35RsKPgtvuUsKfph16
XjC1fhrN0hI/GhQrwkXn91IDhJ8dN9V9y/ubjhoaqmImHRThm+/J69WE/+1T
v39yZoTIQc1mE0fXKcL+Y+v2ORJ+Ofbjxm8xzXREVz+DYl4oANaWUH9D+Ovk
osfG/ZV0JBbMPxNiqwCKxZ846wg/fk+0u2Mmh47qfz07SF6VB/mchmdxhH+P
2Sf1ueIBHamn633Iz5AHlvD7X4QIvx8C7tYm4XRUbRKhzLCQh3Mfdp44ROQD
jf2Wj6N8iPxl3uA091MOuOOfiu8j8sTVFMnWq0foKHd6xvRdghxoKciO/mk0
BP8OgqR30lHdZteKgyAHLCrzl08SeeVK6pbfpSp0ZHOI9Cx/XBY87YdrI4h8
M64nbcEQpqNfy/TulpuycHzcP9qByENsLHSPvn9TCC+V76smy4LlaFP8DJGf
Enm4rt6YmkLXu6yaQzplILqxs/l/eev6y7Lvi61T6MybKWu2MBlYGpLmMCTy
2eLq6GOJyikE5P1FtjIy0PSCzr1A5DndU1tZODOn0A6/uvYL9dLg4ipZ4k7k
v+3iUWa5t6YQnSn3zN1PGqSPuY3cIfLieCNbHs+FKWT8uOqvnIA0fHbl8Qog
8uWH6U0uao5TaPTBqQ9vSqTAzk5UkjuUCu0nP+bw7JlCP8zc6SL2UhDnvmf4
CJFfG/78qshVm0J39B5Ymf+TBIFLS9cdiLzLPbzcxiU8hQ7OafceTJcE8arD
P7cS+dhbm64luzKJdFe4glX2SsLnHunfN4g8HeHlK8wyMolcL0SJlLRLAOMS
I/ANkb/9u1pKn3yaRDbPxVaxmASEZ0yZPSTyuqPORrvfryaRp/rGC/+dEod0
bm5rFSLfe7PkGgo+mkRlFW42Q893ADmU7hM0TgU9rsGk2ZBJNDyw3XdpVgy+
7Z0K/u8nFdZ/D6u6eXISiX/5dbdORwxKrgkc01yjwhW130P0PZOoQDD6yd6Q
7VATrUxPWU+D1vPH9m1QnUSTxw2cLmNRsN6az1cjRIN40kG9ab5JlCFhVOy/
ThTiftS/SJSggZmX0uythQmkfib2rKj5NjBZ9spQVKaBrGxT8c+uCZSU3H72
yu2toFio0emjTYO6xsqmbVUTSJJ+/3ZW6xaY9Dmr5mpEA+vk7aHsaRPI3OTn
0xsiW8C1zOQ6vxkNRAQzuAuiJtDV8ZYrZDsReJft1XLOmgZz+/PLJLwmUMWW
2s3JycLwXNyLEWtHA+FLst8OWU6gRbxO/vOgEITKhFYfOUWDRNNHT/dpTKAL
4iHPamWEIFb5sX6HDw0uSMu6cwhMoDiXPKcod0EQOulJ4QmkgVJrjH/k/Dg6
dKzSiP+5AFQtHi1YCKHBz5ci6z5+H0df2E/v8J7mh0C3mKv3I2mQKlQa8LVs
HLmDSM9dNX5oLv3+bCyWBixoaiUpcRxFOCQdjfXng1+fu39N36XBZ4XaeY3Q
ccTnMTWe67IZBlMn3LPiaWAz8iM95sQ4+hOrL0Ef2wQ2VzdOCj2lQe7yyyPZ
RuNoMF5x+3dPHvjjzueml0kDd/OW4zclxpFY6tuUs9MbQIc/tGlTHg0EWt4t
6bGMI57T9NPv/dbDHpe4TfEFNFDk87uWOziGYvKfWDfNcsGPGxZbv7+hQbqD
14FRPIYmVxI33T3DCTctPfs+VtDAWPtLyljqGHrAG+ct/IsDohUcD/ghoh63
t/5l+BgiFS2QTgSyg2PSyRN172kwrsu/HZzHEEzyKfsusMJfe9fV1o80CNq4
OJFgPIbaGBMSey6wQGCosPT9Rhr0OFiFV4qPoc5LZyv6mKvGTnlDiPMrDf6Q
OXRzVkeRotmYXdvMkrGz469GtVYa/JcYY3+idxTFHDpYHjT725jKpkXlbqfB
6dneXb0Vo4jbSMT/6+y88X7FvVyPOmjgKH/LRC5hFA3K1YiMzM4ZOxc9kO3o
osEGoYI8/aBRhEWmHwcOMI3nVoxuNvbQoP/1+DcR21HEF5h/pLx/wriDS1Hv
XB8NZnzt+TB5FDVb/slI7xsyNkv+If6ln5ibbXWJNt8okhS5dDmqrMPYJOgP
rXeAePcLh3ecZ44glnnlR4+9Pxo7n3K8kzxIgyTutsQrDUQ9WLm57e45tOzK
sllgiAaqFTei7bKJekhxoXJGPapsDyk3IOo1E2b6LFdHkHPaK/zPthNFXFW7
KUTUC3scuc85j6AAeivrvOowymjVjEoj+i9zZ1q9phJ9mnyaOtQnUcJX1/QR
4jwpuy94VG8dQYMus0tPSDNo5JDLeAdxfkv2gufJ88Poj9fH9K3bfqIAoegD
l4n7LkUXBpg1D6M4MTbd2m0LyOT9dG8XMZ8VcfstNXnDSLKoh2+f6B/kLup/
f4KYZ9/RTX83XBtGAUfn4p6KLiPH+bzAHGL+nRo5Z2RchtExeo8AFl1DJQ5r
kWLEe/0xi+3bSBtGndrP/rO+xYJFUiM+7CLed2VbXELtlmF0U/fCXslNbDjW
TthInMDD5x2C7Ad+DiFtK+9n9TfZscrVw7/yCPy8Zp0KymkaQqNJO0r28KzD
bKGJ0wwCb+qtLkfasoaQqZlD8aMbnNiFn1t9iMDnfXnL1ZbwIZRar9BYvIEb
u9+4WBND4HmXBb3xmd0QylDCSsnX1+MvL+MKRwj8J3ovS5lqDyHXwy/+WXBv
xFo1zzl+EvuSWvzGqXzTECo+XB/6LpoHX4gb+/D6f7+PRdWNsU4MIo5c0xYm
By8+5yXLokTs4+x1a2FxPIiSHpSrdUVsxiJSXMia2F+d0Vkr3oRBlPXq4RAt
nA8n8czyqhP77rP/1e/WM4NI1i52aNKIH2uvra68I/jBQo/f39d8EG34XfrK
Z5UfNxmJPGa9R4O/0+u39UgPons6zm61bwUwJbp7+g/BPw7H/xUaLQ6gQ3Ob
xOb+E8SJcy82ZBB8RUq5L3cuawAF9CUwZ/WE8M/fr9nZQwn8FznZ2hwZQAdJ
GvNVC0JY9ETzhDDBh6WUlg0j6wYQ58GD5g6vhfGkdHZ9L8GfK2lkPsk3/Wgp
rGdDXYAIvhecVHaU4NuSw89JPK79KPr6ZusltS3YNqetIZrg55o+Lf0cgX5U
eS5O/zd9Cz7Cri3oTfD5DfmcX/O4D91T8O2ryN6Kmxsds1gJ/j98t5D063Qf
qpORcNjlug277ChP2E/oxYjc13fpYn3opXJCy21JUfzymzv7AUJfeoutvbka
elHB3E77J72iWM3fYomN0KMHf49zSgT1It6WVRGP+O2Y+mf9I19Cv3zLv7tM
y/Qiu3NkmR+HxbDNIMdsLKF3fYMR1n7NPYgR1ZiivXkHjh86Ie5I6ONS8khG
ZmgPWvI0fk5u2IFDexdo46tUiA/eQ3qo2IPoA/ddJq+K45LXvp4yhP5u9UQf
qW3dqLvaZfqwsQS2kJcqFyb0OnVcHpIvdyPO3H7Xc38l8FI2yfJdFxV2sm31
L1XuRtJtPsFpxyVxrl6QkSjhB877zCjfbO9CdX8Gjp0qkcRk7TsvVAn/4HOl
1lwsvAttMTvmtiwghfU1Wkrni6gwY38my1O5C4lvKH3l5S+FD1UdDj2bSYWF
1miRs22dqOaZrvmLRilsYz4tmvWYCsORVoEGYZ2ocNRn7wcFaYx7lYrvXKdC
SFtTAlLoRDvPmVUURErjy9OOXhohVIj5VXxyXUsHWse3o+T0gDTOlX7sEOVL
BfWOgOyNFzuQ3+8nB9YoMvixalLB3RNU+KMvuvebdAf6rdvz2PGRDOYJno+x
OUCFsjv/7TjR+B0d5ziadXtOBt9bGV7/xYgKnFwc3LnnvqNTQvO3b1nKYqFV
92Nr6lTICOwardj+HT2dY/Wwy5bFl+sNE8fECX9lUXMv7n07enWIZjrPKodz
gjsXInmpkHNTbU7Fpx2ZB7RS7Rzk8P5X/ve6Vg1h9I364C2BdiRk7+Rxo0QO
H7GefTzOMIT9L0OgtLwNLR5c7I7mk8fiwKKR10P45wLvXznObUhWQPKVhbc8
XuTjvKLQYAiz5B/dp7ja0LBO/3Lne3ncViNeZl9mCBmfk7omX3xD6WEvutR2
KGDRs9L/9mYZgr34k1Z9m29oTi3m5L4LCvjWhvQrjPuGoJr74rnNUiuqPTqZ
r/xVAZ/9Pe2z74ohqLxT3UVLbUXhOg3tzQqK+GML67TjaUNY3Mtx9dfuVkQJ
frlICVfEuTxpqmr2hkB7W2gdPN2CXicmKXt2KuKhpyZOxXsNQXRo572muBZU
RJa7dZSkhCMK+IvmtQzhv+IDqnM6Lah2pyuFO0YJN+ot2MxIGMJp3VXOie5m
dCaK3eq/ASXMkRMb/GyjIZzbubz+1eVm9K2OOvlcVxln3JE/wPubAt/sLu0w
l21GsUq9Mgm3lPElShuXzjAFvrD/Z3P27le08p+J5J5RZSxibdsp/JkC9KUJ
8lLXF7R20WPlFUUFy12Q+lVQSgHKgarnatJfECb3drTHqWCFYbebnGkUcPU6
fYvX+zMa1v3cWjKugiVWObpEblLg47+Tr1MKm9DSbw7eQ1RVHLj4kHf4PAVu
PV6YG/jTiMR4ZnKz7qriMTvXU55OFFDiD5RsM25EHcEPG1+Pq+KXOf68uWYU
4FQR2HIpugGJr+TfCzZUw5VD3nuzNSlwgZX+srfpEwq0uSUzf0cN84lV7nEW
JfrcWKyeF/iEjGL00+RG1TCZL3R3OxsFMvg3q3w8Vo/kVR20ePTVcVvm+Uuc
0wbgnDX8wTblI7qfc3gl64Y6vhUmpzTfagCWD36dThupQ9phyjIL/eo4Law8
MqXCAK58vsf+SrEOXbqe8mVBUwPz2PB9WpdmAOO2PScv+X1AZrul5XOuauC7
y2U6ytcN4N/zF56bi2qRJc+A9cYODczY9ZOTJ8AA3KXzfrsvvkfN+fa0O0Ik
rGaVezHviAH8PKw5G0V5jwSuyroF0EhYWiDsKzfNAGx8bUmnw2qQa33QG0V3
Ep5pKTOVlTGApBsDSVI11WhMZuR96W0Srnl6WHSN2wCsRPdsSVtXjewsbeV3
lJJwaut83KMZfdAVex4xZ4ZRiqTEuWMDJLzn8uwU85s+MP4lRslsRSj0wzx4
cWniwzMmHhzl+uDZQQpen/IO9VTPyFtpaOKjfIkW3cn6kMQjnB0vU4ncRG9U
rj+qibV/mHf7R+gDOeRCX1tOBfLzfZkQH6aJw2WOHP3grg80wZyJarVydIg7
88hypiYWMnDn6jHXB7vjW+6fKipF3Btlb2p+1sRv5L5qFKrrw6khk5fvdEuQ
XJD5N8q8Jh57eUvETEAfPtQUcLdVFCPR/WkfRLaTccO3PWypC3pgyjV2Ntfo
NWpKk1qt3UnGoL2XUt6pB2JCx6pMawqRX4WK0G5PMl49H8H54K0eaG7ye5e1
uwDFb72X+eg2Gf/IvveKlKIHUe7N0Tl3X6CKhIeW5cVknJVeGnYnXA8cgxvM
0h7novzoiYz8bjKe8v3+rsBFD3Qsn3ibJGej2zm55gEsWtj1TnDpA1M92LQh
5XFcWgYasw/sZpfXwo8uNpYYyutB4eO00AfZz1Bb2v45dwstXNLzlCuLSw/O
0orv5B1LRs90i1UTArTwxILn4rdJXVgRumZddvIxso5/opz4UAsH/jFs/vBJ
F0wXNFIdve+iS5Knr3tVaGE4/HU4JFcXml73VtmPRaNDvLyTnANa2Hr9xdDF
WF2IGU9pa6efR/8H8Wco3g==
     "]]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005], 
    Line3DBox[CompressedData["
1:eJwVWXc4le8bR0IlO3vvzTnWcdbzRqGUkBQpiqRQGlYhZYSEpGHma2SkQsrI
uI1S9ibZex20ReX3/v5yXff1et77vZ/P/RnXkTl90foMCxMT03dmJqYt+N+k
B33Tl7bowl1mnSU9d30sOPvry9aTCP1bTJHNV9KFuCNxN8nm+tiAns6Cdb8/
cjtSRH9prguQ9j6aVU0fKzHIPRI7FIEctcYGgy/qgsfu3JMJ2/WxKGpGUoNr
PEreuPxY8r4uKL/JMluY18NCtmeKUR0fo4RzBJGIN7pwqLMxhe2jHvboxL7q
tKNpSM3x9GblJ10o4ih/Pp+jh3Wc3ohYVspADkytjMo/unCmtKLtfrgeRsy/
1/VNLhutvS6/fVtKDz465h3eekYPU6+su9UvlYvsdL55iRvpQeXiehzdWA9T
+yo+dk/sGVK93njwuosefFmo+oxk9DDNhh/aYkIvkNQkR31muB7can8cuW1T
F5uarh7WiyxE2YLcPg9y9eCZ8sfV5CFdjPfswkQVWzGKFy7jtGzSg5efZd1+
letiz2e4mmVCX6E643Ma3Yt6wHGc21T8kS72InZf+Qnm1yh1P88NyZ36kP05
enr7VV1MzKS1wzPoDUrWk88jaOpDQIRGSr2lLva3bEnXYqMUpTo9Pcx5SB9Q
iWCDiYYuluUrv23Dtxzp+sopvbioD6bbmEoTtuliBtsULnl9r0BNF0taBOP0
obGU2P58WgcrYB+Oy/eqRJlhm4y9hfognxFxNr5WBxOhhURnL1WhSoKhHqVD
HyJuu382StXBYurTI0641aC7sgoHf67oQ616T3iNnw62fH/nkdlLgG4QhcZ9
uA1gX8i+9xw2OthXE6k717RqkcWJ7ymVmgZwr230p6SWDvZr0dl/ZqkWaZbo
aDQeNID7jQY+LNt1sKmzv4gq+XWo2nKU/tDDAJKqAzNeTRGx38qkZuxsPSoy
eXBD5Y4BmL91GyTWELHrtJYjavINyCQhIjU4zwB+JRkGBicSsa3uT2dmxhrQ
Nd5bpsmNBqCuUbGQcoWI/TPZEX8p9R36c2Jc3X/aAB5bUEMiDhKxgkMPPT7a
vUdtral/RbaQQIAlMcdYiYhps6E7S7saUbKN6flAaRLIR2iVtzERsWWOk1s+
dTYiuMgun0kjQfLVKRHVQQLWpVm8EH33A2LlzhiKsidBUp20uu0rAiaaeeYo
276PaP26j4muLwnmZjqsD0cTsBhmfidj1ib0FwULPLlPgsAx5y8yZwiYw5Um
MaOaJjTKcWy96SUJ/E2b3OtoBEy4RTCD6VozUovWLShtJoGTvbeiniAB25PD
siNQtwWxnVsccZklwfNttuHXlrUx1XCJi6+XW9Azjq+mXSyG8JZ5aDX+vTZW
zQiezcltRV6BJ1M3JQxhs/h7c1CaNjYR2nvX+nQbuuo092CJZAgFx7YH0X20
sSzisYBXYu2o8vn83OPDhvD0L8uFroPaWDx1tPVDTztaSnO0YL1gCF030BaK
gjYWUrxi8cGkA0WHLgZpRhhClpye+Zc1Law0lBTKmtmBKlO7dYQyDEHAp/2a
UI4Wppuuukt4swMFLW9Rqn5rCBYFU67zNlrY5PVAHpbjnchDgJtfrtcQJsR+
j59l0cK4txmF1b7pRAsiWq/2LhuCQVFAzf2Xmpic0fStI3xdaNjUpF6BnQzd
Ex+6PR00MdlyokiVZxd6/WN0s06KDA//k/z+k0MT+6lw9NivD11o+zGCogSJ
DA17s35qvdbAQr5PWG6R70a3D4p+17Ekw05/52KRUxqYfVcL/1hQN7JQVVRm
dyPDHgnTzRJODYxKvVoc/akbld2MvvnwBhl0tEXesJSpY3o7sugcuj0oeJkA
4w/JQC0ILtzirI6dYH7QZBXTg6ifcrPmnpPhy5nND2U71TF921U3t7keZEQj
ruY3kKFuZmVQtkwNizLqUjc36kWf3KtdlD+T4fqekDqj02rY8p0Wld/Jvai2
ldHg9IUMIz+qHUQ41bCX3PNXLv3oRXyZvD2H2SmgmXXtds5rVWz/wQKpVxZ9
6Gitui2zBAUWfp+QWT6pitFWhYyqcvoQt+V37nNECly4MLJtmV0Vc7J7vhrD
1I8Oh3S8jzKlwFsumkxuoQp2S8lrt5JdPxq3GcZcHShw1jjUTMJOBbtcM7c/
rKgfWVAW92x4USD8ftgpC2YVzLZbUT532wAKGb2RtC+MAmMu/RbUPGXMcL5+
KubUALrQ0bfNKpECxuVd32YtlbGVseksUvkA+qo7cZz3OQW+zMXpWq8pYcr+
uwOzeD7he2RuHwUUcLOf/3H9iRKW0y1+u/PsJ9S6/Wr7224KqBtclHA1UcIq
16yGqqs/oXvz3uHZMxRQkLx4j5ehiNXaWT1y3zWIhj3lzU1/U2Cia4l0474i
9sJavrvPfRAlT3IupO+gwo2F9I2XhorYYP7FZ5u1g2hBx1e7WIIK0d4/a7NG
FbBsAR/qtNBnRI5yXbqmRYXHORzeJ8MUMJEC0cxwz8/I+1fi0jpGhZHr6f+G
VRWwzKuTfybqPiMj/rtMRGsqeBwl7pPvkMeiezfO/hYaQkHJfmtSzlSoyP2M
iN7yWOQugy0fPYZQCu/h7IYrVEgOdWrjEJXHVnv4li1rhxDJtnNAKpQK9ZjK
eG61HDYaXm4Wt2sYFRqdPUNIoELsDuwMv7Mctm+eVTf83DCqxcwkf2dSIeum
hdk+djns8vXgTkLVMCKNne33eUWFOizZz/yZLHbtm7txPM8Iyj9/7Ux+HRWc
/NinRQ/JYheKqwqeOo8gUe8fqfc7qfDKlzOw7KsMxm2gQLjwZgRVXOQ5Shyj
wlXDcm2FhzKYfOzOH7McoyhD593Z8GUq6DJerp4ylMEiGp9I8B8fRVdiOnJi
/1DhcJDci4tD0liu/buO5YJRxNxSvHJwOw3KhXvtD92Qxu6nqupd+zeKlmmF
wrVCNNj3jHeeWVYaq3kgbTioNIaMazv/zMnToLj95COeSCnsm5LMMQvLMdSx
e9rnHYEGUbcEl963SmKepcKciX5jqJASdNqWTgPNNs4yZT5JbFFvZb48fQwl
kH8mJ++nwddA9ikDWwnsJvv38MIPY+irrSfTA1sa7ClrsvuZKI4d0h31C1gd
Q/pFTZ5Gp2nAN8/P6joshl1M7DoiITyOahYq6zI9aSCbm9AWIS2G/RY+XhKP
xtGblIqRMj8aiCYzsp2cRTGZj5fUhlzHUV8LS8bNEBo0HM7zXckWwXxkA61/
3x1HrE6pjL93aVChYkA0mBPGaBrWtfMl46gy6nimxmMaTPDMNBiqCmNvnuvx
PP88jo6hgWyeDBqcdB+V+u0uhKUeGu43YplAWkl+A0+f0aClX0bX97kg9rjD
qyhfeQJ5mXtIrZbQgOnP9W+vl3dhySp39KcsJtDCv+eOS1U0qDa/bVmqtQu7
XEphXrk6gUJrt9xIfo/PuTmDHuglgImfZi9oSppA0S6bzn/baKDfySjaVsSP
6dfPd/rABOod+feDt58GHNVGT05+4cNszG25vk1PoMBn6hKfRmjwr4zwJ5DA
h+m7Gv6l75hE8YrBddYzNGBz3qg+d4kX20j9TbbXnkRes1XtQQwaxETcGZEr
4sHIVX4ue45Mol5hP60T32nQkT6b5TDOjY2sCAj99Z9EZW1crYx1GpBaWxQE
nbgw1sm81ZC0SdRlV5igzUyHBrNTBL8RTuzx5L3YgbpJtPrY7ooCOx2czrtX
hDvswDo2nsavz0yiCdM+2xZOOqR7dZXsHdyG+XLvSZzfPoW0DtRqKPDRoaXm
/q7yoxzYxs+9xtmaU8hvM3RWS4gOwSJlXVM9bJh5IidBw3oKBfkev7okRoee
NrPJFqutmA9rwJab3lNopdninb00HTgZe5B32xaMLezv8fTHU6jMzrDlmjwd
qC4PR8f3s2CilcFDUW+nkCbr++sHlOkwoMJeLdjIhGmUBChhI1Oo/IpXY7sa
HbTzPPK1wv+hlO+rozVM04hoHZbJqkWHD26iu7sCN1Dbfde8bXLT6Guo7NZF
Ah1WP7qRJLzXEK/ZFyWJvdPovIvBxC1dOriV8kYJe/xAPL7aTOuu0+jyl1BC
iz4dHo/LEFpOf0W/jS37n0RMI22OtIX3JDpA3LvDwcXLyCBl+2Gu/Gl0N252
6xUyPk/fyMm1tDn01ihXZG/zNLIveBzQQcHrT+9x8d2ZQH8+MXcZL02j7ZMV
ZqNUvB70LKeUMYAcl4Lltu+cQUzmqmee0OiAxdl3PI78iMy+Sb95pDGDvAof
tPLQ6cDkEeNxwCsE5Tp4EZcOzqCJ8qAgHbwenChXzSneWCMae283+4UZRNlO
9mbH69Lx3L3PS/trzi9R7s7dnUGnnFZeRuPnO92R+p23Ol5T1lVZE/t8BnmU
JGrU/7+fDkMbj61zNX+S10L+tODvtWZfzsf7lzZm/r5TdLmGLcU9THNpBjV8
/fTFGP/eOH52NyT0teafuJqXwo5ZNNceTo7B5xPs+/HiUZkfNWr2M6tjKrNo
rNy2KRKfZ/ClBk5TtbUaY//ZEiezWWSk5Jql///5n71AZtPbqJG/JXA+y3UW
JRlntyTg91U2dPB7NP1fTbfNavWz0FkUsNFvmqWJ43OePXk+kwlmU5NP+2TM
IgG2h2JncDyAUHugmzILWH7sZWWFWURc2m/Rr4TXeZKlawq2wKVvf4/YDM+i
BU792XU5Ouia1dyc194KYQP87GfXZ1Huk/PL7VJ08Nrb/mSyhA0c6so+UoTm
0NCrdg9bHM/yQ3n+eSQOOH5V27JLZw4JaEp7xAjSweFsKJdB5Tao2XX6oKrl
HMqsW/jpy0sHjq0/T0SgHaAl+umqscccamDcE+bH96uli8UtsY4TApXfX5OI
mEPG8+bDjmx0mFNT0nDdywUFm5v8ZZlzKO2JrPVJJnw+s6dfLDRyg7o960++
mjlUmPItlGv9/3yV4cObzQMW7Wt9GoNzqHrjYqjXNxo4uKx7b3XlhfbiZ54c
P+aQ1mFxp9AlnH/S023bFfng9deESxnc8ygm1VJ5/zQNLGVtRD1n+cDgW1/S
hso8IkmTlmuHcZ6cIdQP5fDDkBvK4N8zj44d6qxf7KXBe9eKw+JuAvBU22z3
wol5FPGS8baxlQbC1P42FeVd4KsoTLzhO486SggLR97h/Fk+ZrBlbhcE/g7R
6oqbR6pPBJwfVuL9x2TGP80RhJJ/XD8m8ubRLZsxSuQrnP9dXCd5zwpBJPMS
vahuHmmSiqI082mQG7iiaawoDIF8/z5SP8+jgU1v1/B0GihbR10jTQvD/OFP
h8O+zaPVsJWZuIc0sNfc2bKSKQLPG+qTonYsoPjEQnmLaBqEto2onD0tCizb
3pw4ILeAepslDKtv0mBpfSMpRVoMdhMcHJrIC6iY7Ekf96FBgOxfxZgRMcgL
EjzKar2AzOyeHip1x/Xou1ifYYo4SCquc627LaC81/9FYE40CN4gFaXaScAq
T9feZzcWkEQlB1ugDQ2ohPHaUkFJuJksVS30cAEN+B6Z9jCjwYHEw3zh3ZKw
bCVGQQULSMuqaw8PlQYpPeHP2eKkIC3/dbBM3QKy+JhofFaLBpzHH7WLKUrD
h+pHh6v7F5ClzkPmy7I0SFoY898RKg3NTPL+uxgLaO38zSfau2jQF4scOsel
IW7Vp1SRZREVR0zRM9lxnJSUB3ogGchsPdv7RXAR0e8LsTT9pkLD9Zrpzyky
cMA0MslHbRGB5m7O7EUqtEVqpEiuy0CAqmp7CVpEZvtsb+oOU6Gs8VCezlFZ
iN1pSy04vIhGGkTC/dqoEKc8tUu0RBamfvc+czi7iHikxLFLNfjzHhKLHTxy
YMtPmHt3bREt7HrbK1lIBeOpbOJRTzm4THteOXt3EQXvl7lwM50KFtoZP599
lIOo6kM/atMX0fexvYTEOCqYbynZ3aYgD3fGhk/avFpESxJLpq7BVEBjfySr
bsrDi9jh92nvFlESc+bnuYtUeDQgneQ7LA/NPx9spPcvIp2xBkEZRyps27ev
5g9JAWJEeFrs5xcR25qPPLcFFWQfKCWbJyjAeQ8hjpb1RTTPmqf9ikqF6+O/
yM4rCkA6Tw7+vmMJ2XYKuO1Uo0JpS0iB0X5FyFRq3tojvoSWGmhrEiJU4FVS
+DeXpQj0qdHz5zWWUJSXF/c0GxVicj/Qj2wqwunEw7dKaUtoWqhu6PR3CpRl
rwaG2ynB8/D3Um8PLqF8Ek/co3EKbNSVNl9/pQRmlWlC3ieWkAY3k31IGwXM
nnaTdHcqQ30GB5r2WEIPhf+5K76lgGXOo74XrsrwNPiX+46AJZQdT1sLzqGA
XtCvNws1ygB/Fbxno5YQ6+9Swv37FAhajVyaEVaBbVmCRP/EJSQSrH7gxA0K
2Afcicq4pAKyJwWuQ84SunxXKmD0PAVsWMazxJtUIOEbUaXq9RJq0Bj8KWJL
AWlPUUsbWVVIvXVI8GI9/nzEua+cuylQeNT7P7NrqpD4i0eir2MJFVmmZZep
USChaPTFWqcqSN6aE/46vIRoupxmEoIUMDy1HuOsogaP2Plm6haW0FPTbXwU
JgoETInZRQSrQfT9hFNmv5YQxes5lW+BDCYr1gqu/WoQ9M7o3K0tDHStuZM5
s5sMYhznOP9oqIMZ9e1nL24GogjwpDAqyVAkO620L1QdtDfdHvOLMdDprXUm
X7PJEEDiij8wqA4eUyE3zisykG4FE70ohgxSo4wzW7U1wOgHz2VvAgOd5Myq
VvUlQ9OQdc3lMA1oaZ+w0qUy0K2V3WyOjmSwqeiuuD+oAQJsScw5JgwU2KRx
2MKUDJaHO73PamnCyrVsl1ZLBrJv851a0yRDtrM/FyNEE/ZUGjnm2DPQ0P6l
3ycFySDP/zFTbkATRu2D+nRdGKiCib8n+K8hpAbFHtmurgUfkG6htycD3b+k
WXJyyhCq6V570m9ogcYmd/c5H/y9GpShtSZDuLA0fW+qSwuKlO8q8t5goGOS
KzGHivC6laz2Ip82HHnwK979NgO1dpRxOz8yhNvo5DkyVRsGi92Z/WMZaPvb
6gydQEO4yvUi3PGMNqS29B03fMRAYjdHomtPG8JERKSofYw2LFn9ii5IYyCC
QQH/TjND0CAOlqqUasO0yIngrmwG8vvvUqCghiHw3PzzpXVUG2qzzsk+K2Cg
8ksavCO8eF2k1sGEgwCp9pZO+q8YqOtWvKDLTxJcY7kQHa9NgLpGQeWr5QzU
y8velztIAo7xml3Fxwhg0Zfg5lLDQDt+ZD4uqCbBQZXFu1nBBPDe6s3L/o6B
0jp0ci9mkCDUJjXqXC4BeNJ0+R2acDzsIx76GkYCVf5//zF14OdPyTk6tzOQ
nW7zgO45ErAHFZ4/9ws/Z5/rrHgPA3m9/xRncIAEw3t7rmdKEuFYwte0iAEG
+lU9W7+uSYLccTbPF3uJYMNz3//pEAOR4tVrgnhJQH3r0hfpQYSu4ml3nzEG
4rwX3VH/zQAe2kdZ6t0nguhuB/e1SQZy4nps0tRrADGxD64WlhOB5Qr1gvos
AxXcivKKLzUAviTFofVRIgjxp7vzLTAQ9fm+NPFEA6i1PCUjwKYDmuLex/OX
8Dm/cpE+d80AhEyWRzbUdMCrJ1D/+zIDbdD4zfyOG8DC4sbLIisdqJ62/Lmy
ykBP7uue3U81ALvXSFvPVwcirtg9SP3KQOHFFh2j4gYgb/BrIyxFB2Q0+7n+
fmOgNde7faS/+nDOZP5lZq0OHHceOcn1g4EcnGpbjwzrQ+6us/N3Z3TgJeex
W514nWWP43aDKn3QsjxosmeHLpQNMvua/GQggeqg8aEUfZjV2XrmvZYuqNMv
UDzxuk3cp1zTAH2wyAub4rfRBYULrO178Trfk6Y3vsf1YcLOxkXdTxe+uTMR
O/Dz1zcOnPYk60NpQ3god4ouGLBeOcOJ1zlX1llURPTBw6p+urJGF0Jad7uv
4/3H/OX8kv9LD4xOGanoTuqCpbySSRL+vXwrx8K+9erB/ZPtq1fZ9MBNvvj3
Ij6fpA5LkS0lenC86eNIkIoelDwxiVrB5/nhBzP74D09EDZTfGh1QA98+ST+
ZuHzV1vjz/O7qAf1ORcrli7owUqC0TFO/L6elTTaj+LPbVtuXDmE/59L0+MM
Bfx+xU1/+nKp6kGS/fzgtVd6kNjaO7mK42F1C88JNnY9eOmhJOOJ91UsGip/
AccPv5fY2Ua879zpi26K+HcE+LBcSMXxxmJQ8s0KdKHlo/nRp8L6oNQd0hSE
43NZcvupp/hc1BzHEpYM9cGRyL2XD8ezxcboznf4HG+qrn5Ys9eHydAb80dx
/F9MjbJ7gc9978Ln5Kbr+nDldkjDIXxfztevZJ7W1oXa2Mw3p/B7M0lNnfzd
gONwa9jBCfxetfRn66oq9eF9jtwRW3wfjcCiVGNWB1aE5s6PDOnD4me68hl8
fweYRo321ulAzs1Iu/o/+tCdsOihiO+7x3kba5VUHYirtyJ74Lj7LfdbJwnn
h1oJO7NBHJcPpd3LBygGUJi2LRZwPolJlYk4Zq0DSW+zQjhwXKvn3YtLxPkn
ssjdO0tdByJvXTHZ8DeA7/QBcwWcr16ZBl6txvfkjtC3l4WPDaDJ72ePM85v
/DZyC0/HiLCjbOaCMr5nfw/1Y0dwPux5UUg5WUGEMpkK4ml8Lw0cDbJ/BzFQ
0+qftil8b/29bz07ge/xx/QsYSucb10snLdTPImAhDcjRfG9P6oaVHwc52ee
S7U2p0yIUHEv6cZjnCcEZr5FieB8zn/IZ9cxKSJsPedO7zcngcs+trdROP9P
MZ8qkVojgPimrn+fGwm4toU7vMT1YippNLEM5ynyWbfJBzhvvWvij7qN60v3
z1ZNuTyc12gKhF04zzn1SDny43oUHxs65HiTAEN+ZCEbnBfPlM3/ssb1K+ZA
P+dFOwIY7FYyt8Z5VJop+JIJrndvrARUrQgEmKwQC+HGefdQd808Q5SB/raw
PGHbRgBS32/vOzhPq6Xa3NiH62lw3Xhf7Jg23BG1/fxO3RAkXpZa2eH6i/W7
0hg47xMv+rlXmxpC/5jWTQlcr4NFq+hSsdpwdcJh9CquG+yanZoPcX2H1hBT
RVdtIFwoWZ0LMIRYq4CAetwPBKi1NrDQtMGoYtpOFNclk5Mj0dm4fwhQl5B/
za8NGUM7+zhwHTM64hVCxf1G06OOp9d7tOCkELNMCa57JeU+oRG4P1m/L3+L
fFML5BLMf4nhOmkty/w6EvczFz5/Ks3R0ILnEkRBDNdV2w/zZAz3PzORnooN
nzThXV8xRRrX4R0CvdQC3C/tbNR5HhemCdtXwhQrcd2eUyRMtF7H/ZjREXUu
giacPSL5kB/XeUdnvcPZuB87/awllDakAYZu+fsVcV8g+3W8jIj7t6eqLo+l
bmuAeKbA1u8+ZBDcu0n1wf3e8Z7ifa8JGuC6n/V2AO47ph5JbPfC/WGhmGjA
5md1OCowEl+D+xSlCwnm0rifLDaq598MU4fB9obFStzXaHHf0riN+0/TDyk/
SrTU8ZyTdOQq7oNubTYNZeF+daz7KLvsJzUQfPYvYXqeDAu+Irf9cX+r8OSM
luktNbBMP3yRB/dZuoND9ltxP3xj+LuNgpoaaF2syP++iwJ5cvtum+H+OUFm
xbGqWxXO9u7iisd9HP8JW6ox7rcrsJ8kngBVCHbafmoOo0AMB+T/KF5EcSWn
PkrKq8Lylk33X0cosP0uK6sT7ufD1ykb880qMFIgsVaN+0rXJy7Xbv3f/39B
5ZevqEB09+F2Ou5DnfImsBN4XijT61suF1UB4vbDlT64byVqGt1ZdcVzzTW+
CKhVhujIe1GuuM+dUmePoeJ5xG+y8NJtN2VYrtjPxoX74ivB3kG78fyy044/
kZtbGSZqbvzxwH10Ai0uflN1EemO0pfsXivBqV+/yCG473bhEmH2xfNR4OyA
3dnjSpAVvDvOEvfp7+/EMucyL6LODPlOErMSWL8tau7BfX10gnZL/NICUrVi
Mmp/qgiB785UceM5wDPjR6IBntcE4iZS1A4owvJPI31mPDcMiidkPaxdQNY5
/V0WXxTwnP+LPQ/PGbF5AYqFzxaQSU9Qr+FDBeiSXWdlx3PJ32uD9qEPFlD7
ffZHDLICPJGJZhLDc8zDlPhAfjxv1i9obncflYc1vbK2KTz3MKjGzSfwfCr4
nCr7KkQepisP73HBc1LRD6ObzlYL6Gk9U/d7JXnI+vtP//+5KpY3fVgez79V
Xh08Oc1y8OK+QmAInsN+tktJZcguINf7IR02F+Vgb98/hiye2149pYV93r6A
/OYvsXfyyUEkLeaUL57zHtxUtez8Oo98LL2eib+RBZZ3mYXBeC4c2WyGkEG8
vrWtmGQnC8XmQyV0PEfWvXwr/K12HlVOWgko/pGBxC//mRXhubPU1CRJKm8e
uWcYNE6nyUDLZXXTATynjg+fj9gWN4/keTXq/XbLwPcbN6Nf4bnWXmJQscgH
P+fwIaaxSWmwEfD+YYTn4Ej/H+WCJ+bRF3FlX/FwabD8mOcYjudmL8e2cLLx
PLKay5fWUpYGV6V7eYF4zt5yRqFbXGUembi6LBESpCDlu3uxMp7LQ3zOTVdx
zSOXc78nXvdLQlTwfvvbeI5fYC5llfw+hxTVjogsiUpCAYPzViKe+62l+/1o
n+bQzwPeoX0nJMDBz3mHoxMNEqroUeLVc4ikzi3qmy4O2m/bBvrdadBctfPW
24w5xHowqqN9QgyaV5+0bvGlgaQMV77o7TkUVL+eNiEvBnSd360TN2kQrPDq
ANl9DqmniAUWuYpCU1lr9dVoGuS5Cr8WPTSH1oz2OdNzRUCLayKs/CENlP8w
aVUS51DA/PX9d+aF4bxFy7aidBqkP+hjkxKcQ/pLu9WTVIVh4eh3wvF8Gmg+
yI00/j2LKvQrWDzdhcB48/5M6SsafFVS26o6NIvicmI+bC0QBCdUytNYSYNJ
hzeNXdWzaP3ysp/r0i4QPUtNinhHg0bDvdL0/2aRflgE9z31XeC0p8fzTysN
HNqunvQImUUOU2ERtz0EoOMAi69sH37O3pCuE2dmURBv6Jh5AT9U14tnrA/T
4PVPi1Y+01lUeS5WYGyRD94PHxgKnabBEa8j6XeUZ9GLcAlZEzU+6BmP4a9d
osGT28WpH7bNork0dvbg87yQblqs//IbDZxOSQk3LcwglpnQ2tg8HijsttM7
tE4DjetfTsc1z6APn/alL3dwQ0PhxmY6Ex2SikW6xApmkN+WBOdLFlzQFz5+
O4uNDrX75So8omdQpbRp87NmTgiOVa6x46SD6irRK8RjBmWxWvX9Z7YD1nJq
HwMvHbjebt3vdGAGWSK50KPvtoGH0yWOT4J02Ka9mrpFfQYdGM3p6djNAT85
OlgyxeiggIbrPHfMIJKu/gfeajb493ZfoKQ0HY7vPsjzZGEascbfdpQkbwVt
V8kL5vJ0CP9uM/Lo4zR6vKsgef31FuhoPtWiokwH8E4JO5Y7jXrObQbmE1gA
7mzElqvRgU4+6TgePo32xEpwEJ8zwYBUTtG6Jh0K2FzfEc9MI22zl76qVv9q
Jga/qTIIdGCZ5uY7aDyNOE5Y6ReabtRwTe35GadLh3Fh03RtmWlU2GFj+Ze2
VrOo1ck1o08Hf76w5uF/U2hMRKBJRPdHzZxPptcSiQ5rjh0rNkNTKMJ6PWen
6teaYypJwllkOsSkvj33sHwKpZd+GqpFyzWcp86y7qTSYbuLy8OMh1Mojuu8
sYHaXI1LRxxRiUYHNv3L3f5XplBwRPedO4ITNV9fXMz4itcL3XfdELecQmB1
5nrqloGa4kxtm4t0OphKsK1FqU8hTO7xDeOSxpragm6zVLyuxRmS+o5jCjHl
7mrf0n4FPWNVvxWA13OjLNtbpiZRcNbX9tLVD2jP1jGWnXjd7HQpIx0mETah
Xy/x3wDi4zjXZoG/l688xM4oZRJZqli2FbpMIMs9/PO78f7tf2y5WuQ7ieB8
dHmI3xy6kf/36Az+vdbp7E+WrfFzmKKyft1ZRhFVIjJUQ/x+TUeo6xqT6EMU
ZV/Qoa/o5jk1c2MDOkg52Bb2cODnqFrtqT32A/3r/zC8gc//Cn+lQ9DkBBIO
PNxYeWoNcRjZj58h4vdlPJD9q2oC+Z050O92fgMl1og43tTC8UBbWcEe4/2x
Pr5WdfkfGhDgP2Whjs/nZc0T+8sTCLMOdLCrYsI6AuS+tuD4Wfe+Kbr3wAS6
eujzQendLNjcpd8Sf3G8CQVMvWNSnEDiYp0PXzZswYauCHwZwfF5J5abI2Zz
HLkVp9G2mG3FLjU3+F0Wp8MM6YkpY2Acfeh23ifUzIZ1mKvVlwrRYTUua1Gy
eBxVDqrWzR7kwK7wGo6+4KPD9V1Zx+XujKPVpG+FXh3bsD76y6GjO+nQF5Cw
ue48jkIJ1VIvrHdgdW8kW4rZ6RAfMYyeUsdRQM8DkZQeTsy8Z7a6hpkOX/ps
wxR2jSOPpOR8fVsuzE+a3Bi0QYOgVyaG/oz//07KO+bfz41lbBVYW/lOA5hx
evffuzFkMUeY0i7gweKCjc7wL9OgNPTd/SepY2jKKNnQ24MX0253kpufoUFR
xSbXFe8x9PPpm7Xb6nyYqMSA6aVRGkwks2aIHxxDfQ3JqmeX+LD3GqNzz/pp
4MkglKXIj6EDtjs/8RTwYzdYr0kkttPAZCLx2uyvUcTiEcQV4i6ASUT5/yU1
0iDLkYWy5+ko0iwX6nurugtz1r7+351qvP/Q6ihLm1HUMlhJKZ/fhZncn5O9
95oGljqlxjtZRhExmfeAf64gNib0K3lfAc7DMUnY9ZcjyEfnhsC6qxAmHZmj
9DqDBtXhnxySHUaQ2W3DTEMFYexC8bvx7sc0qHTJvnph2wjic9zDrj8pjM39
mp3JjsHnc4Th8uP1MMpI8bNkpItgd5cu2KiF0uDut+M7CKeHUYxnZOyJk6IY
cSbUzMWfBk+bbUxkuYaRhd+2vlAxMcwkVmLC8gINoqe/fP9YPoS+snnpnxoQ
w1x9fmBfTtNg0YT5l/KZIWSrLtmwmiCOjSXfC9t7lAYCviwaGM8Qyp9xvk+w
ksBm/tA7D5rT4AKTvB/P289IkxZWLrNTEusW5zPZjnDd/IJVJJ35jC7Y1Ryo
+SCJaUbPsF0n0sDFfqR3lPszyk096MIRKoXd8jxpkK5AA7k25Rdj5YMo3t4g
OlBKGjNfG9/wF6aB0tAXxTTnQSTYqVvbFCCNPfyd5s+xgwbY3efyIjsHUcvp
fSMLn6SxEuuIPvO/VFAfuRht/eYT4rms/GVIXwYr8z5iuGeFCjdJC8bmjp/Q
HT5ejvT7MhjX2M2PX8aocGrRjcDK8Qmp3e4g6KzKYM3xB17adFHBIaODElQ4
gE5UNQQ+OCCLKUaW8nvWU+HT5+T9FccG0PC7kY13ubJYr/ptaUoJFUJPDuwt
ZxpAJebZlfWsctiJD7uZarKoYPVcXjAgtx8ROAw67zrJYed/aY6sJVBh//Xn
WVss+5G63kFzuUo5THzX0Zm5UCq0SKh9tvzVh4T/0GghQvLY1dxbe2OvUiH7
30imS1ofujn5r7zgsjyW0GaosuRMhUzOe/Nobx8iGCr1prXKY8aZ9TWb1lTQ
Ur/7aHKxF+Vd+5pxTFkB25+jQGraTQXHp+mJlvG9KKDCiPTplgL2TV6uzlwb
93WPhIZuk3rRni2Z+VLDChjEU2NCJamw17HCPGqkBzmV7eNRM1DEBr+9aL3K
SQXW7c29x0J70OVvosHrcYrYVoMrxeLrFOirZXH7rtKDeMfyee8uKGLH7tMu
BsxSIJIUu3qivRuN8WPD48ZKmNlkgEFCDwXoAjwnH17tRtTp3o1fKUpY8V87
5FJLAR77hCdpIt2ooErydtsPJUx6Z+nbpecUiP30KMu3ugupuocnulgoY1rT
mhMaSRS4+5DphKxzFwry1LUof6qMSdoKzCuFU8BfR7z8CXsXKt3NVdv8Txnz
CbrE/vkSBeLsU/NWn3Ui2fxyrmRbFUxAjN3b9AQFopQSpQQtO5H89zQbxRcq
mHqv+XlPMwqoxoVy8n7vQN3kxUKPrarYyxh36YM6eJ+thNMTjzrQf0/jjTwd
VLHBApPOGQkKWNS18t2hdKCufGsVpVeq2B+nS6VkDgo8bKuQEa5uR0qoJCxx
mxoWtULk2veVDPtO+qS1sLajGCEu/3pHNezMj1BeviEyeIwp39Izb0OcA+EK
Wa/VsPBnfP8evCND8uPWVzb3WlG8idAL8g51rEGZxNv7ggwNWhui6v0taNkv
Wj/cSR2TyWCObH9EBqfQkSdV4i2okClqMuy1OqaZp5oVFkyGVT89tR2nm5Ef
f/QgabsG9sVNIuOXGxki6vc9FcxpQvqF87vTTmpgXONf6hSsyOBXtbg+vvgR
Ldf2Ya+LNTCalKcpjyEZRIie/Be1P6K3dNfNADZN7IAv06VSaTKYa6UM1lz9
gC7tiX763U4To5R/uCnGQYY7PVWUvrJG5E2QdhJ7rolxud6tpK4YgrJ8pGzJ
n/dI5+2I7eqmJlYxUeMi1mcIW7tlrh/H3qMSJo83l621sLq8a9WllYbwRJSf
2BbyDjUlHXn2X5YWtvV6MBdfpiGMRe7X5WpsQGm5As4BP7Uw1ShKkmqkIRT2
812U2N6AgpbY2ZjltbFrzypzmC8agtgbro6/B+pRRFnbwuMD2pjgjYrARzaG
wJGts7cotg4F57D4bfXWxvqS4pyXDA3hdGNDpWFXLZL33m1ikqqN+RXT/2OS
MgSz0oMKiQK16EdO5rL9O20srPrsjZ4thtDnkOrZaQtINqZquzFDGwuVsTJ1
myOBfsTNbR8JNeg0KV33nwAB22geN6psIUHR4sar3NdV6O6VQbZoKgHLO/lf
ZUchCfrSUsv3GlYiIviLLzkTsGfmpZvZCSQ4/bb0d2ZlBZo228EreYeALf+Y
P0r1I0HWheXDjagcJfSlBMsUEzDb9lTehOMk6CjWzH1VV4r21Fex/xwgYEne
Pf7P6STo3J7V57H3DTq0eMM4eZOAXW1VG4mQIcFV+ouan40lKDvFr5NHkYj1
iQ9HK7KSoEW83/jI/leoKLT2kO0BIuYqV9kTPmMAxbQPxtEtRUgn5beD+2Ui
tkLQ35r/wQD+fMTSn1gUIuA1eXzoMREzwqwuxOUbgEa44FXF/54jbeLh/1iq
iRgTyzMncrQBMDJmJnuz8lHxoSPCoZNEbPK3r0aupwE0KvhaHcnNQbNPt6V1
c+hgo3duKQ5aGMDakGJQwbMsRDcq7V7V0MGYuFTTOrQMwGNARG3yxX+o57PW
8c/W+PP9p2bv8BhAif5+IotLKjKr6uiL99XBBK0Kj3B+0Yfqsqu84ucfIem0
kHnBFB2M/E+DZt2pD3x3cq7Ied1DQsE1+mdBB/sUHfr1RJE+OPHceHloKRxt
REaeDpnSwf4NM5q07unDWL0rY2LVG/0PIfPeqA==
     "]]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], Thickness[0.002], 
    Line3DBox[{{
     11.684649987044317`, -31.570288692123505`, -0.0010415461808919169`}, \
{-14.078555725315162`, 38.75145915684063, -0.07507514727601183}}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.002], 
    Line3DBox[{{-20.013456692589536`, 22.418791544392253`, 
     0.00047867318785196206`}, {19.892629774645666`, -22.567135508606945`, 
     0.005356680331190383}}]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], Thickness[0.005], 
    Dashing[{Small, Small}], Line3DBox[CompressedData["
1:eJwVV3k0lW8XlSGzTJnnmXvNXPO9hzsUigZDotKgQYmkfjJEKiFFyFBRJKlU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     "]]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], Thickness[0.005], 
    Line3DBox[CompressedData["
1:eJxdeXk0le/3tihzMs/DOaZkHs7hOM45z0ZEpUGD0mAqIZG5IpUGROZKiWRK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     "]]}},
  Boxed->False,
  PlotRange->All,
  SphericalRegion->True]], "Output",
 CellChangeTimes->{3.889427729273509*^9, 3.891017628206709*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"b01f7dc2-8c4d-4251-81d7-5f895eb3052b"],

Cell[CellGroupData[{

Cell[BoxData[
 Graphics3DBox[{
   {RGBColor[1, 1, 0], SphereBox[{0, 0, 0}, 3.]}, 
   {RGBColor[0, 0, 1], 
    SphereBox[{6.018673911707431, -29.600708148802106`, 0.46980980066264977`},
      1.]}, 
   {GrayLevel[1], 
    SphereBox[{-20.267394500921334`, -20.11523901824606, 8.015589193357108}, 
     0.7]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005], 
    Dashing[{Small, Small}], Line3DBox[CompressedData["
1:eJxdeXc41e//vxUSspNk7+1Yxxk8i0KUFCWEZFNUindJpCQtpUEh2atCsir3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     "]]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005], 
    Line3DBox[CompressedData["
1:eJwVV3c4le8bt0IlO3vvzTnWcdbzRqGUEBUNKkkhGlZFZCQJScPMFyGpkEIZ
t5WyV0j2HuegUonK7/39da7rvp7zvPdzj8+QP+ltd5qNhYVlhZWFhR3/Tb7f
O3WB3QBiWfUZhh5GWMiTby9bjyP0byFVIV/VAO46xIeSrYywfkP9ebu+QOTu
UER/aWUANenvYzg0jbAS4zyHuMEo5Kw7OhDibQBeO/KOJ24xwqKpmcn1bgko
Zf3iI5l7BqD+Jttyfs4QC9uSJUl1foQSzxLEo94YgE1nYyrnR0Ps4bHdVemH
0pGm88mNis8GUMxd/nwu1xDrOLketaiaiY6ytDIr/hiAW+nbtnuRhhgx/27X
d8UnaPV1+c2bsobQ5Pz0wKbThphWRe2NPtk85Kj/3UfK1BAqF9bi6WaGmOY3
qdG7ks+QxtXGfVddDeHbfOUXJG+I6dT/0JMUfYFkJ7jrsiINIaz90a3NGwbY
5FTVkOGtQvREhM/vfp4hPFP7uJwyaIAJnJkfr+QsRgliZTw2TYZQ+EXB/Ve5
AfZ8mrdZPvwVqjU7q929YAibj/BZSD00wF7E7S4/xvoape3hvy6zzQhyvsRM
bblsgEmat3Z4Bb9BKYZKTwk6RhAUpZ1aZ2OA/S1jGFivl6J0l5wDPPuNACsR
qTfXNsCy/ZU2r/uXIwN/RdUX3kZguZmlNHGzAWa8WfmCz8pb1ORd0iISbwQf
Sontz6f0sQKuofh8nwqUHbHB3FVoBMqZUWcSavQxcVpYzBNGJaogmBhSOowg
+qbHF9M0fSy2LiPqmHs1uqOgvO/nkhHUavVEVgfoY4v3tjnMXAAUQhQd8+Mz
hj1hu99z2+tj38xlb1/RrUHWx1ZSK3SMIaFt5KeMrj72a+FU4DSjBumW6Gs3
7jOGe43Gfmxb9LHJM7+I6vm1qMpmhP7A0xhSqoIyX00Ssd9qpGbsTB0qMr9/
Xf22Mex95z5ArCZiV2ktDppK9cg8MSot5KkxrCabBIUkEbFNHjnT06P16IrA
DYuURmPQ0X47n3qJiP0z35pwIa0B/T02phU4ZQxJ1tSwqH1ErGD/A8+Pju9R
W2vaX3F2EoiwJeWaqRIxPU50m7G9EaXaW5wLkiOBcpRueRsLEVvkPs7+ubMR
gTeXUhaNBCmXJ8U1BghYl07xfMydD4iDL3Mw2gmP18ppHXxFwCSyTh/i3P0R
rV31MzfwJ8HcdIfdgRgCFssq5GLG0YT+ohDhx/dIEDR66qv8aQJ29FKTpGl1
ExrlPrzW9JIEVyyaPGppBEysRSST5Uoz0owxKChtJsEJJ18VQxECtjOXbWuQ
QQviPLsw7DpDghebD0ZeWdTDNCKlvV8vtqBn3N8suthMoIJ1cDnhvR5WxQyZ
yc1rRReCjqdtSJsAy6uV5uB0PWw8/NMdu5Nt6LLL7H0GyQSeH94STPfTw7KJ
h6+9kmxHFc/nZh8dMIHcv2znu/bpYQnUkdYPPe2Ike5szXHeBHquI3aKsh4W
Vrxk/cG8A8WELwTrRJlAjqKh1ddVXaw0nBTOkdWBKtK69UUzTUDEr/2KaK4u
ZpChsV1sowMFL7KrVr0zAZuCSbc5e11s4moQP9uRTuQpzCek+MkEJiV/j51h
08X4NptG1LzpRPPiuq92LZqASdG16nsvdTBF06kbDoJdaMjCvE6Ziwyfxj90
ex3VwRTKieKVXl3ozY+RjVpZMjz4T2blJ7cO9lP50OFfH7rQlsMEFWkSGd7v
yv6p+1obC1sZt2FX6kY390ms6NuQgS/wVLH4CW3MqatFaDS4G1lrqKhxuZPB
XNpio4RHG6NSLxfHfO5G5aExoQ+uk8FQT/wNW5kWZrg1m85t0INCFgkw9oAM
9IKQQvZTWtgx1vtNtrE9iPo5L3v2ORm+n974ULZNCzM6uOzuPtuDTGnE5fx6
MtRPLw0olGli0aZdWlamn9BnjypXtS9kCNoZVmt6UhNbvN2i/jvlE6ptZda7
fCXD6I+qo+I8mthLvrlLF358QoJZAj0HuCigk33lZu5rDWzPvgLZV9a96FCN
1kFWaQowfh+TXzyugdGWRU0rc3sRn80K31kiBXzOD29e5NLAXByfL8ey9KED
YR3voy0oUMlLk88rVMduqPrsUHXsQ2P2Q5jbUQqcNQu3lHZUxy5Wz+6JKOpD
1pSFnes+FIi6F3HCmlUdO9itopS3uR+Fj1xP3h1BgXHXPmvqUzXMZK5uMvZE
P/Lu6N1sm0SBXeVd32ds1LCl0alsUnk/+mYwfkTgOQW+z8Yb2K2qYmqBO4Ky
+T/je2TlFA0UOOc09+PqY1Ust1vqZueZz6hty+X2d934e429pd3MVbGKVdvB
qqrP6O6cb+STaQqoynjfFWCqYDWOtg89tg+gIS8lK4vfFJjsYpCu31PBXtgp
dfd6DKDUCZ75jK1UCJ3PWH9pooIN5Hs/26gZQAv6/nrF0lSI9f1Zkz2ijD0R
9qNOiX5BlGg3xhVdKiTncvsej1DGxAsksiK9viC/X0mMNYwKo1cz/g1pKGNZ
lyf+jNd+QaZCd1iIdlQ4f4i4W6lDCYv5tH7mt+ggCk4JWJU9RYWKvC+I6KuE
3dpuzP7RcxClChx4Un+JCmnhLm3cEkrYco/gok3NICId7OyXDadCA6Y+llel
iI1EllvGbx9ChaZnThMSqXB3K3Za6JQitnuOwyDy7BCqxSxlfmdRISfU2nI3
lyJ28WpIJ6FyCJmMnunze0WFeiwlwOqZAnblu4dZAv8wyj935XR+LRVcArim
JPYrYOeLKwtyTg0jCd8fafc6qfDanyeo7Js8xmesTDj/Zhi98+Y/RBylgp9J
uZ7yA3lMKW7bjxnuEZSp33AmcpEKRsyXyydM5LGoxsfSQkdG0OXYjty4P1Rw
CFZ84T0oh+U5NXQsFowgtpbipX1baPBO7JPT/uty2L00DcMr/0bQEq1QrEaU
BlbPBOZYFeSw6vtyJgOqo2hnTeefWSUavGk//pD/liz2XVX+sLXNKOrYMeXX
QKBB7A0RxvtWGcyrVIwnKWAUFVKCTx6k04DYxlOmJiiDLRguzZVnjKJE8s+U
lD00+BnENWl8UBoL5VqJLPwwir4d9GK5f5AGlmVNjj+TpLD9BiMB15ZHkXFR
k5fpSRqIzAlxuA1JYt5JXQ7SYmMI5itqs7xooJCX2BYlJ4n9FjtSkoDG0JvU
t8NlATSQSWE+cTklgcl/vKA56DaGelvYMkPDaPDhwFP/pSfimJ9CkN3vO2OI
wyWN+fcODarUjYnGs2IYTduuZq5kDFVEH8nSfkSDaf7pehMNMezNc0P+51/G
0GHU/4Q/kwYnPUZkf3uIYmn7h/pM2caRXnJAf84zGnT0yRv4PxfBHnX4FOWr
jSMfK0/Z5RIacPy5+v314nYsRf220aT1OJr/99yZUUmDWqubNqW627GLpRTW
pcvjKLyG/XrKe7zOzZn0IB9hTOokV0FT8ji647px6m8bDcidzKLNRUKYUd1c
px+Mo97hfz8E+mjAU2X6+PhXQcze6iDv96lxFPxMS/rzMA3Yygl/ggiCmJGb
yV/61gmUoBJSazdNgy2n1qvOXhDA1tN+k530JpDPTGV7MJMGCVG3hxWL+DFy
ZYDrTocJ1CsWoHtshQb9GTPZR8f4sOElYdG/gROorI23lblGA1Jri7KICy/G
MfF0OSx9AnU5FibqsdKhxfIEIWCYB3s0cTeuv3YCLT9yvKTMRQf3cx5vI49u
xTrWcxLWpifQuEXvwRYeOuT5dJXsGtiM+fPtTJrbMon09tZoKwvi91Tf215+
iBtb/7nL7InOJArcCJ/RFaVDlHhZ12QPJ2aVxEPQtptE1/2PXGZI0qGnzXKi
xXYT5sdxjT3UdxItN1s3OMnRQZi5E/m2sWOcEX+PZDyaROWOJi1XlOiw0/XB
yNgeNkyiImQw+t0k0uV4f3WvGh361bmqRBpZMO2Sa6rY8CR6e8mnsV2TDthT
z3zdyH8odWV5pJplChHtIrI4dPHz7hI7uoLWUds9t6ebFafQt3CFTQsEOrA0
uZOkfVeRgOVXVeldU+icq/H4DQM6+JQKRIt5/kD8/nosa25T6NLXcEKLER0y
xuQJLSe/od9mNn2Po6YQgTt9/j2JDqPxDQdCiheRceqWA7z5Uyg2fmbTJTId
QvxvTaymz6J3pnniu5qnkFPBo2sdFPz+nLu8grfH0Z/PrF1mjCnEM/HWcoSK
nw9+llvK7EfOjBDFLdumEauVxunHNDwe79Tx6NZHZPld7s1D7WnkU3i/lZ+O
5+8T67nXJwzlHfUhMvZNo4ny4GB9PI4lKVbxSDVWS8Td3cF1fhpRt5B9uf5/
PoHv0/PSvupzDMqd2TvT6KTL0ssY/H7stuzvp8tj1WVdFdVxz6eRZ0mSdh2e
j02Hib3nptnqPymrYX9a8O/acS3m4/nzm7GubJNYrOZM9YjQYUyj+m+fv5r9
/71CXO5I9Fv1PylNH+WtM2i2PZIci9cnwP+j9yH5H9WaTtPLo+ozaLT8YNMt
vJ4BF+p5LDRXq80CZ0pcLGeQqapbthFe/8NnzpM5DderlW4In8t2m0HJZk9a
EvF+FQ7uW4mh/6vutl+uehY+g4LW+yyydeiQOseVMpfFAjNpKSf9MmfQds4H
kqfxeagQbQ9yV2MDm4+fODhgBhEZe6z7VPE4f4pcdQE7XPj+18F+aAbN8xjN
rCnSQc+yOnRObxNE9AtxnVmbQXmPzy22y9LBc1f744kSTjhaW/aRIjqLhl61
ex7E51lu8GngUxI3HLmsZ9OlP4uEdeQ8Y0X+n384r3HFZqjefnKfhs0syqqd
/+kvQAeOTT+PRaGtoCvx+bKZ5yyqZ94VE8L360MXm3tSLQ8Eqb2/Ih01i8zm
rIacOekwqamq7baLFwo2NoTKsmZRxmMFu+MsdHCZOflivpEPtJw4fgpWz6Ki
1O/hvPi+V1hl+gk84Qfr9tVe7YFZBOve4T7faeDkuua7yU0A2oufeXH/mEV6
B6Rcwhk0+JORcbBdRRBef0u8kMk3h+LTbNT2TNHAWsFewmtGEIy/9yavq88h
khxpsWaIBv+mCHWDuUIw6I4yhXbOocP7O+sWPtGg3u3tASl3YcjRs9wxf2wO
Rb1kvmtsxXmB2temrrYd/FXEiNf951BHCWHeoYEGL8pHjdlnt0PQ7zDdrvg5
pPVY+NSDCjz/2KyEnFwRKPnH+2P86RwKsx+l3HpFgzJXtwmBM6Jwi5VBL6qd
QzqkomidfBrkBC3pmKmIQZDgv4/UL3Oof8PXLTKDBip20VdIU2Iwd+DzgYjv
c+hbxNJ0/AMaHNbZ1rKUJQ7P6+uSo7fOo8SkQiXrGBrcaBtWP3NSAtg2vzm2
V3Ee9TZLm1SF0mB+bT05VU4SdhCOHm0iz6Nishd9zI8GVxT+qsQOS8LTYJFD
HHbzyNIxZ3+pBw1GVyR7TVKlQEZljXfNfR7lv/4vCnOhQfA6qSjNURqW+bt2
Pbs+j2QquDmD7HG+IIzVlIrIQGiKbJXog3k04O8w5WlJgz1JBwQju2Vg0VaS
ggrmkZ5t105+Kg2SeyKfc8bLQnr+6xD52nlk/THJ7IwuDbYeedguqSIHH6oe
Hqjqm0d2+g9YLyrQIGl+NHBruBw0sygFbmfOo9VzoY/1ttPgUxw62jkmB/HL
fqUqbAuoOGqSnsVFgyMl5UGeSB6yWs98+iqygOj3RNmaflOh7mr11JdUedhr
cSvZT3MB1ejs4HmyQIXWW9qpMmvycE1Do70ELaA9uw+GGgxRobRx/1P9QwoQ
t+0gteDAAhqtF48MaKNCnNrkdokSBZj8/enZ0TMLiF9WCrtQjZ/3lF7o4FeE
g0KE2YYrC2h++7tPMoVUMJt8QjzkpQgXac8rZu4soJA98udDM6iwTy/z57OP
ihBdtf9HTcYC+jm6i5AUTwUr9pIdbcpKcHt06Lj9qwW0KM2wcAuhAn30j0xl
qBK8iBt6n96wgJJZs77MelPhQb9csv+QEjT/vL+e0beADEbrReSdqcC9e3f1
H5IyxIrztzjNLSDuVT8lPmsqyN9XTbFKVIZznqLcLWt4nhxP9V5RqXBl7Bf5
1JIykM6RQ1a2MtDBTmH3bZpUeNMSVmC6RwWyVJs39UgxEKOetiotTgV+VeV/
s9kqQJ8cOXdOm4Fu+/jwTXHiujrvA91hQwVOJh24UUpjoGnR2sGTKxQoe7Ic
FOmoCs8j38u+28dA+ST++IdjFFivLW2++koVLCvSRX2PMZAOH4tTWBsFLHO6
SQbb1KAukxtNeTLQA7F/HirvKGCT+7D3hZsa5IT88th6jYFyEmirIbkUMAj+
9Wa+Wg3gr7LvTDQDbfpdSrh3jwLBy7cY02LqsDlbhBiYxEASIVp7j12ngNO1
29GZF9RB4bjwVchloEt3ZK+NnKOAHdtYtlSTOiR+J6pXvmagBu2Bn+IHKSDn
JWFjr6ABaTf2i3jXMdDFqLPfeHZQ4MUh3/8sr2hA0i9+6d4OBiq2SX9SpkmB
xKKRF6udGiBzY1bs2xAD0Q14LKVFKEA6sRZ7Sl0THnIJTtfOM1CuxWZBCgsF
rk1KOkaFaELMvcQTlr8YiOrznCo4j/vTJTtltz5NCG4wPXuDnYmuNHeyZnWT
QYL7LM8fbS2wpL774sPHRFRh/lRmBRkKFaZUd4drgd6G+yMhSSY6uanW/NsT
Mlwl8SbsHdACz8mw6+dUmMjgLQu9KJYMMiPM05v0tMH0B/9FXwITOfNkV2n4
k6Fp0K76YoQ2tLSP2xpQmShsaQenszMZDrztfntvQBuEOZNZc82ZKLhJ+4C1
BRlsDnT6ntHVgaUrT1xbbZjoaJv/5KoOGbJPBfIyw3RgZ4Wpc64TEw3uYfw+
LkIGJaGPWYr9OjDiFNxr4MpE71iEekL+mkBqcJzDFi1d+IAMCn29mCjxgk7J
8UkTqKL77My4rgvaG3zdZ/3w72pTBlebTMCLMXV3sksXitTuqAhcZ6LDMkux
+4vwuK2C3oKgHjjc/5XgcZOJ2jrK+E49NIGb6PhZMlUPBoo9WAPjmGjLu6pM
/SATuMT7ItL5tB6ktfQeMXnIRFKhwzE1J01gPOqWhFOsHjBsf8UUpDMR0bhA
aJulCWgTB0rVS/VgSvxYSNcTJgr870KQiLYJ8If++do6ogc12WcVnhUw0dsL
2gLDAnhcvOaoOTcB0pxsXIxeMVHXjQQR158kCGQ7H5OgR4DaRhG1y+VM1CvA
1Zs3QALusertxYcJYN2b6O5azUQ8P7IeFVSRYJ/6wp3sEAL4bvIV4GpgoowO
/TzvTBKE26dFn80jAH+6gdDRJnwedhP3f4sggbrQv/9YOvD7JxWdT7UzkaNB
c7/BWRJwBReeO/sLv2e324xUDxNdeP853ngvCYZ29VzNkiHC4cRv6VH9TLRa
NVO3pkOCvDFOrxe7iGDPfy8wZ5CJTBK0qoMFSEB959p7y5MIXcVTHn6jTLTt
bkxH3XdjuO8UbWN4jwgSO456rE7gc8j7yLzpkzHExt2/XFhOBLZL1PNaM0z0
/Ea0T0KpMQgmqwyujRBBVCjDQ3CeiejPd6dLJRlDjc0JeWFOfdCR8j2Sz8Dn
/5Wr3NkrxiBqvji8rqkPPj1BRiuLTPSHJmQZcMQY5hfWXxbZ6kPVlM3PpWW8
PvcMzuyhGoPja6Rn6K8PUZcc76d9Y6KbxdYdI1LGoGT8az0iVR/kdfp4/35n
ot9ud3pJf43grPncy6wafThyavg47w8mOuZS0+owZAR528/M3ZnWh5c8h290
4nH2nc5bjCuNQNdmn/nOrQZQNsDqb/6TiYSrgscGU41gRn/T6fe6BqBFP0/x
wuMO8Z/zLK4ZgfXTiEkhewNQPs/RvguPCz1ueuN/xAjGHe1dtQIM4LsHC7ED
v399fe9JL7IRlNZHhvOlGoAxx6XTPHh829Iam7q4EXja1k1VVBtAWOsOjzU8
/7i/PF/zfxmC6QlTdYMJA7BRUjVPxt8rtHQ44vsnQ7h3vH35MqchuCsV/17A
65PSYSPOXmIIR5o+DgerG0LJY/PoJbyeH3+wcg3cNQQxS5UHtnsNwV9Q+m82
Xn/NVaGnAd6GUJfr/ZZx3hCWEk0P8+D9KihpdBrBz21ebFzaj//PtelRpjLe
X2mLn/68GoaQ7DQ3cOWVISS1fppYxufhKzv/MU4uQ3jpqSrvhedVLBGudB6f
H2EfyTONeN55U97uKvg7rvmxnU/D543duOS7LRhAy0erQzliRqDaHdYUjM/n
ksyWEzl4XTSdRxMZJkbgTOTbJYjP8/71kW0NeB1DNZY/rDoZwUT49blD+Pz7
pEU7vsDrvmv+S0rTVSO4dDOsfj++Lx51S1kn9QygJi7rzQm8b+ZpaRO/65mI
tili3zjeV12jmdrKCiN4n6vocBDfRzOwLtWe0Ycl0dlzw4NGsPCFrnYa39/P
LCOmu2r1ITf0lmPdHyPoTlzwVMH33fOcvZ16mj7crbMle+Jz91vxt34yjg+1
0o6WA/hcPpDzKO+nGENh+uY4wPEkPk0+6rCdPiS/yw7jxuda6+nd+CQcf6KL
PHyztfTh1o1L5uuBxrBC77dSxvGqxCLochW+J7dFv78sfGQMTQE/e07h+CZs
rzifM0qErWXT59XwPfu7vw9zwPHw04tCyvG3RCiTf0s8ie+lsbPxk9/BTNS8
/KdtEt/bQN8bz47he/wxI1vMFsfb09antlC8iIDENm5J4Ht/SCO4+AiOzwIX
auxPmBPh3d3k649wnBCe/h4tjuO58H6/7YdlicB51oPeZ0UC192c76Jx/J9i
PVEiu0oA6Q2DwF53EvBujjz6EueL6eSRpDIcp8hn3Cfu47jV0CQUfRPnl56f
rTqKT3FcoykTtuM459Ij6yyE81FiXPigcygBBgPIovY4Lp4um/tlh/NX3N4+
Hm9HAhjvULWyw3FUjiXkgjnOd6W2whq2BAJMvpUM48Nxd3939RxTgon+tbA9
5txMAFLvb9/bOE5rptlf343zaUjtWG/cqB7cljj4pUHLBKRflto64vy7o8+N
xsRxn+gd4FFlYQJ9o7qh0jhfh0hU0mXj9ODy+NGRyzhvcOl06jzA+b2mNcxC
xU0PCOdLlmevmUCc7bVrdbgeCNJsrWej6YHp2ylHCZyXzI8PxzzB9UOwlrTS
ayE9yBrc1suN85ipg08YFdcbLQ87cq726MJxUVb5Epz3Ssr9wqNwffLnntIN
cqguKCZa/ZLEedJOgfX1LVzP+Hz5XJqrrQvPpYkiGM6rBz/MkTFc/8ze8lKp
/6wD73uLKXI4D28V/kQtwPUSX6P+8/gIHdi6FKFSgfP2rAphvPUqA+maOmjx
EnTgjIPMAyGc551PGR54gusx12ct4bRBbTBxz9+jgusChW9jZURcv+VpuD6S
vakNUlnCm1b8yCCya4Pqh+u9Yz3Fu18TtMFtD8fNa7jumHwovcUH14fFkhLX
Nr5owWHh4YRqXKeonk+0ksP1ZIlpndBGhBZ8aa9fqMB1jS7fDe2buP7c/SH1
R4muFu5zkh0u4zroxkbTYDauV8e7D3EpfNYEkWf/EqfmyDDvL34zENe3qo9P
61rc0ASbjAPe/LjOMhgYdNqE6+HQoRV7ZU1N0PV+m7+ynQJPFXfftMT18wP5
JefKbg1w/7SdNwHXcULHDlLNcL1dgf0k8V/TgBCXLSdmMQrEckP+j+IFlFBy
4qOMkgYssm94/HKgwJY7HBwuuJ6PWqOszzWrw3CB9GoVrivdHrteuYHr/xtf
UfnFS+oQ032gnY7rUJen49gx3C+8NexdLJdQB/0tByr8cN1K1DG9vey2gEqu
CEZBjRrE3Lob7Ybr3Ektrlgq7keuTBReuOmuBotv93Dy4rr4Uohv8A7cv/A5
CiXx8anBePX1P564jk6kxSdsaCwgoxE6w/G1Kpz49YschutuV15xVn/cH12f
6Xc8c0QVskN2xNvgOv397TjWPNYF1J2p1EliVQW7d0XNPbiuj0nUa0lgzCMt
WxbT9hwVXI+eruTDfYBX5o8kY9yvicSPp2ruVYGln6ZGrLhvGJBKzH5QM4/s
c/u6rL8qg7bTL66nuM+Ie3pNpfAZ7jd7gj+ZPFCGLoU1Di7cl/y9MuAUfn8e
dd7jesgkK0OGfAyLJO5jHqQmBAnhfrNhXmeLx4gSrBqWtU3ivodJNWs+hvtT
sedUhVdhSjBdcWCnK+6Tin6Yhp6ynUc5dSzd71WVIPvvP6P/+6o4gYwhJdz/
Vvt08Oc2K8KLe8pBYbgP+9kuK5upMI/c7oV12HsrgnnvP6YC7tte5dAivmyZ
R1fmLnB1CuI+jRZ7wh/3efdDNWw6v82hABufZ1JvFICtIaswBPeFwxvNEDaA
xze1FZMcFeCV1WAJHfeRtS/fiX2vmUNVE7bCKn/kIfnrf5ZFuO8stTBPln06
hzwyjRun0uWh5aKWRT/uU8eGzkVtjp9DSgLadQE75GHlemjMK9zXOkkPqBT5
zaGKA/tZRifkwF7Y94cp7oNvBf4oFzk2h75LqflLRcqBzcenzpG4b/Zxbosk
m82hA7P5crpqcuCmevdpEO6z2U8rd0upzyFzN1cGIVEW0lY8itVwXx7md3aq
kncOuZ/9Pf66TwaiQ/Y43cR9/DxrKYfMyixS0XQQZ0jIQAGT50YS7vvt5PoC
aJ9n0dpe3/DeY9JwLODUVmcXGiRW0qOlqmYRVYtPwj9DCvTetfX3edCguXLb
jXeZs4h7X3RH+7gktCw/bmX3p4GMPG++xM1ZdKNuLX1cSRLo+r9bx0NpEKL8
ai/ZYxbppUoGFblJQFNZa9XlGBo8dRN7LbF/Fv0x3X2KnicOerzjEeUPaKD2
h0W3gjiLQuau7rk9JwbnrFs2F2XQION+L6esyCwiM3ZoJWuIwfyhFcKRfBro
3M+7ZfZ7BlUZvWXz8hCFnRv3pktf0eCbquYmjcEZlJgb+2FTgQi4oFL+xgoa
TBx909hVNYP+XVwMcGNsB8kz1OSoBho0muySo/83g8gRUXx3tbbDiZ09Xn9a
aXC07fJxz7AZ5DIZEXXTUxg69rL5K/Ti9+wK6zp2egbdEAgftSoQgqo6qcy1
IRq8/mndKmgxg+BsnPDogiC8H9o7GD5FAwcfh4zbajOoOFJawVxTEHrGYoVq
GDR4fLM47cPmGcRI5+IKOScA/1kUG738TgOXE7JiTfPTiG06vCbuKT8UdTsa
7l+jgfbVryfjm6dRx+fdGYsdfFBfuL6RwUKH5GLxLsmCaRTCnnjqgjUv9EaO
3czmpEPNHsW3njHTqF7OovlZMw+ExKlVO/LQQWOZ6BPmOY0KOGx7/7PcCqu5
NY9AgA687zbtcdk7jQ4jxfBDDZvB0+UC92cROmzWW05j15pGe0dyezp2cMNP
7g62LEk6KKOhWq+t04hkYPRBoIoT/r3bHSQjR4cjO/bxP56fQjwJN51lyJtA
z03mvJUSHSJX7IcffpxCGdsLUtZes0NH84kWdTU6gG9qxOG8KTR4diMon8AG
NbfX48o16UAnH3cei5xCe+OkuYnPWaBfNrdoTYcOBZxuDcTTUwizfOmvYfuv
emLguwaTQAe2KT7BfWZTSOyYrVGhxXo17+TOn/EGdBgTs8jQk59CZR32Nn9p
q9UM3U7eaSM6BApGNA/9m0Sz4sJN4gY/qmf9snwYJDqsOncs2Q9Ookd2a7nb
NL5VH1ZPFssm0yE27d3ZB+WTqLD082ANWqzmOXGGYxuVDltcXR9kPphEGbzn
zIw1Z6tdO+KJqjQ6cBpd7A68NInio7pv3xYZr/7+wjvzGx4v9Nh+XcpmEo3a
nr6axt5fXZylZ+9Np4OFNOdqtNYkClF8dN2spLG6tqDbMg2P6/KEpTVwTyKW
jO3t7O2X8L5p3biGx/OibdpbJicQS/a39tLlD2jnplG2bXjc8mQpMwMmkNy4
UZ30f/1ImPtsmzX+XcHyMEfT1AmEqdu0FbqOI9udQnM78PydfrBfLvKfQIXn
YsrDAvD9y/97aBp/r10G1+NFuwmkxxKd/ev2IoqqFJenmuD9tRimrmlPIIim
7A7e/w3dOKtpZWZMB9mjBwt7uCdQmYbtzprDP9BG34ehdbz+l4QqjgZPjCP+
oAONFSdWEbep09hpIt4vs/4nvyrHkc/pvX3u59ZRcrW4c6guPg+0pSXs0TjC
OB5dqbz4D/ULC52w1sLr87L6sdPFcUS1CzrqWMmCdVxT/NaCz8+ab6jErr34
Pfu/7JPbwYbNXvgt/RefN9Frkw0sKuNITLLzwct6dmzokvDXYXw+b8fxccdu
jCHX4nQau+Um7GJzfcBFKTpMkx5bMPvHUH33qd2izZxYh5VmXakoHZbjsxdk
isdQ2YBG7cw+buyygMnIC0E6XN2efUTx9hhiJH8v9OnYjPXRXw4e2kaH3muJ
G2unxtA1QpXsC7utWP0bmZZiLjokRA2hHOoYCui5L57aw4NZ9cxUVbPS4Wvv
wQjl7WPIPTkl3+ggLxYgR24MXqdB8Ctzk0DmKCqgCIwG9vFhmZuEV5dWaADT
Lg3/NYyivbOESb0CfiwhxPS00CINSsMb7j1OG0Wjpikmvp4CGLHdRXFumgZF
bzd4L/mOopWcN6s3tQQxCel+iwsjNBhP4ciU2jeKeupTNM4wBLH32iOzz/po
4MUklKUqjaI9B7d95i8Qwq5zXJFOaqeB+XjSlZlfI+ifRzBvmIcwJh0d+JfU
SINsZzbKzpwRpFUu2vtOYzvmqnf1v9tVeP7hVdE29iOoaaCCUj63HTO/N6tw
9zUNbPRLzbaxjSC9FIG9gXki2Kjor5TdBTgOxyZjV18Oo8v614XX3EQx+Vu5
qq8zaVAV+floytFhZH7TJMtEWQzzLm4Y635EgwrXJ5fPbx5G/M47uYwmxLDZ
XzPTT2Lx+jgwXX+8HkIZqQE2zAxxLJZx3l4znAZ3vh/ZSjg5hGK8bsUdOy6B
6U+HW7oG0iCn2d5cgXcI7Q3Y3BsuKYlZxEmP25ynQczU15WP5YNomdPH6ES/
JHbG7wf29SQNFsxZf6mdHkT2WjL1y4lS2GjK3Yhdh2gg7M+mjfEPorzpU/cI
ttLY9B965z4rGpxnUQrgf/cFadEiyuW3yWA9UoLmWxDOm1+xt8mnv6DzjtV7
qz/IYDox05xXiTRwdRr+NML3BeWk7XPlDpfFwr2OG2co00CxTe3FaPkAuutk
HBMkK4ftXR1bDxSjgergV5X0UwNoe6dBTdM1OezB7/RA7q00wO48VxLfNoBa
Tu4env8sh5XYRfVa/aWC1rB3jN2bz4j/otrXQSN5rNzXwWTnEhVCSfNmVs6f
UbSgAHfGPXmMbzT049dRKpxYcCdwcH9Gmjc7CPrL8lhLwt6X9l1UOJrZQQku
7EdHK+uD7u9VwFRulQp51VHh85eUPW8P96PBhuH1hjwFrFfrphylhArhx/t3
lbP0o1dWTyrqOBSx4x92sFRnU8H2uZLItbw+pMdt3HnHRRE790tneDWRCnuu
Ps9mt+lDmob7rBQrFDGp7YemZ8Op0CKt+cXmVy8S/UOjhYkqYX55N3bFXabC
k3/DWa7pvShk4l95wUUl7EGbiTrjFBWyeO7OoV29SM9E9VN6qxK2M6uuesOO
Crpadx5OLHxCeVe+ZR5WU8b25CqTmnZQwTknI8km4RO6+taU9PmGMraipFhr
pYfruoeigzdJn5AZe1a+7JAyBgnU2HAZKuxyfmsVPdyDnMt282saq2AD31+0
XuahAseW5k+Hw3vQxe8SIWvxKhin8aViqTUK9Nawua+o9yD+0XyBO/MqmNM9
mve1GQrcIsUtH2vvRiNC2NCYmSq2Z+KacWIPBejC/McfXO5G1KlP679SVbHi
v47ItYYC/E6Jj9PFu1FBpczNth+qmPy20neM5xSI+/ww27+qC2l4RCa5Wqth
elM649rJFLjzgOWYwqkuFOxlYF2eo4bJHhSeU42kQKC+VPljri70ZgdvTfM/
Ncw/+ALXlwsUiHdKe7r8rBMp5JfzphxUx4QluXwtjlEgWjVJVsSmEymtpNur
vFDHtD5ZnfOypIBGfDiPwEoH6iIvFHpu0sBexnrI7dPH82wlnBx/2IEychJM
vY5qYF8KzDunpSlgXdsqeJuCn8+3U1d9pYH9c7lQSuamwIO2t/JiVe1IBZVE
JG3WxGKWiLy7v5Fh93G/9BaOdnRHlDewzlkTc/sRLiA4SAbPUbUbhlZtiKc/
Ujn7tSZ285ngv/sNZEh51PrK/m4rumsu+oK8VQtrUCMJfHpBhnrddQmtvha0
GBBjFOmihclnst5qf0gGl/Dhx5VSLaiQJXoi4rUWpvtUIzsihAzLAYaaW082
owChmAHSFm3sm7t05i93MkTV7c4RyW1CRoVzO9KPa2N8Y19rlW3JEFC5sDa2
8BEt1vRir4u1MbqslwW/CRnEiV5C3nof0Vu628Y1Th1snz/LhVI5Mljppg5U
X/6AfHbG5Kw46mDU8g+hktxkuN1TSekta0SXCXIuks91MF63OxXUJRNQU7ql
UPLnPSK+Gz64vKGDvRuvdpXsNYFN3fJXj2Dv0SsWzzcX7XSx+qdXqkorTOCx
hBCxLawBfUx2ePZfti7GeTWEVzDLBEZv7THgbaxH6XnCp6791MU0oynJGrdM
oLBP0Ft6Sz0KZnBxsirpYVefVeSyepuA5Bvejr9761BUWdv8o716mOj1t0EP
7U2A+4n+rqK4WhSSyxawyVcP60uOP8UwMYGTjfUVJl01SMl3h7l5mh52pZj+
H4usCViW7lNOEq5BP3KzFp0a9LDIqjPXe9hNoPdomlfnQUAKsZVbzJh6WIS8
rYX7LAmMokI3fyRUoxOkDIN/wgTsT/OYaUULCYoW1l/lva5Edy4NcMZQCVj+
8f8qOgpJ0JueVr7LpAIRIVCKcYqAFViVbjxJJMHJd6W/syreoinLrQIytwnY
0o+5Q9QAEmSfXzzQiMpRYm9qiHwxATvUniaQeIQEHcU6ea9qS5FZXSXXz34C
luzbE/icToLOLdm9nrveIOuF62YpGwTMt1VzOEqeBJfpL6p/NpagJ6kBnfwq
RKxPaihGhYMELVJ9Zg57XqGi8Jr9B/cSsTOKFT2R08ZQTPtgFtNShPRTfx/1
uEjElglGm/I/GMOfj1jGY+tCBALmj/Y/ImJmmO35+Hxj0I4Uuazy33OkRzzw
H1sVEWNle+ZCjjEGZub0xKfsfFS830EsfIKITf72187zMoZGZX9bh7xcNJOz
Ob2bWx8buX1DZcDaGFYHVYILnmUjumlp97K2PsbKq5HeoWsMnv3imhMv/kM9
X3SPfLHTx0b7Tszc5jeGEqM9RDbXNGRZ2dGb4K+PidoWOvB8NYKqsssCUuce
Irn0sDmRVH2M8k+bZtdpBIK3cy8p+txFoiHVRmdAHxuICf92rMgIXPivv9zP
iETrt26dDJvUxzaGmE26d41gtM6NOb7si/4HG7rftA==
     "]]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], Thickness[0.002], 
    Line3DBox[{{
     11.684649987044317`, -31.570288692123505`, -0.0010415461808919169`}, \
{-14.078555725315162`, 38.75145915684063, -0.07507514727601183}}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.002], 
    Line3DBox[{{-20.013456692589536`, 22.418791544392256`, 
     0.00047867318785196206`}, {19.892629774645666`, -22.56713550860695, 
     0.005356680331190383}}]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], Thickness[0.005], 
    Dashing[{Small, Small}], Line3DBox[CompressedData["
1:eJwVV3k0lW8XlSGzTJnnmXvNXPO9hzsUigZDotKgQYmkfjJEypgiZKgoklQq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     "]]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], Thickness[0.005], 
    Line3DBox[CompressedData["
1:eJxdeXk0le/3tihzMs/DOaZkHs7hOM45z0ZEpUGD0mAqIZG5IpUGROZKicwJ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     "]]}},
  Boxed->False,
  PlotRange->All,
  SphericalRegion->True]], "Input",
 CellChangeTimes->{3.8894253869760113`*^9},
 CellLabel->"In[13]:=",ExpressionUUID->"b72db828-fea3-4011-a6a8-63525bdcf306"],

Cell[BoxData[
 Graphics3DBox[{
   {RGBColor[1, 1, 0], SphereBox[{0, 0, 0}, 3.]}, 
   {RGBColor[0, 0, 1], 
    SphereBox[{6.018673911707431, -29.600708148802106`, 0.46980980066264977`},
      1.]}, 
   {GrayLevel[1], 
    SphereBox[{-20.267394500921334`, -20.11523901824606, 8.015589193357108}, 
     0.7]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005], 
    Dashing[{Small, Small}], Line3DBox[CompressedData["
1:eJxdeXc41e//vxUSspNk7+1Yxxk8i0KUFCWEZFNUindJpCQtpUEh2atCsir3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     "]]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005], 
    Line3DBox[CompressedData["
1:eJwVV3c4le8bt0IlO3vvzTnWcdbzRqGUEBUNKkkhGlZFZCQJScPMFyGpkEIZ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     "]]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], Thickness[0.002], 
    Line3DBox[{{
     11.684649987044317`, -31.570288692123505`, -0.0010415461808919169`}, \
{-14.078555725315162`, 38.75145915684063, -0.07507514727601183}}]}, 
   {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.002], 
    Line3DBox[{{-20.013456692589536`, 22.418791544392256`, 
     0.00047867318785196206`}, {19.892629774645666`, -22.56713550860695, 
     0.005356680331190383}}]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], Thickness[0.005], 
    Dashing[{Small, Small}], Line3DBox[CompressedData["
1:eJwVV3k0lW8XlSGzTJnnmXvNXPO9hzsUigZDotKgQYmkfjJEypgiZKgoklQq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     "]]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], Thickness[0.005], 
    Line3DBox[CompressedData["
1:eJxdeXk0le/3tihzMs/DOaZkHs7hOM45z0ZEpUGD0mAqIZG5IpUGROZKicwJ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     "]]}},
  Boxed->False,
  PlotRange->All,
  SphericalRegion->True]], "Output",
 CellChangeTimes->{3.889427729306963*^9, 3.891017628275134*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"c4010176-dd39-4283-990c-e41db1e4e6fd"]
}, Open  ]]
}, Open  ]],

Cell["\<\
Define the labels for the Sun, Neptune and Pluto as well as arrows denoting \
the direction of motion for the two orbits.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.889424961584906*^9, 3.889424998514917*^9}, {
  3.8894250740850677`*^9, 3.889425089895455*^9}, {3.889427315539879*^9, 
  3.889427332924192*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5b1edd8b-4dac-439c-8fe8-0cfa3dfb6a90"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"label1", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<Sun\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"4", ",", "4", ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"label2", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<Pluto\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "15"}], ",", 
          RowBox[{"-", "19"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"label3", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<Neptune\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"-", "27"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"arrownep", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"color1", ",", 
      RowBox[{"Arrowheads", "[", "0.04", "]"}], ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"Tube", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"nepdata1new", "[", 
           RowBox[{"[", "250", "]"}], "]"}], ",", 
          RowBox[{"nepdata1new", "[", 
           RowBox[{"[", "251", "]"}], "]"}]}], "}"}], "]"}], "]"}]}], "}"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"arrowplu", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"color2", ",", 
      RowBox[{"Arrowheads", "[", "0.04", "]"}], ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"Tube", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"pludata2new", "[", 
           RowBox[{"[", "50", "]"}], "]"}], ",", 
          RowBox[{"pludata2new", "[", 
           RowBox[{"[", "51", "]"}], "]"}]}], "}"}], "]"}], "]"}]}], "}"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.889425305927781*^9, 3.88942536568699*^9}, {
  3.889425486782702*^9, 3.889425510677499*^9}, {3.889425637503998*^9, 
  3.889425700833909*^9}, {3.8894257513566093`*^9, 3.8894258588601227`*^9}, {
  3.889425911483109*^9, 3.889425924366622*^9}, {3.889427346622572*^9, 
  3.8894273559824963`*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"1073b826-2c12-4354-8bd6-8c0ee91ae26f"],

Cell["\<\
Display the final plot with labels and arrows viewed from directly above the \
plane of the ecliptic.  This is Fig.9.33.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.889424961584906*^9, 3.889424998514917*^9}, {
  3.8894250740850677`*^9, 3.8894251297806473`*^9}, {3.889427289365941*^9, 
  3.889427305009214*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d9553d0d-4101-4aec-8b23-75bd8523239f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
  "nepplu", ",", "label1", ",", "label2", ",", "label3", ",", "arrownep", ",",
    "arrowplu", ",", 
   RowBox[{"ViewPoint", "->", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "20"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.88942448164229*^9, 3.8894244977069817`*^9}, {
  3.889425709594389*^9, 3.889425718926343*^9}, {3.889426967732082*^9, 
  3.889426970927178*^9}, {3.889427253560217*^9, 3.889427255778887*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"a0ed153f-0510-4405-866a-58df4ef7c6bc"],

Cell[BoxData[
 Graphics3DBox[{{
    {RGBColor[1, 1, 0], SphereBox[{0, 0, 0}, 3.]}, 
    {RGBColor[0, 0, 1], 
     SphereBox[{6.018673911707433, -29.6007081488021, 0.46980980066264977`}, 
      1.]}, 
    {GrayLevel[1], 
     SphereBox[{-20.267394500921334`, -20.11523901824606, 8.015589193357108}, 
      0.7]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005], 
     Dashing[{Small, Small}], Line3DBox[CompressedData["
1:eJxdeXk01d/3vilUkrmSzPN4XfN1LzuphJKiASGZh6gU70gikibNCMkcKiRT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      "]]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005], 
     Line3DBox[CompressedData["
1:eJwVWXc4le8bR0IlO3vvzTnWcdbzRqGUkBQpiqRQGlYhZYSEpGHma2SkQsrI
uI1S9ibZex20ReX3/v5yXff1et77vZ/P/RnXkTl90foMCxMT03dmJqYt+N+k
B33Tl7bowl1mnSU9d30sOPvry9aTCP1bTJHNV9KFuCNxN8nm+tiAns6Cdb8/
cjtSRH9prguQ9j6aVU0fKzHIPRI7FIEctcYGgy/qgsfu3JMJ2/WxKGpGUoNr
PEreuPxY8r4uKL/JMluY18NCtmeKUR0fo4RzBJGIN7pwqLMxhe2jHvboxL7q
tKNpSM3x9GblJ10o4ih/Pp+jh3Wc3ohYVspADkytjMo/unCmtKLtfrgeRsy/
1/VNLhutvS6/fVtKDz465h3eekYPU6+su9UvlYvsdL55iRvpQeXiehzdWA9T
+yo+dk/sGVK93njwuosefFmo+oxk9DDNhh/aYkIvkNQkR31muB7can8cuW1T
F5uarh7WiyxE2YLcPg9y9eCZ8sfV5CFdjPfswkQVWzGKFy7jtGzSg5efZd1+
letiz2e4mmVCX6E643Ma3Yt6wHGc21T8kS72InZf+Qnm1yh1P88NyZ36kP05
enr7VV1MzKS1wzPoDUrWk88jaOpDQIRGSr2lLva3bEnXYqMUpTo9Pcx5SB9Q
iWCDiYYuluUrv23Dtxzp+sopvbioD6bbmEoTtuliBtsULnl9r0BNF0taBOP0
obGU2P58WgcrYB+Oy/eqRJlhm4y9hfognxFxNr5WBxOhhURnL1WhSoKhHqVD
HyJuu382StXBYurTI0641aC7sgoHf67oQ616T3iNnw62fH/nkdlLgG4QhcZ9
uA1gX8i+9xw2OthXE6k717RqkcWJ7ymVmgZwr230p6SWDvZr0dl/ZqkWaZbo
aDQeNID7jQY+LNt1sKmzv4gq+XWo2nKU/tDDAJKqAzNeTRGx38qkZuxsPSoy
eXBD5Y4BmL91GyTWELHrtJYjavINyCQhIjU4zwB+JRkGBicSsa3uT2dmxhrQ
Nd5bpsmNBqCuUbGQcoWI/TPZEX8p9R36c2Jc3X/aAB5bUEMiDhKxgkMPPT7a
vUdtral/RbaQQIAlMcdYiYhps6E7S7saUbKN6flAaRLIR2iVtzERsWWOk1s+
dTYiuMgun0kjQfLVKRHVQQLWpVm8EH33A2LlzhiKsidBUp20uu0rAiaaeeYo
276PaP26j4muLwnmZjqsD0cTsBhmfidj1ib0FwULPLlPgsAx5y8yZwiYw5Um
MaOaJjTKcWy96SUJ/E2b3OtoBEy4RTCD6VozUovWLShtJoGTvbeiniAB25PD
siNQtwWxnVsccZklwfNttuHXlrUx1XCJi6+XW9Azjq+mXSyG8JZ5aDX+vTZW
zQiezcltRV6BJ1M3JQxhs/h7c1CaNjYR2nvX+nQbuuo092CJZAgFx7YH0X20
sSzisYBXYu2o8vn83OPDhvD0L8uFroPaWDx1tPVDTztaSnO0YL1gCF030BaK
gjYWUrxi8cGkA0WHLgZpRhhClpye+Zc1Law0lBTKmtmBKlO7dYQyDEHAp/2a
UI4Wppuuukt4swMFLW9Rqn5rCBYFU67zNlrY5PVAHpbjnchDgJtfrtcQJsR+
j59l0cK4txmF1b7pRAsiWq/2LhuCQVFAzf2Xmpic0fStI3xdaNjUpF6BnQzd
Ex+6PR00MdlyokiVZxd6/WN0s06KDA//k/z+k0MT+6lw9NivD11o+zGCogSJ
DA17s35qvdbAQr5PWG6R70a3D4p+17Ekw05/52KRUxqYfVcL/1hQN7JQVVRm
dyPDHgnTzRJODYxKvVoc/akbld2MvvnwBhl0tEXesJSpY3o7sugcuj0oeJkA
4w/JQC0ILtzirI6dYH7QZBXTg6ifcrPmnpPhy5nND2U71TF921U3t7keZEQj
ruY3kKFuZmVQtkwNizLqUjc36kWf3KtdlD+T4fqekDqj02rY8p0Wld/Jvai2
ldHg9IUMIz+qHUQ41bCX3PNXLv3oRXyZvD2H2SmgmXXtds5rVWz/wQKpVxZ9
6Gitui2zBAUWfp+QWT6pitFWhYyqcvoQt+V37nNECly4MLJtmV0Vc7J7vhrD
1I8Oh3S8jzKlwFsumkxuoQp2S8lrt5JdPxq3GcZcHShw1jjUTMJOBbtcM7c/
rKgfWVAW92x4USD8ftgpC2YVzLZbUT532wAKGb2RtC+MAmMu/RbUPGXMcL5+
KubUALrQ0bfNKpECxuVd32YtlbGVseksUvkA+qo7cZz3OQW+zMXpWq8pYcr+
uwOzeD7he2RuHwUUcLOf/3H9iRKW0y1+u/PsJ9S6/Wr7224KqBtclHA1UcIq
16yGqqs/oXvz3uHZMxRQkLx4j5ehiNXaWT1y3zWIhj3lzU1/U2Cia4l0474i
9sJavrvPfRAlT3IupO+gwo2F9I2XhorYYP7FZ5u1g2hBx1e7WIIK0d4/a7NG
FbBsAR/qtNBnRI5yXbqmRYXHORzeJ8MUMJEC0cxwz8/I+1fi0jpGhZHr6f+G
VRWwzKuTfybqPiMj/rtMRGsqeBwl7pPvkMeiezfO/hYaQkHJfmtSzlSoyP2M
iN7yWOQugy0fPYZQCu/h7IYrVEgOdWrjEJXHVnv4li1rhxDJtnNAKpQK9ZjK
eG61HDYaXm4Wt2sYFRqdPUNIoELsDuwMv7Mctm+eVTf83DCqxcwkf2dSIeum
hdk+djns8vXgTkLVMCKNne33eUWFOizZz/yZLHbtm7txPM8Iyj9/7Ux+HRWc
/NinRQ/JYheKqwqeOo8gUe8fqfc7qfDKlzOw7KsMxm2gQLjwZgRVXOQ5Shyj
wlXDcm2FhzKYfOzOH7McoyhD593Z8GUq6DJerp4ylMEiGp9I8B8fRVdiOnJi
/1DhcJDci4tD0liu/buO5YJRxNxSvHJwOw3KhXvtD92Qxu6nqupd+zeKlmmF
wrVCNNj3jHeeWVYaq3kgbTioNIaMazv/zMnToLj95COeSCnsm5LMMQvLMdSx
e9rnHYEGUbcEl963SmKepcKciX5jqJASdNqWTgPNNs4yZT5JbFFvZb48fQwl
kH8mJ++nwddA9ikDWwnsJvv38MIPY+irrSfTA1sa7ClrsvuZKI4d0h31C1gd
Q/pFTZ5Gp2nAN8/P6joshl1M7DoiITyOahYq6zI9aSCbm9AWIS2G/RY+XhKP
xtGblIqRMj8aiCYzsp2cRTGZj5fUhlzHUV8LS8bNEBo0HM7zXckWwXxkA61/
3x1HrE6pjL93aVChYkA0mBPGaBrWtfMl46gy6nimxmMaTPDMNBiqCmNvnuvx
PP88jo6hgWyeDBqcdB+V+u0uhKUeGu43YplAWkl+A0+f0aClX0bX97kg9rjD
qyhfeQJ5mXtIrZbQgOnP9W+vl3dhySp39KcsJtDCv+eOS1U0qDa/bVmqtQu7
XEphXrk6gUJrt9xIfo/PuTmDHuglgImfZi9oSppA0S6bzn/baKDfySjaVsSP
6dfPd/rABOod+feDt58GHNVGT05+4cNszG25vk1PoMBn6hKfRmjwr4zwJ5DA
h+m7Gv6l75hE8YrBddYzNGBz3qg+d4kX20j9TbbXnkRes1XtQQwaxETcGZEr
4sHIVX4ue45Mol5hP60T32nQkT6b5TDOjY2sCAj99Z9EZW1crYx1GpBaWxQE
nbgw1sm81ZC0SdRlV5igzUyHBrNTBL8RTuzx5L3YgbpJtPrY7ooCOx2czrtX
hDvswDo2nsavz0yiCdM+2xZOOqR7dZXsHdyG+XLvSZzfPoW0DtRqKPDRoaXm
/q7yoxzYxs+9xtmaU8hvM3RWS4gOwSJlXVM9bJh5IidBw3oKBfkev7okRoee
NrPJFqutmA9rwJab3lNopdninb00HTgZe5B32xaMLezv8fTHU6jMzrDlmjwd
qC4PR8f3s2CilcFDUW+nkCbr++sHlOkwoMJeLdjIhGmUBChhI1Oo/IpXY7sa
HbTzPPK1wv+hlO+rozVM04hoHZbJqkWHD26iu7sCN1Dbfde8bXLT6Guo7NZF
Ah1WP7qRJLzXEK/ZFyWJvdPovIvBxC1dOriV8kYJe/xAPL7aTOuu0+jyl1BC
iz4dHo/LEFpOf0W/jS37n0RMI22OtIX3JDpA3LvDwcXLyCBl+2Gu/Gl0N252
6xUyPk/fyMm1tDn01ihXZG/zNLIveBzQQcHrT+9x8d2ZQH8+MXcZL02j7ZMV
ZqNUvB70LKeUMYAcl4Lltu+cQUzmqmee0OiAxdl3PI78iMy+Sb95pDGDvAof
tPLQ6cDkEeNxwCsE5Tp4EZcOzqCJ8qAgHbwenChXzSneWCMae283+4UZRNlO
9mbH69Lx3L3PS/trzi9R7s7dnUGnnFZeRuPnO92R+p23Ol5T1lVZE/t8BnmU
JGrU/7+fDkMbj61zNX+S10L+tODvtWZfzsf7lzZm/r5TdLmGLcU9THNpBjV8
/fTFGP/eOH52NyT0teafuJqXwo5ZNNceTo7B5xPs+/HiUZkfNWr2M6tjKrNo
rNy2KRKfZ/ClBk5TtbUaY//ZEiezWWSk5Jql///5n71AZtPbqJG/JXA+y3UW
JRlntyTg91U2dPB7NP1fTbfNavWz0FkUsNFvmqWJ43OePXk+kwlmU5NP+2TM
IgG2h2JncDyAUHugmzILWH7sZWWFWURc2m/Rr4TXeZKlawq2wKVvf4/YDM+i
BU792XU5Ouia1dyc194KYQP87GfXZ1Huk/PL7VJ08Nrb/mSyhA0c6so+UoTm
0NCrdg9bHM/yQ3n+eSQOOH5V27JLZw4JaEp7xAjSweFsKJdB5Tao2XX6oKrl
HMqsW/jpy0sHjq0/T0SgHaAl+umqscccamDcE+bH96uli8UtsY4TApXfX5OI
mEPG8+bDjmx0mFNT0nDdywUFm5v8ZZlzKO2JrPVJJnw+s6dfLDRyg7o960++
mjlUmPItlGv9/3yV4cObzQMW7Wt9GoNzqHrjYqjXNxo4uKx7b3XlhfbiZ54c
P+aQ1mFxp9AlnH/S023bFfng9deESxnc8ygm1VJ5/zQNLGVtRD1n+cDgW1/S
hso8IkmTlmuHcZ6cIdQP5fDDkBvK4N8zj44d6qxf7KXBe9eKw+JuAvBU22z3
wol5FPGS8baxlQbC1P42FeVd4KsoTLzhO486SggLR97h/Fk+ZrBlbhcE/g7R
6oqbR6pPBJwfVuL9x2TGP80RhJJ/XD8m8ubRLZsxSuQrnP9dXCd5zwpBJPMS
vahuHmmSiqI082mQG7iiaawoDIF8/z5SP8+jgU1v1/B0GihbR10jTQvD/OFP
h8O+zaPVsJWZuIc0sNfc2bKSKQLPG+qTonYsoPjEQnmLaBqEto2onD0tCizb
3pw4ILeAepslDKtv0mBpfSMpRVoMdhMcHJrIC6iY7Ekf96FBgOxfxZgRMcgL
EjzKar2AzOyeHip1x/Xou1ifYYo4SCquc627LaC81/9FYE40CN4gFaXaScAq
T9feZzcWkEQlB1ugDQ2ohPHaUkFJuJksVS30cAEN+B6Z9jCjwYHEw3zh3ZKw
bCVGQQULSMuqaw8PlQYpPeHP2eKkIC3/dbBM3QKy+JhofFaLBpzHH7WLKUrD
h+pHh6v7F5ClzkPmy7I0SFoY898RKg3NTPL+uxgLaO38zSfau2jQF4scOsel
IW7Vp1SRZREVR0zRM9lxnJSUB3ogGchsPdv7RXAR0e8LsTT9pkLD9Zrpzyky
cMA0MslHbRGB5m7O7EUqtEVqpEiuy0CAqmp7CVpEZvtsb+oOU6Gs8VCezlFZ
iN1pSy04vIhGGkTC/dqoEKc8tUu0RBamfvc+czi7iHikxLFLNfjzHhKLHTxy
YMtPmHt3bREt7HrbK1lIBeOpbOJRTzm4THteOXt3EQXvl7lwM50KFtoZP599
lIOo6kM/atMX0fexvYTEOCqYbynZ3aYgD3fGhk/avFpESxJLpq7BVEBjfySr
bsrDi9jh92nvFlESc+bnuYtUeDQgneQ7LA/NPx9spPcvIp2xBkEZRyps27ev
5g9JAWJEeFrs5xcR25qPPLcFFWQfKCWbJyjAeQ8hjpb1RTTPmqf9ikqF6+O/
yM4rCkA6Tw7+vmMJ2XYKuO1Uo0JpS0iB0X5FyFRq3tojvoSWGmhrEiJU4FVS
+DeXpQj0qdHz5zWWUJSXF/c0GxVicj/Qj2wqwunEw7dKaUtoWqhu6PR3CpRl
rwaG2ynB8/D3Um8PLqF8Ek/co3EKbNSVNl9/pQRmlWlC3ieWkAY3k31IGwXM
nnaTdHcqQ30GB5r2WEIPhf+5K76lgGXOo74XrsrwNPiX+46AJZQdT1sLzqGA
XtCvNws1ygB/Fbxno5YQ6+9Swv37FAhajVyaEVaBbVmCRP/EJSQSrH7gxA0K
2Afcicq4pAKyJwWuQ84SunxXKmD0PAVsWMazxJtUIOEbUaXq9RJq0Bj8KWJL
AWlPUUsbWVVIvXVI8GI9/nzEua+cuylQeNT7P7NrqpD4i0eir2MJFVmmZZep
USChaPTFWqcqSN6aE/46vIRoupxmEoIUMDy1HuOsogaP2Plm6haW0FPTbXwU
JgoETInZRQSrQfT9hFNmv5YQxes5lW+BDCYr1gqu/WoQ9M7o3K0tDHStuZM5
s5sMYhznOP9oqIMZ9e1nL24GogjwpDAqyVAkO620L1QdtDfdHvOLMdDprXUm
X7PJEEDiij8wqA4eUyE3zisykG4FE70ohgxSo4wzW7U1wOgHz2VvAgOd5Myq
VvUlQ9OQdc3lMA1oaZ+w0qUy0K2V3WyOjmSwqeiuuD+oAQJsScw5JgwU2KRx
2MKUDJaHO73PamnCyrVsl1ZLBrJv851a0yRDtrM/FyNEE/ZUGjnm2DPQ0P6l
3ycFySDP/zFTbkATRu2D+nRdGKiCib8n+K8hpAbFHtmurgUfkG6htycD3b+k
WXJyyhCq6V570m9ogcYmd/c5H/y9GpShtSZDuLA0fW+qSwuKlO8q8t5goGOS
KzGHivC6laz2Ip82HHnwK979NgO1dpRxOz8yhNvo5DkyVRsGi92Z/WMZaPvb
6gydQEO4yvUi3PGMNqS29B03fMRAYjdHomtPG8JERKSofYw2LFn9ii5IYyCC
QQH/TjND0CAOlqqUasO0yIngrmwG8vvvUqCghiHw3PzzpXVUG2qzzsk+K2Cg
8ksavCO8eF2k1sGEgwCp9pZO+q8YqOtWvKDLTxJcY7kQHa9NgLpGQeWr5QzU
y8velztIAo7xml3Fxwhg0Zfg5lLDQDt+ZD4uqCbBQZXFu1nBBPDe6s3L/o6B
0jp0ci9mkCDUJjXqXC4BeNJ0+R2acDzsIx76GkYCVf5//zF14OdPyTk6tzOQ
nW7zgO45ErAHFZ4/9ws/Z5/rrHgPA3m9/xRncIAEw3t7rmdKEuFYwte0iAEG
+lU9W7+uSYLccTbPF3uJYMNz3//pEAOR4tVrgnhJQH3r0hfpQYSu4ml3nzEG
4rwX3VH/zQAe2kdZ6t0nguhuB/e1SQZy4nps0tRrADGxD64WlhOB5Qr1gvos
AxXcivKKLzUAviTFofVRIgjxp7vzLTAQ9fm+NPFEA6i1PCUjwKYDmuLex/OX
8Dm/cpE+d80AhEyWRzbUdMCrJ1D/+zIDbdD4zfyOG8DC4sbLIisdqJ62/Lmy
ykBP7uue3U81ALvXSFvPVwcirtg9SP3KQOHFFh2j4gYgb/BrIyxFB2Q0+7n+
fmOgNde7faS/+nDOZP5lZq0OHHceOcn1g4EcnGpbjwzrQ+6us/N3Z3TgJeex
W514nWWP43aDKn3QsjxosmeHLpQNMvua/GQggeqg8aEUfZjV2XrmvZYuqNMv
UDzxuk3cp1zTAH2wyAub4rfRBYULrO178Trfk6Y3vsf1YcLOxkXdTxe+uTMR
O/Dz1zcOnPYk60NpQ3god4ouGLBeOcOJ1zlX1llURPTBw6p+urJGF0Jad7uv
4/3H/OX8kv9LD4xOGanoTuqCpbySSRL+vXwrx8K+9erB/ZPtq1fZ9MBNvvj3
Ij6fpA5LkS0lenC86eNIkIoelDwxiVrB5/nhBzP74D09EDZTfGh1QA98+ST+
ZuHzV1vjz/O7qAf1ORcrli7owUqC0TFO/L6elTTaj+LPbVtuXDmE/59L0+MM
Bfx+xU1/+nKp6kGS/fzgtVd6kNjaO7mK42F1C88JNnY9eOmhJOOJ91UsGip/
AccPv5fY2Ua879zpi26K+HcE+LBcSMXxxmJQ8s0KdKHlo/nRp8L6oNQd0hSE
43NZcvupp/hc1BzHEpYM9cGRyL2XD8ezxcboznf4HG+qrn5Ys9eHydAb80dx
/F9MjbJ7gc9978Ln5Kbr+nDldkjDIXxfztevZJ7W1oXa2Mw3p/B7M0lNnfzd
gONwa9jBCfxetfRn66oq9eF9jtwRW3wfjcCiVGNWB1aE5s6PDOnD4me68hl8
fweYRo321ulAzs1Iu/o/+tCdsOihiO+7x3kba5VUHYirtyJ74Lj7LfdbJwnn
h1oJO7NBHJcPpd3LBygGUJi2LRZwPolJlYk4Zq0DSW+zQjhwXKvn3YtLxPkn
ssjdO0tdByJvXTHZ8DeA7/QBcwWcr16ZBl6txvfkjtC3l4WPDaDJ72ePM85v
/DZyC0/HiLCjbOaCMr5nfw/1Y0dwPux5UUg5WUGEMpkK4ml8Lw0cDbJ/BzFQ
0+qftil8b/29bz07ge/xx/QsYSucb10snLdTPImAhDcjRfG9P6oaVHwc52ee
S7U2p0yIUHEv6cZjnCcEZr5FieB8zn/IZ9cxKSJsPedO7zcngcs+trdROP9P
MZ8qkVojgPimrn+fGwm4toU7vMT1YippNLEM5ynyWbfJBzhvvWvij7qN60v3
z1ZNuTyc12gKhF04zzn1SDny43oUHxs65HiTAEN+ZCEbnBfPlM3/ssb1K+ZA
P+dFOwIY7FYyt8Z5VJop+JIJrndvrARUrQgEmKwQC+HGefdQd808Q5SB/raw
PGHbRgBS32/vOzhPq6Xa3NiH62lw3Xhf7Jg23BG1/fxO3RAkXpZa2eH6i/W7
0hg47xMv+rlXmxpC/5jWTQlcr4NFq+hSsdpwdcJh9CquG+yanZoPcX2H1hBT
RVdtIFwoWZ0LMIRYq4CAetwPBKi1NrDQtMGoYtpOFNclk5Mj0dm4fwhQl5B/
za8NGUM7+zhwHTM64hVCxf1G06OOp9d7tOCkELNMCa57JeU+oRG4P1m/L3+L
fFML5BLMf4nhOmkty/w6EvczFz5/Ks3R0ILnEkRBDNdV2w/zZAz3PzORnooN
nzThXV8xRRrX4R0CvdQC3C/tbNR5HhemCdtXwhQrcd2eUyRMtF7H/ZjREXUu
giacPSL5kB/XeUdnvcPZuB87/awllDakAYZu+fsVcV8g+3W8jIj7t6eqLo+l
bmuAeKbA1u8+ZBDcu0n1wf3e8Z7ifa8JGuC6n/V2AO47ph5JbPfC/WGhmGjA
5md1OCowEl+D+xSlCwnm0rifLDaq598MU4fB9obFStzXaHHf0riN+0/TDyk/
SrTU8ZyTdOQq7oNubTYNZeF+daz7KLvsJzUQfPYvYXqeDAu+Irf9cX+r8OSM
luktNbBMP3yRB/dZuoND9ltxP3xj+LuNgpoaaF2syP++iwJ5cvtum+H+OUFm
xbGqWxXO9u7iisd9HP8JW6ox7rcrsJ8kngBVCHbafmoOo0AMB+T/KF5EcSWn
PkrKq8Lylk33X0cosP0uK6sT7ufD1ykb880qMFIgsVaN+0rXJy7Xbv3f/39B
5ZevqEB09+F2Ou5DnfImsBN4XijT61suF1UB4vbDlT64byVqGt1ZdcVzzTW+
CKhVhujIe1GuuM+dUmePoeJ5xG+y8NJtN2VYrtjPxoX74ivB3kG78fyy044/
kZtbGSZqbvzxwH10Ai0uflN1EemO0pfsXivBqV+/yCG473bhEmH2xfNR4OyA
3dnjSpAVvDvOEvfp7+/EMucyL6LODPlOErMSWL8tau7BfX10gnZL/NICUrVi
Mmp/qgiB785UceM5wDPjR6IBntcE4iZS1A4owvJPI31mPDcMiidkPaxdQNY5
/V0WXxTwnP+LPQ/PGbF5AYqFzxaQSU9Qr+FDBeiSXWdlx3PJ32uD9qEPFlD7
ffZHDLICPJGJZhLDc8zDlPhAfjxv1i9obncflYc1vbK2KTz3MKjGzSfwfCr4
nCr7KkQepisP73HBc1LRD6ObzlYL6Gk9U/d7JXnI+vtP//+5KpY3fVgez79V
Xh08Oc1y8OK+QmAInsN+tktJZcguINf7IR02F+Vgb98/hiye2149pYV93r6A
/OYvsXfyyUEkLeaUL57zHtxUtez8Oo98LL2eib+RBZZ3mYXBeC4c2WyGkEG8
vrWtmGQnC8XmQyV0PEfWvXwr/K12HlVOWgko/pGBxC//mRXhubPU1CRJKm8e
uWcYNE6nyUDLZXXTATynjg+fj9gWN4/keTXq/XbLwPcbN6Nf4bnWXmJQscgH
P+fwIaaxSWmwEfD+YYTn4Ej/H+WCJ+bRF3FlX/FwabD8mOcYjudmL8e2cLLx
PLKay5fWUpYGV6V7eYF4zt5yRqFbXGUembi6LBESpCDlu3uxMp7LQ3zOTVdx
zSOXc78nXvdLQlTwfvvbeI5fYC5llfw+hxTVjogsiUpCAYPzViKe+62l+/1o
n+bQzwPeoX0nJMDBz3mHoxMNEqroUeLVc4ikzi3qmy4O2m/bBvrdadBctfPW
24w5xHowqqN9QgyaV5+0bvGlgaQMV77o7TkUVL+eNiEvBnSd360TN2kQrPDq
ANl9DqmniAUWuYpCU1lr9dVoGuS5Cr8WPTSH1oz2OdNzRUCLayKs/CENlP8w
aVUS51DA/PX9d+aF4bxFy7aidBqkP+hjkxKcQ/pLu9WTVIVh4eh3wvF8Gmg+
yI00/j2LKvQrWDzdhcB48/5M6SsafFVS26o6NIvicmI+bC0QBCdUytNYSYNJ
hzeNXdWzaP3ysp/r0i4QPUtNinhHg0bDvdL0/2aRflgE9z31XeC0p8fzTysN
HNqunvQImUUOU2ERtz0EoOMAi69sH37O3pCuE2dmURBv6Jh5AT9U14tnrA/T
4PVPi1Y+01lUeS5WYGyRD94PHxgKnabBEa8j6XeUZ9GLcAlZEzU+6BmP4a9d
osGT28WpH7bNork0dvbg87yQblqs//IbDZxOSQk3LcwglpnQ2tg8HijsttM7
tE4DjetfTsc1z6APn/alL3dwQ0PhxmY6Ex2SikW6xApmkN+WBOdLFlzQFz5+
O4uNDrX75So8omdQpbRp87NmTgiOVa6x46SD6irRK8RjBmWxWvX9Z7YD1nJq
HwMvHbjebt3vdGAGWSK50KPvtoGH0yWOT4J02Ka9mrpFfQYdGM3p6djNAT85
OlgyxeiggIbrPHfMIJKu/gfeajb493ZfoKQ0HY7vPsjzZGEascbfdpQkbwVt
V8kL5vJ0CP9uM/Lo4zR6vKsgef31FuhoPtWiokwH8E4JO5Y7jXrObQbmE1gA
7mzElqvRgU4+6TgePo32xEpwEJ8zwYBUTtG6Jh0K2FzfEc9MI22zl76qVv9q
Jga/qTIIdGCZ5uY7aDyNOE5Y6ReabtRwTe35GadLh3Fh03RtmWlU2GFj+Ze2
VrOo1ck1o08Hf76w5uF/U2hMRKBJRPdHzZxPptcSiQ5rjh0rNkNTKMJ6PWen
6teaYypJwllkOsSkvj33sHwKpZd+GqpFyzWcp86y7qTSYbuLy8OMh1Mojuu8
sYHaXI1LRxxRiUYHNv3L3f5XplBwRPedO4ITNV9fXMz4itcL3XfdELecQmB1
5nrqloGa4kxtm4t0OphKsK1FqU8hTO7xDeOSxpragm6zVLyuxRmS+o5jCjHl
7mrf0n4FPWNVvxWA13OjLNtbpiZRcNbX9tLVD2jP1jGWnXjd7HQpIx0mETah
Xy/x3wDi4zjXZoG/l688xM4oZRJZqli2FbpMIMs9/PO78f7tf2y5WuQ7ieB8
dHmI3xy6kf/36Az+vdbp7E+WrfFzmKKyft1ZRhFVIjJUQ/x+TUeo6xqT6EMU
ZV/Qoa/o5jk1c2MDOkg52Bb2cODnqFrtqT32A/3r/zC8gc//Cn+lQ9DkBBIO
PNxYeWoNcRjZj58h4vdlPJD9q2oC+Z050O92fgMl1og43tTC8UBbWcEe4/2x
Pr5WdfkfGhDgP2Whjs/nZc0T+8sTCLMOdLCrYsI6AuS+tuD4Wfe+Kbr3wAS6
eujzQendLNjcpd8Sf3G8CQVMvWNSnEDiYp0PXzZswYauCHwZwfF5J5abI2Zz
HLkVp9G2mG3FLjU3+F0Wp8MM6YkpY2Acfeh23ifUzIZ1mKvVlwrRYTUua1Gy
eBxVDqrWzR7kwK7wGo6+4KPD9V1Zx+XujKPVpG+FXh3bsD76y6GjO+nQF5Cw
ue48jkIJ1VIvrHdgdW8kW4rZ6RAfMYyeUsdRQM8DkZQeTsy8Z7a6hpkOX/ps
wxR2jSOPpOR8fVsuzE+a3Bi0QYOgVyaG/oz//07KO+bfz41lbBVYW/lOA5hx
evffuzFkMUeY0i7gweKCjc7wL9OgNPTd/SepY2jKKNnQ24MX0253kpufoUFR
xSbXFe8x9PPpm7Xb6nyYqMSA6aVRGkwks2aIHxxDfQ3JqmeX+LD3GqNzz/pp
4MkglKXIj6EDtjs/8RTwYzdYr0kkttPAZCLx2uyvUcTiEcQV4i6ASUT5/yU1
0iDLkYWy5+ko0iwX6nurugtz1r7+351qvP/Q6ihLm1HUMlhJKZ/fhZncn5O9
95oGljqlxjtZRhExmfeAf64gNib0K3lfAc7DMUnY9ZcjyEfnhsC6qxAmHZmj
9DqDBtXhnxySHUaQ2W3DTEMFYexC8bvx7sc0qHTJvnph2wjic9zDrj8pjM39
mp3JjsHnc4Th8uP1MMpI8bNkpItgd5cu2KiF0uDut+M7CKeHUYxnZOyJk6IY
cSbUzMWfBk+bbUxkuYaRhd+2vlAxMcwkVmLC8gINoqe/fP9YPoS+snnpnxoQ
w1x9fmBfTtNg0YT5l/KZIWSrLtmwmiCOjSXfC9t7lAYCviwaGM8Qyp9xvk+w
ksBm/tA7D5rT4AKTvB/P289IkxZWLrNTEusW5zPZjnDd/IJVJJ35jC7Y1Ryo
+SCJaUbPsF0n0sDFfqR3lPszyk096MIRKoXd8jxpkK5AA7k25Rdj5YMo3t4g
OlBKGjNfG9/wF6aB0tAXxTTnQSTYqVvbFCCNPfyd5s+xgwbY3efyIjsHUcvp
fSMLn6SxEuuIPvO/VFAfuRht/eYT4rms/GVIXwYr8z5iuGeFCjdJC8bmjp/Q
HT5ejvT7MhjX2M2PX8aocGrRjcDK8Qmp3e4g6KzKYM3xB17adFHBIaODElQ4
gE5UNQQ+OCCLKUaW8nvWU+HT5+T9FccG0PC7kY13ubJYr/ptaUoJFUJPDuwt
ZxpAJebZlfWsctiJD7uZarKoYPVcXjAgtx8ROAw67zrJYed/aY6sJVBh//Xn
WVss+5G63kFzuUo5THzX0Zm5UCq0SKh9tvzVh4T/0GghQvLY1dxbe2OvUiH7
30imS1ofujn5r7zgsjyW0GaosuRMhUzOe/Nobx8iGCr1prXKY8aZ9TWb1lTQ
Ur/7aHKxF+Vd+5pxTFkB25+jQGraTQXHp+mJlvG9KKDCiPTplgL2TV6uzlwb
93WPhIZuk3rRni2Z+VLDChjEU2NCJamw17HCPGqkBzmV7eNRM1DEBr+9aL3K
SQXW7c29x0J70OVvosHrcYrYVoMrxeLrFOirZXH7rtKDeMfyee8uKGLH7tMu
BsxSIJIUu3qivRuN8WPD48ZKmNlkgEFCDwXoAjwnH17tRtTp3o1fKUpY8V87
5FJLAR77hCdpIt2ooErydtsPJUx6Z+nbpecUiP30KMu3ugupuocnulgoY1rT
mhMaSRS4+5DphKxzFwry1LUof6qMSdoKzCuFU8BfR7z8CXsXKt3NVdv8Txnz
CbrE/vkSBeLsU/NWn3Ui2fxyrmRbFUxAjN3b9AQFopQSpQQtO5H89zQbxRcq
mHqv+XlPMwqoxoVy8n7vQN3kxUKPrarYyxh36YM6eJ+thNMTjzrQf0/jjTwd
VLHBApPOGQkKWNS18t2hdKCufGsVpVeq2B+nS6VkDgo8bKuQEa5uR0qoJCxx
mxoWtULk2veVDPtO+qS1sLajGCEu/3pHNezMj1BeviEyeIwp39Izb0OcA+EK
Wa/VsPBnfP8evCND8uPWVzb3WlG8idAL8g51rEGZxNv7ggwNWhui6v0taNkv
Wj/cSR2TyWCObH9EBqfQkSdV4i2okClqMuy1OqaZp5oVFkyGVT89tR2nm5Ef
f/QgabsG9sVNIuOXGxki6vc9FcxpQvqF87vTTmpgXONf6hSsyOBXtbg+vvgR
Ldf2Ya+LNTCalKcpjyEZRIie/Be1P6K3dNfNADZN7IAv06VSaTKYa6UM1lz9
gC7tiX763U4To5R/uCnGQYY7PVWUvrJG5E2QdhJ7rolxud6tpK4YgrJ8pGzJ
n/dI5+2I7eqmJlYxUeMi1mcIW7tlrh/H3qMSJo83l621sLq8a9WllYbwRJSf
2BbyDjUlHXn2X5YWtvV6MBdfpiGMRe7X5WpsQGm5As4BP7Uw1ShKkmqkIRT2
812U2N6AgpbY2ZjltbFrzypzmC8agtgbro6/B+pRRFnbwuMD2pjgjYrARzaG
wJGts7cotg4F57D4bfXWxvqS4pyXDA3hdGNDpWFXLZL33m1ikqqN+RXT/2OS
MgSz0oMKiQK16EdO5rL9O20srPrsjZ4thtDnkOrZaQtINqZquzFDGwuVsTJ1
myOBfsTNbR8JNeg0KV33nwAB22geN6psIUHR4sar3NdV6O6VQbZoKgHLO/lf
ZUchCfrSUsv3GlYiIviLLzkTsGfmpZvZCSQ4/bb0d2ZlBZo228EreYeALf+Y
P0r1I0HWheXDjagcJfSlBMsUEzDb9lTehOMk6CjWzH1VV4r21Fex/xwgYEne
Pf7P6STo3J7V57H3DTq0eMM4eZOAXW1VG4mQIcFV+ouan40lKDvFr5NHkYj1
iQ9HK7KSoEW83/jI/leoKLT2kO0BIuYqV9kTPmMAxbQPxtEtRUgn5beD+2Ui
tkLQ35r/wQD+fMTSn1gUIuA1eXzoMREzwqwuxOUbgEa44FXF/54jbeLh/1iq
iRgTyzMncrQBMDJmJnuz8lHxoSPCoZNEbPK3r0aupwE0KvhaHcnNQbNPt6V1
c+hgo3duKQ5aGMDakGJQwbMsRDcq7V7V0MGYuFTTOrQMwGNARG3yxX+o57PW
8c/W+PP9p2bv8BhAif5+IotLKjKr6uiL99XBBK0Kj3B+0Yfqsqu84ucfIem0
kHnBFB2M/E+DZt2pD3x3cq7Ied1DQsE1+mdBB/sUHfr1RJE+OPHceHloKRxt
REaeDpnSwf4NM5q07unDWL0rY2LVG/0PIfPeqA==
      "]]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], Thickness[0.002], 
     Line3DBox[{{
      11.684649987044317`, -31.570288692123505`, -0.0010415461808919169`}, \
{-14.078555725315162`, 38.75145915684063, -0.07507514727601183}}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.002], 
     Line3DBox[{{-20.013456692589536`, 22.418791544392253`, 
      0.00047867318785196206`}, {19.892629774645666`, -22.567135508606945`, 
      0.005356680331190383}}]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], Thickness[0.005], 
     Dashing[{Small, Small}], Line3DBox[CompressedData["
1:eJwVV3k0lW8XlSGzTJnnmXvNXPO9hzsUigZDotKgQYmkfjJEKiFFyFBRJKlU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      "]]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], Thickness[0.005], 
     Line3DBox[CompressedData["
1:eJxdeXk0le/3tihzMs/DOaZkHs7hOM45z0ZEpUGD0mAqIZG5IpUGROZKiWRK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      "]]}}, 
   StyleBox[Text3DBox["\<\"Sun\"\>", {4, 4, 0}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[Text3DBox["\<\"Pluto\"\>", {-15, -19, 0}],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[Text3DBox["\<\"Neptune\"\>", {1, -27, 0}],
    FontFamily->"Times",
    FontSize->16], 
   {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{22.352848192585594`, 
     19.703519882044734`, -0.9204076075363867}, {22.228476191104882`, 
     19.843580118595618`, -0.9204198563996255}}]]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{-22.9176912516485, 30.179395759843402`, 
     3.3992487254186265`}, {-23.0594217490016, 29.987400554052133`, 
     3.4607956420140202`}}]]}},
  Boxed->False,
  PlotRange->All,
  SphericalRegion->True,
  ViewPoint->{0, 0, 20}]], "Output",
 CellChangeTimes->{
  3.889424499129526*^9, 3.889425723943811*^9, 3.889425796904862*^9, 
   3.889425863802103*^9, 3.889425930387162*^9, {3.889426972652176*^9, 
   3.8894270431477337`*^9}, 3.889427257122802*^9, 3.8894277293475122`*^9, 
   3.891017628348344*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"3ae832dd-fabc-46dc-a25f-b8cc22e4f5bb"]
}, Open  ]],

Cell["\<\
Calculate the Julian date at the start of 1989, our reference year.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"44624e13-118b-4f7a-8fd5-d2448cb843c0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"y1989", " ", "=", " ", 
  RowBox[{"JulianDate", "[", 
   RowBox[{"{", 
    RowBox[{"1989", ",", " ", "1", ",", " ", "1", ",", " ", "12."}], "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.888916165533124*^9, 3.8889161655359793`*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"84c3e68c-b592-4679-b6f1-c0f0d7298de9"],

Cell[BoxData["2.4475279583333335`*^6"], "Output",
 CellChangeTimes->{3.8889161661838217`*^9, 3.889427501916237*^9, 
  3.889427729357379*^9, 3.8910176283731527`*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"2be2f09c-6849-4f1c-bbc3-fbbbbe6eb9b3"]
}, Open  ]],

Cell[TextData[{
 "Define a simple function, ",
 StyleBox["Separation", "Input"],
 ", that calculates the distance between points defined by two position \
vectors, ",
 StyleBox["v1", "Input"],
 " and ",
 StyleBox["v2", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{3.888670949361918*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"555d8450-9ee6-4b81-bb5a-165feca2938c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Separation", "[", 
   RowBox[{"v1_", ",", " ", "v2_"}], "]"}], " ", ":=", "\n", 
  RowBox[{"Sqrt", "[", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"v1", "-", "v2"}], ")"}], "^", "2"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.888916178667593*^9, 3.888916178670327*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"fc480f8f-1919-4b50-b1c8-3629f3403985"],

Cell["\<\
Calculate the separation of Neptune and Pluto for a period of 1000 years \
centred on 1989.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ec0f2008-1f7c-4344-8f46-1df20cefb24a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sep", " ", "=", "\n", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1989", "+", "i"}], ",", " ", "\n", "       ", 
       RowBox[{"Separation", "[", 
        RowBox[{
         RowBox[{"PlanetXYZ", "[", 
          RowBox[{"8", ",", " ", 
           RowBox[{"y1989", "+", 
            RowBox[{"i", "*", "365.25"}]}]}], "]"}], ",", "\n", 
         "                  ", 
         RowBox[{"PlanetXYZ", "[", 
          RowBox[{"9", ",", " ", 
           RowBox[{"y1989", "+", 
            RowBox[{"i", "*", "365.25"}]}]}], "]"}]}], "]"}]}], "}"}], ",", 
     "\n", "      ", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"-", "500"}], ",", "500", ",", "2"}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.888916193619856*^9, 3.888916193622663*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"aa324cc8-b7a4-4829-9f9f-456b3bd00c81"],

Cell["Define the axis labels.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869373084037505*^9, 3.869373204667523*^9}, {
  3.869552502127846*^9, 3.869552527987165*^9}, {3.8695525676926813`*^9, 
  3.869552627902935*^9}, {3.869552688038094*^9, 3.8695527321988773`*^9}, {
  3.86955276584477*^9, 3.8695527789835157`*^9}, {3.869552853609722*^9, 
  3.8695529191526623`*^9}, {3.869553047085703*^9, 3.869553087120385*^9}, {
  3.870607952402626*^9, 3.870607986048612*^9}, {3.870608112694354*^9, 
  3.870608186135066*^9}, {3.870608226185451*^9, 3.8706082321707907`*^9}, {
  3.888066732220325*^9, 3.888066733585045*^9}, {3.888427818930439*^9, 
  3.888427819673703*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5ae671f9-7228-4f58-9a76-694e6b6f48af"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xlabel", "=", "\"\<Year\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ylabel", "=", "\"\<Separation (AU)\>\""}], ";"}]}], "Input",
 CellLabel->"In[23]:=",ExpressionUUID->"d53fda52-72ba-4a10-b60b-7bc505b66216"],

Cell["Plot the results.  This is Fig.9.34.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.88891624802958*^9, 3.888916255109871*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8c574b9b-0d1f-49a6-908e-84d9128225c7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"sep", ",", " ", 
   RowBox[{"Joined", "->", "True"}], ",", " ", 
   RowBox[{"Frame", "->", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"xlabel", ",", "ylabel"}], "}"}]}], ",", 
   RowBox[{"FrameStyle", "->", 
    RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
   RowBox[{"PlotRangePadding", "->", "None"}], ",", 
   RowBox[{"PlotRange", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1489", ",", " ", "2489"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"0", ",", "80"}], "}"}]}], "}"}]}], ",", " ", 
   RowBox[{"AxesOrigin", "->", 
    RowBox[{"{", 
     RowBox[{"1489", ",", "0"}], "}"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.8889162228173943`*^9, 3.888916222820115*^9}, {
  3.889427523277779*^9, 3.8894275357126923`*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"96456c5c-1da8-461b-add2-4979232cafab"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
     0.0055000000000000005`], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJw12HlcTev3B/DSRFKGhG5CpUsKNw0k+UiiEUkoQhJSIWUqSRKaL+XM5+y9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      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1489., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Separation (AU)\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Year\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{1489., 2489.}, {0., 80.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.888916224782346*^9, 3.8894275023649797`*^9, 
  3.889427729907642*^9, 3.8910176294974947`*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"a9a94210-856d-4b57-8e9b-7cc88f632704"]
}, Open  ]]
},
WindowToolbars->"MultipurposeBar",
CellGrouping->Manual,
WindowSize->{1050, 675},
WindowMargins->{{78, Automatic}, {Automatic, 23}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"5e9b0490-ccc8-47a8-95ae-45b3cc69d324"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 439, 9, 53, "Text",ExpressionUUID->"0521a82d-3ac4-4af3-ac0c-3ecb329ec3ba"],
Cell[1000, 31, 119, 0, 67, "Section",ExpressionUUID->"6e8e70b0-1575-4ccc-baaf-e425552046ca"],
Cell[1122, 33, 227, 6, 49, "Text",ExpressionUUID->"3c7aeaef-b3f9-4c07-be4d-8f4bc4dbd77f"],
Cell[CellGroupData[{
Cell[1374, 43, 337, 7, 30, "Input",ExpressionUUID->"d4a525c2-5c7e-4c5f-99a4-e11877c21736"],
Cell[1714, 52, 287, 4, 34, "Output",ExpressionUUID->"193a76b0-a57d-460c-82d4-bca8163b54d2"]
}, Open  ]],
Cell[2016, 59, 543, 15, 76, "Text",ExpressionUUID->"1e6ea287-f3f6-406f-a963-81a6d3dcd9d1"],
Cell[2562, 76, 17947, 396, 1879, "Input",ExpressionUUID->"e986d2c8-6682-408d-b946-ac05cf7e7474"],
Cell[20512, 474, 628, 18, 99, "Text",ExpressionUUID->"06eee10d-3ff4-41e5-a807-c90227427eee"],
Cell[21143, 494, 15227, 333, 1522, "Input",ExpressionUUID->"388b24a0-4c3d-4561-9097-3da0221cc470"],
Cell[36373, 829, 462, 13, 76, "Text",ExpressionUUID->"08e74ed8-0797-4847-9022-fce34af1facb"],
Cell[36838, 844, 9713, 202, 1123, "Input",ExpressionUUID->"f68ca662-ed8b-4978-bff1-602abda50129"],
Cell[46554, 1048, 560, 19, 76, "Text",ExpressionUUID->"d05c996d-7459-4ae3-8619-4ae813fccd6d"],
Cell[47117, 1069, 5856, 148, 619, "Input",ExpressionUUID->"6d21460d-0123-4e60-9f21-ccbdaf51f309"],
Cell[52976, 1219, 478, 14, 76, "Text",ExpressionUUID->"a5208f34-cbff-4da1-9fbb-0f6646570de2"],
Cell[53457, 1235, 597, 15, 52, "Input",ExpressionUUID->"bd5b1bdd-47d3-4af7-8945-57037a25b020"],
Cell[54057, 1252, 382, 6, 53, "Text",ExpressionUUID->"2a95b0b2-a352-4075-97a7-5f59ef5ebfb5"],
Cell[54442, 1260, 487, 12, 56, "Input",ExpressionUUID->"ace28e4d-4334-4e26-a75d-00e9831428cf"],
Cell[54932, 1274, 313, 9, 53, "Text",ExpressionUUID->"35ce9c0f-2e58-40f7-9127-35236564ad5e"],
Cell[55248, 1285, 2414, 59, 199, "Input",ExpressionUUID->"21cf9018-4114-4d65-ba12-700a036b685f"],
Cell[57665, 1346, 240, 4, 53, "Text",ExpressionUUID->"bd6027c6-f73a-4709-9302-8e8f95a59d2e"],
Cell[CellGroupData[{
Cell[57930, 1354, 300, 7, 30, "Input",ExpressionUUID->"504edf43-0e45-4157-943a-a52a33af7412"],
Cell[58233, 1363, 13576, 229, 384, "Output",ExpressionUUID->"b725b66b-7703-47f3-9f4c-ebac15da4972"]
}, Open  ]],
Cell[71824, 1595, 313, 8, 53, "Text",ExpressionUUID->"0591ee4e-3327-4b75-bf04-035f1a306d57"],
Cell[72140, 1605, 11139, 277, 619, "Input",ExpressionUUID->"440a53e5-37e5-4aad-8b4e-46218272edb6"],
Cell[83282, 1884, 247, 4, 53, "Text",ExpressionUUID->"883787f3-cdd6-4b46-824f-abc770631d33"],
Cell[CellGroupData[{
Cell[83554, 1892, 329, 6, 30, "Input",ExpressionUUID->"471265d3-11b5-43b3-bb0f-394197914ce0"],
Cell[83886, 1900, 64016, 1061, 377, "Output",ExpressionUUID->"b01f7dc2-8c4d-4251-81d7-5f895eb3052b"],
Cell[CellGroupData[{
Cell[147927, 2965, 63992, 1061, 373, "Input",ExpressionUUID->"b72db828-fea3-4011-a6a8-63525bdcf306"],
Cell[211922, 4028, 64013, 1061, 377, "Output",ExpressionUUID->"c4010176-dd39-4283-990c-e41db1e4e6fd"]
}, Open  ]]
}, Open  ]],
Cell[275962, 5093, 421, 9, 53, "Text",ExpressionUUID->"5b1edd8b-4dac-439c-8fe8-0cfa3dfb6a90"],
Cell[276386, 5104, 2752, 75, 115, "Input",ExpressionUUID->"1073b826-2c12-4354-8bd6-8c0ee91ae26f"],
Cell[279141, 5181, 422, 9, 53, "Text",ExpressionUUID->"d9553d0d-4101-4aec-8b23-75bd8523239f"],
Cell[CellGroupData[{
Cell[279588, 5194, 556, 11, 30, "Input",ExpressionUUID->"a0ed153f-0510-4405-866a-58df4ef7c6bc"],
Cell[280147, 5207, 65024, 1083, 377, "Output",ExpressionUUID->"3ae832dd-fabc-46dc-a25f-b8cc22e4f5bb"]
}, Open  ]],
Cell[345186, 6293, 201, 5, 53, "Text",ExpressionUUID->"44624e13-118b-4f7a-8fd5-d2448cb843c0"],
Cell[CellGroupData[{
Cell[345412, 6302, 340, 7, 30, "Input",ExpressionUUID->"84c3e68c-b592-4679-b6f1-c0f0d7298de9"],
Cell[345755, 6311, 243, 3, 34, "Output",ExpressionUUID->"2be2f09c-6849-4f1c-bbc3-fbbbbe6eb9b3"]
}, Open  ]],
Cell[346013, 6317, 397, 13, 53, "Text",ExpressionUUID->"555d8450-9ee6-4b81-bb5a-165feca2938c"],
Cell[346413, 6332, 460, 12, 52, "Input",ExpressionUUID->"fc480f8f-1919-4b50-b1c8-3629f3403985"],
Cell[346876, 6346, 225, 6, 53, "Text",ExpressionUUID->"ec0f2008-1f7c-4344-8f46-1df20cefb24a"],
Cell[347104, 6354, 929, 25, 115, "Input",ExpressionUUID->"aa324cc8-b7a4-4829-9f9f-456b3bd00c81"],
Cell[348036, 6381, 754, 12, 53, "Text",ExpressionUUID->"5ae671f9-7228-4f58-9a76-694e6b6f48af"],
Cell[348793, 6395, 259, 5, 52, "Input",ExpressionUUID->"d53fda52-72ba-4a10-b60b-7bc505b66216"],
Cell[349055, 6402, 227, 4, 53, "Text",ExpressionUUID->"8c574b9b-0d1f-49a6-908e-84d9128225c7"],
Cell[CellGroupData[{
Cell[349307, 6410, 1176, 29, 94, "Input",ExpressionUUID->"96456c5c-1da8-461b-add2-4979232cafab"],
Cell[350486, 6441, 10457, 208, 286, "Output",ExpressionUUID->"a9a94210-856d-4b57-8e9b-7cc88f632704"]
}, Open  ]]
}
]
*)

